@@ -1,7 +1,7 @@
 /*
  * @(#)Barrel.c
  *
- * Copyright 2003 - 2008  David A. Bagley, bagleyd@tux.org
+ * Copyright 2003 - 2010  David A. Bagley, bagleyd@tux.org
  *
  * All rights reserved.
  *
@@ -1985,37 +1985,37 @@ setValuesPuzzle(BarrelWidget w)
 	char szBuf[80], buf[20], charbuf[2];
 	int face;
 
-	w->barrel.tiles = GetPrivateProfileInt(SECTION, "tiles",
-		DEFAULT_TILES, INIFILE);
-	w->barrel.faces = GetPrivateProfileInt(SECTION, "faces",
-		DEFAULT_FACES, INIFILE);
-	w->barrel.orient = (BOOL) GetPrivateProfileInt(SECTION, "orient",
-		DEFAULT_ORIENT, INIFILE);
-	w->barrel.pairs = (BOOL) GetPrivateProfileInt(SECTION, "pairs",
-		DEFAULT_PAIRS, INIFILE);
-	w->barrel.practice = (BOOL) GetPrivateProfileInt(SECTION, "practice",
-		DEFAULT_PRACTICE, INIFILE);
-	w->barrel.base = GetPrivateProfileInt(SECTION, "base",
-		DEFAULT_BASE, INIFILE);
-	w->barrel.mono = (BOOL) GetPrivateProfileInt(SECTION, "mono",
-		DEFAULT_MONO, INIFILE);
+	w->barrel.tiles = GetPrivateProfileInt(SECTION,
+		"tiles", DEFAULT_TILES, INIFILE);
+	w->barrel.faces = GetPrivateProfileInt(SECTION,
+		"faces", DEFAULT_FACES, INIFILE);
+	w->barrel.orient = (BOOL) GetPrivateProfileInt(SECTION,
+		"orient", DEFAULT_ORIENT, INIFILE);
+	w->barrel.pairs = (BOOL) GetPrivateProfileInt(SECTION,
+		"pairs", DEFAULT_PAIRS, INIFILE);
+	w->barrel.practice = (BOOL) GetPrivateProfileInt(SECTION,
+		"practice", DEFAULT_PRACTICE, INIFILE);
+	w->barrel.base = GetPrivateProfileInt(SECTION,
+		"base", DEFAULT_BASE, INIFILE);
+	w->barrel.mono = (BOOL) GetPrivateProfileInt(SECTION,
+		"mono", DEFAULT_MONO, INIFILE);
 	w->barrel.reverse = (BOOL) GetPrivateProfileInt(SECTION,
 		"reverseVideo", DEFAULT_REVERSE, INIFILE);
 	/* cyan */
-	(void) GetPrivateProfileString(SECTION, "frameColor", "0 255 255",
-		szBuf, sizeof (szBuf), INIFILE);
+	(void) GetPrivateProfileString(SECTION,
+		"frameColor", "0 255 255", szBuf, sizeof (szBuf), INIFILE);
 	(void) sscanf(szBuf, "%d %d %d",
 		&(color.red), &(color.green), &(color.blue));
 	w->barrel.frameGC = RGB(color.red, color.green, color.blue);
 	/* gray75 */
-	(void) GetPrivateProfileString(SECTION, "tileColor", "191 191 191",
-		szBuf, sizeof (szBuf), INIFILE);
+	(void) GetPrivateProfileString(SECTION,
+		"tileColor", "191 191 191", szBuf, sizeof (szBuf), INIFILE);
 	(void) sscanf(szBuf, "%d %d %d",
 		&(color.red), &(color.green), &(color.blue));
 	w->barrel.tileGC[1] = RGB(color.red, color.green, color.blue);
 	/* gray50 */
-	(void) GetPrivateProfileString(SECTION, "tileBorder", "127 127 127",
-		szBuf, sizeof (szBuf), INIFILE);
+	(void) GetPrivateProfileString(SECTION,
+		"tileBorder", "127 127 127", szBuf, sizeof (szBuf), INIFILE);
 	(void) sscanf(szBuf, "%d %d %d",
 		&(color.red), &(color.green), &(color.blue));
 	w->barrel.tileGC[0] = RGB(brighter(color.red),
@@ -2024,8 +2024,8 @@ setValuesPuzzle(BarrelWidget w)
 		darker(color.green), darker(color.blue));
 	w->barrel.borderGC = RGB(color.red, color.green, color.blue);
 	/* #AEB2C3 */
-	(void) GetPrivateProfileString(SECTION, "background", "174 178 195",
-		szBuf, sizeof (szBuf), INIFILE);
+	(void) GetPrivateProfileString(SECTION,
+		"background", "174 178 195", szBuf, sizeof (szBuf), INIFILE);
 	(void) sscanf(szBuf, "%d %d %d",
 		&(color.red), &(color.green), &(color.blue));
 	w->barrel.inverseGC = RGB(color.red, color.green, color.blue);
@@ -2041,34 +2041,29 @@ setValuesPuzzle(BarrelWidget w)
 		(void) sprintf(buf, "faceChar%d", face);
 		charbuf[0] = faceColorChar[face];
 		charbuf[1] = '\0';
-		(void) GetPrivateProfileString(SECTION, buf, charbuf,
-			szBuf, sizeof (szBuf), INIFILE);
+		(void) GetPrivateProfileString(SECTION,
+			buf, charbuf, szBuf, sizeof (szBuf), INIFILE);
 		w->barrel.faceChar[face] = szBuf[0];
 	}
-	(void) GetPrivateProfileString(SECTION, "picture", PICTURE,
-		szBuf, sizeof (szBuf), INIFILE);
-	(void) strcpy(w->barrel.picture, szBuf);
-	w->barrel.picture[80] = 0;
-	w->barrel.delay = GetPrivateProfileInt(SECTION, "delay",
-		DEFAULT_DELAY, INIFILE);
-	w->barrel.sound = (BOOL)
-		GetPrivateProfileInt(SECTION, "sound", 0, INIFILE);
-	(void) GetPrivateProfileString(SECTION, "bumpSound", BUMPSOUND,
-		szBuf, sizeof (szBuf), INIFILE);
-	w->barrel.bumpSound[80] = 0;
-	(void) strcpy(w->barrel.bumpSound, szBuf);
-	(void) GetPrivateProfileString(SECTION, "moveSound", MOVESOUND,
-		szBuf, sizeof (szBuf), INIFILE);
-	(void) strcpy(w->barrel.moveSound, szBuf);
-	w->barrel.moveSound[80] = 0;
-	(void) GetPrivateProfileString(SECTION, "userName", "Guest",
-			szBuf, sizeof (szBuf), INIFILE);
-	(void) strcpy(w->barrel.userName, szBuf);
-	w->barrel.userName[80] = 0;
-	(void) GetPrivateProfileString(SECTION, "scoreFile", "",
-			szBuf, sizeof (szBuf), INIFILE);
-	(void) strcpy(w->barrel.scoreFile, szBuf);
-	w->barrel.scoreFile[80] = 0;
+	(void) GetPrivateProfileString(SECTION,
+		"picture", PICTURE, szBuf, sizeof (szBuf), INIFILE);
+	(void) strncpy(w->barrel.picture, szBuf, 80);
+	w->barrel.delay = GetPrivateProfileInt(SECTION,
+		"delay", DEFAULT_DELAY, INIFILE);
+	w->barrel.sound = (BOOL) GetPrivateProfileInt(SECTION,
+		"sound", 0, INIFILE);
+	(void) GetPrivateProfileString(SECTION,
+		"bumpSound", BUMPSOUND, szBuf, sizeof (szBuf), INIFILE);
+	(void) strncpy(w->barrel.bumpSound, szBuf, 80);
+	(void) GetPrivateProfileString(SECTION,
+		"moveSound", MOVESOUND, szBuf, sizeof (szBuf), INIFILE);
+	(void) strncpy(w->barrel.moveSound, szBuf, 80);
+	(void) GetPrivateProfileString(SECTION,
+		"userName", "Guest", szBuf, sizeof (szBuf), INIFILE);
+	(void) strncpy(w->barrel.userName, szBuf, 80);
+	(void) GetPrivateProfileString(SECTION,
+		"scoreFile", "", szBuf, sizeof (szBuf), INIFILE);
+	(void) strncpy(w->barrel.scoreFile, szBuf, 80);
 }
 
 void
@@ -2375,10 +2370,8 @@ destroyPuzzle(Widget old)
 	Display *display = XtDisplay(w);
 	int i;
 
-#if 0
 #if defined( USE_SOUND ) && defined( USE_ESOUND )
 	(void) shutdown_sound();
-#endif
 #endif
 	for (i = 0; i < MAX_COLORS; i++)
 		XtReleaseGC(old, w->barrel.faceGC[i]);
@@ -2609,12 +2602,10 @@ Widget request, Widget renew
 #ifdef USE_NAS
 	dsp = XtDisplay(w);
 #endif
-#if 0
 #ifdef USE_ESOUND
 	(void) init_sound();
 #endif
 #endif
-#endif
 }
 
 void
