@@ -4,7 +4,7 @@
  * Taken from James G. Nourse's The Simple Solutions to Cubic Puzzles.
  * Break ability taken from the X puzzle by Don Bennett, HP Labs
  *
- * Copyright 2003 - 2008  David A. Bagley, bagleyd@tux.org
+ * Copyright 2003 - 2009  David A. Bagley, bagleyd@tux.org
  *
  * All rights reserved.
  *
@@ -1500,7 +1500,9 @@ solveL0(BarrelWidget w)
 static int
 moveToCenter(BarrelWidget w, int level, int face)
 {
+#if DEBUG
 	printf("moveToCenter level %d, face %d\n", level, face);
+#endif
 	/* move to 11 */
 	if (level == 1) {
 		switch (face) {
@@ -1640,7 +1642,9 @@ solveL1Orient(BarrelWidget w)
 	int orient[MAX_FACES] = {-1, -1, -1, -1, -1};
 	int piece = checkLevelSolved(w, 1);
 	int currentLevel, currentFace;
+#ifdef DEBUG
 	int ok = -2;
+#endif
 
 	if (piece == w->barrel.faces) {
 		return True;
@@ -1695,7 +1699,7 @@ solveL1Orient(BarrelWidget w)
 					LeftAway(w);
 				}
 			} else {
-				ok = moveToCenter(w, currentLevel,
+				(void) moveToCenter(w, currentLevel,
 					currentFace);
 				LeftSlide(w);
 				if (NRANDOM(2) == 1) {
@@ -1721,14 +1725,23 @@ solveL1Orient(BarrelWidget w)
 		}
 	}
 	piece = 17;
+#ifdef DEBUG
 	(void) printf("solving level 1, piece %d\n", piece);
+#endif
 	if (ORIENTTILE(2, 2) != piece) {
 		currentLevel = findLevelOrient(w, piece);
 		currentFace = findFaceOrient(w, currentLevel, piece);
-		ok = moveToCenter(w, currentLevel, currentFace);
+#ifdef DEBUG
+		ok =
+#else
+		(void)
+#endif
+		moveToCenter(w, currentLevel, currentFace);
 		L2_3222(w);
-		(void) printf("solving level 1, %d %d\n",
-			currentLevel, currentFace);
+#ifdef DEBUG
+		(void) printf("solving level 1, %d %d %d\n",
+			currentLevel, currentFace, ok);
+#endif
 	}
 	orient[0] = ORIENTTILE(1, 2);
 	orient[1] = ORIENTTILE(2, 2);
@@ -1737,13 +1750,22 @@ solveL1Orient(BarrelWidget w)
 		orient[0], orient[1]);
 #endif
 	piece = 9;
+#ifdef DEBUG
 	(void) printf("solving level 1, piece %d\n", piece);
+#endif
 	if (ORIENTTILE(3, 2) != piece) {
 		currentLevel = findLevelOrient(w, piece);
 		currentFace = findFaceOrient(w, currentLevel, piece);
-		ok = moveToCenter(w, currentLevel, currentFace);
-		(void) printf("solving level 1, %d %d\n",
-			currentLevel, currentFace);
+#ifdef DEBUG
+		ok =
+#else
+		(void)
+#endif
+		moveToCenter(w, currentLevel, currentFace);
+#ifdef DEBUG
+		(void) printf("solving level 1, %d %d %d\n",
+			currentLevel, currentFace, ok);
+#endif
 	}
 	orient[0] = ORIENTTILE(1, 2);
 	orient[1] = ORIENTTILE(2, 2);
@@ -1771,13 +1793,22 @@ solveL1Orient(BarrelWidget w)
 		orient[0], orient[1], orient[2], orient[3]);
 #endif
 	piece = 5;
+#ifdef DEBUG
 	(void) printf("solving level 1, piece %d\n", piece);
+#endif
 	if (ORIENTTILE(2, 1) != piece) {
 		currentLevel = findLevelOrient(w, piece);
 		currentFace = findFaceOrient(w, currentLevel, piece);
-		ok = moveToCenter(w, currentLevel, currentFace);
-		(void) printf("solving level 1, %d %d\n",
-			currentLevel, currentFace);
+#ifdef DEBUG
+		ok =
+#else
+		(void)
+#endif
+		moveToCenter(w, currentLevel, currentFace);
+#ifdef DEBUG
+		(void) printf("solving level 1, %d %d %d\n",
+			currentLevel, currentFace, ok);
+#endif
 		L1_E(w);
 	}
 	orient[0] = ORIENTTILE(1, 4);
@@ -1790,13 +1821,22 @@ solveL1Orient(BarrelWidget w)
 		orient[0], orient[1], orient[2], orient[3], orient[4]);
 #endif
 	piece = 13;
+#ifdef DEBUG
 	(void) printf("solving level 1, piece %d\n", piece);
+#endif
 	if (ORIENTTILE(2, 3) != piece) {
 		currentLevel = findLevelOrient(w, piece);
 		currentFace = findFaceOrient(w, currentLevel, piece);
-		ok = moveToCenter(w, currentLevel, currentFace);
+#ifdef DEBUG
+		ok =
+#else
+		(void)
+#endif
+		moveToCenter(w, currentLevel, currentFace);
+#ifdef DEBUG
 		(void) printf("solving level 1, %d %d\n",
 			currentLevel, currentFace);
+#endif
 		L1_F(w);
 	}
 	orient[0] = ORIENTTILE(1, 4);
@@ -1815,7 +1855,7 @@ solveL1Orient(BarrelWidget w)
 	orient[3] = ORIENTTILE(1, 1);
 	orient[4] = ORIENTTILE(1, 3); /* see if already in place */
 #ifdef DEBUG
-	(void) printf("1H: 1,4: %d, 1,3: %d, 1,2: %d, 1,1: %d, 1,3: %d\n",
+	(void) printf("1H: 1,0: %d, 1,4: %d, 1,2: %d, 1,1: %d, 1,3: %d\n",
 		orient[0], orient[1], orient[2], orient[3], orient[4]);
 #endif
 	return True;
