@@ -1,7 +1,7 @@
 /*
  * @(#)Cubes.c
  *
- * Copyright 1994 - 2008  David A. Bagley, bagleyd@tux.org
+ * Copyright 1994 - 2010  David A. Bagley, bagleyd@tux.org
  *
  * All rights reserved.
  *
@@ -120,6 +120,7 @@ static char translations[] =
  <KeyPress>0x2C: Slow()\n\
  Shift<KeyPress>2: Sound()\n\
  <KeyPress>o: MoveOut()\n\
+ <KeyPress>F11: MoveOut()\n\
  <KeyPress>KP_Divide: MoveOut()\n\
  <KeyPress>R5: MoveOut()\n\
  <KeyPress>Up: MoveTop()\n\
@@ -133,6 +134,7 @@ static char translations[] =
  <KeyPress>KP_4: MoveLeft()\n\
  <KeyPress>R10: MoveLeft()\n\
  <KeyPress>i: MoveIn()\n\
+ <KeyPress>F12: MoveIn()\n\
  <KeyPress>Begin: MoveIn()\n\
  <KeyPress>KP_5: MoveIn()\n\
  <KeyPress>R11: MoveIn()\n\
@@ -1993,27 +1995,27 @@ setValuesPuzzle(CubesWidget w)
 	} color;
 	char szBuf[80];
 
-	w->cubes.sizeX = GetPrivateProfileInt(SECTION, "sizeX",
-		DEFAULT_CUBESX, INIFILE);
-	w->cubes.sizeY = GetPrivateProfileInt(SECTION, "sizeY",
-		DEFAULT_CUBESY, INIFILE);
-	w->cubes.sizeZ = GetPrivateProfileInt(SECTION, "sizeZ",
-		DEFAULT_CUBESZ, INIFILE);
-	w->cubes.base = GetPrivateProfileInt(SECTION, "base",
-		DEFAULT_BASE, INIFILE);
-	w->cubes.mono = (BOOL) GetPrivateProfileInt(SECTION, "mono",
-		DEFAULT_MONO, INIFILE);
-	w->cubes.reverse = (BOOL) GetPrivateProfileInt(SECTION, "reverseVideo",
-		DEFAULT_REVERSE, INIFILE);
+	w->cubes.sizeX = GetPrivateProfileInt(SECTION,
+		"sizeX", DEFAULT_CUBESX, INIFILE);
+	w->cubes.sizeY = GetPrivateProfileInt(SECTION,
+		"sizeY", DEFAULT_CUBESY, INIFILE);
+	w->cubes.sizeZ = GetPrivateProfileInt(SECTION,
+		"sizeZ", DEFAULT_CUBESZ, INIFILE);
+	w->cubes.base = GetPrivateProfileInt(SECTION,
+		"base", DEFAULT_BASE, INIFILE);
+	w->cubes.mono = (BOOL) GetPrivateProfileInt(SECTION,
+		"mono", DEFAULT_MONO, INIFILE);
+	w->cubes.reverse = (BOOL) GetPrivateProfileInt(SECTION,
+		"reverseVideo", DEFAULT_REVERSE, INIFILE);
 	/* cyan */
-	(void) GetPrivateProfileString(SECTION, "frameColor", "0 255 255",
-		szBuf, sizeof (szBuf), INIFILE);
+	(void) GetPrivateProfileString(SECTION,
+		"frameColor", "0 255 255", szBuf, sizeof (szBuf), INIFILE);
 	(void) sscanf(szBuf, "%d %d %d",
 		&(color.red), &(color.green), &(color.blue));
 	w->cubes.frameGC = RGB(color.red, color.green, color.blue);
 	/* gray75 */
-	(void) GetPrivateProfileString(SECTION, "blockColor", "191 191 191",
-		szBuf, sizeof (szBuf), INIFILE);
+	(void) GetPrivateProfileString(SECTION,
+		"blockColor", "191 191 191", szBuf, sizeof (szBuf), INIFILE);
 	(void) sscanf(szBuf, "%d %d %d",
 		&(color.red), &(color.green), &(color.blue));
 	w->cubes.blockGC[1] = RGB(color.red, color.green, color.blue);
@@ -2022,14 +2024,14 @@ setValuesPuzzle(CubesWidget w)
 	w->cubes.blockGC[2] = RGB(darker(color.red),
 		darker(color.green), darker(color.blue));
 	/* gray25 */
-	(void) GetPrivateProfileString(SECTION, "textColor", "64 64 64",
-		szBuf, sizeof (szBuf), INIFILE);
+	(void) GetPrivateProfileString(SECTION,
+		"textColor", "64 64 64", szBuf, sizeof (szBuf), INIFILE);
 	(void) sscanf(szBuf, "%d %d %d",
 		&(color.red), &(color.green), &(color.blue));
 	w->cubes.textGC = RGB(color.red, color.green, color.blue);
 	/* #AEB2C3 */
-	(void) GetPrivateProfileString(SECTION, "background", "174 178 195",
-		szBuf, sizeof (szBuf), INIFILE);
+	(void) GetPrivateProfileString(SECTION,
+		"background", "174 178 195", szBuf, sizeof (szBuf), INIFILE);
 	(void) sscanf(szBuf, "%d %d %d",
 		&(color.red), &(color.green), &(color.blue));
 	w->cubes.inverseGC[1] = RGB(color.red, color.green, color.blue);
@@ -2042,30 +2044,25 @@ setValuesPuzzle(CubesWidget w)
 	w->cubes.inverseGC[4] = RGB(darker(darker(darker(color.red))),
 		darker(darker(darker(color.green))),
 		darker(darker(darker(color.blue))));
-	(void) GetPrivateProfileString(SECTION, "picture", PICTURE,
-		szBuf, sizeof (szBuf), INIFILE);
-	(void) strcpy(w->cubes.picture, szBuf);
-	w->cubes.picture[80] = 0;
-	w->cubes.delay = GetPrivateProfileInt(SECTION, "delay",
-		DEFAULT_DELAY, INIFILE);
-	w->cubes.sound = (BOOL)
-		GetPrivateProfileInt(SECTION, "sound", 0, INIFILE);
-	(void) GetPrivateProfileString(SECTION, "bumpSound", BUMPSOUND,
-		szBuf, sizeof (szBuf), INIFILE);
-	(void) strcpy(w->cubes.bumpSound, szBuf);
-	w->cubes.bumpSound[80] = 0;
-	(void) GetPrivateProfileString(SECTION, "dripSound", DRIPSOUND,
-		szBuf, sizeof (szBuf), INIFILE);
-	(void) strcpy(w->cubes.dripSound, szBuf);
-	w->cubes.dripSound[80] = 0;
-	(void) GetPrivateProfileString(SECTION, "userName", "Guest",
-		szBuf, sizeof (szBuf), INIFILE);
-	(void) strcpy(w->cubes.userName, szBuf);
-	w->cubes.userName[80] = 0;
-	(void) GetPrivateProfileString(SECTION, "scoreFile", "",
-		szBuf, sizeof (szBuf), INIFILE);
-	(void) strcpy(w->cubes.scoreFile, szBuf);
-	w->cubes.scoreFile[80] = 0;
+	(void) GetPrivateProfileString(SECTION,
+		"picture", PICTURE, szBuf, sizeof (szBuf), INIFILE);
+	(void) strncpy(w->cubes.picture, szBuf, 80);
+	w->cubes.delay = GetPrivateProfileInt(SECTION,
+		"delay", DEFAULT_DELAY, INIFILE);
+	w->cubes.sound = (BOOL) GetPrivateProfileInt(SECTION,
+		"sound", 0, INIFILE);
+	(void) GetPrivateProfileString(SECTION,
+		"bumpSound", BUMPSOUND, szBuf, sizeof (szBuf), INIFILE);
+	(void) strncpy(w->cubes.bumpSound, szBuf, 80);
+	(void) GetPrivateProfileString(SECTION,
+		"dripSound", DRIPSOUND, szBuf, sizeof (szBuf), INIFILE);
+	(void) strncpy(w->cubes.dripSound, szBuf, 80);
+	(void) GetPrivateProfileString(SECTION,
+		"userName", "Guest", szBuf, sizeof (szBuf), INIFILE);
+	(void) strncpy(w->cubes.userName, szBuf, 80);
+	(void) GetPrivateProfileString(SECTION,
+		"scoreFile", "", szBuf, sizeof (szBuf), INIFILE);
+	(void) strncpy(w->cubes.scoreFile, szBuf, 80);
 }
 
 void
@@ -2328,10 +2325,8 @@ destroyPuzzle(Widget old)
 	Display *display = XtDisplay(w);
 	int i;
 
-#if 0
 #if defined( USE_SOUND ) && defined( USE_ESOUND )
 	(void) shutdown_sound();
-#endif
 #endif
 	XtReleaseGC(old, w->cubes.textGC);
 	for (i = 0; i < FG_SHADES; i++)
@@ -2568,12 +2563,10 @@ Widget request, Widget renew
 #ifdef USE_NAS
 	dsp = XtDisplay(w);
 #endif
-#if 0
 #ifdef USE_ESOUND
 	(void) init_sound();
 #endif
 #endif
-#endif
 }
 
 #ifndef WINVER
