@@ -1,7 +1,7 @@
 /*
  * @(#)xcubes.c
  *
- * Copyright 1993 - 2009  David A. Bagley, bagleyd@tux.org
+ * Copyright 1993 - 2010  David A. Bagley, bagleyd@tux.org
  *
  * All rights reserved.
  *
@@ -21,8 +21,9 @@
 /* Driver file for Cubes */
 
 #ifndef WINVER
+#include "version.h"
 static const char aboutHelp[] = {
-"Cubes Version 7.5\n"
+"Cubes Version " VERSION "\n"
 "Send bugs (reports or fixes) to the author: "
 "David Bagley <bagleyd@tux.org>\n"
 "The latest version is at: "
@@ -45,14 +46,14 @@ static const char optionsHelp[] = {
 #if defined(HAVE_MOTIF) || defined(WINVER)
 static const char descriptionHelp[] = {
 "A 3D  sliding block puzzle.  The cubes represented are  "
-"flattened out on the plane.  If the Blocks Z slider is\n"
-"greater than 1, then each group of boxes is a layer of the "
+"flattened out on the plane.  If the Blocks Z slider  is\n"
+"greater than 1,  then each group of boxes is a layer of the "
 "puzzle.  If the Blocks Z slider = 1, then this is a\n"
-"simple 15 tile puzzle.  The 15 puzzle was originally "
-"made around 1879 (the 14-15  puzzle of Sam Loyd  was made\n"
-"soon after.)  Similar 3D puzzles include  BloxBox; "
-"Qrazy Qube (2x2x2) by P. Hein of Denmark and Varikon Box 'L\n"
-"Box 'L (3x3x3) (Hungary) and Mad Marbles (3x3x3) by "
+"simple 15 tile puzzle.  The 15 puzzle was originally made "
+"around 1880 by Noyes Chapman (the 14-15 puzzle of Sam\n"
+"Loyd  was made soon after.)  Similar 3D puzzles include  BloxBox; "
+"Qrazy Qube (2x2x2)  by P. Hein of Denmark and\n"
+"Varikon Box 'L (3x3x3) (Hungary) and Mad Marbles (3x3x3) by "
 "Toys & Games International USA."
 };
 
@@ -398,6 +399,7 @@ writeRecords(void)
 		char lockFile[FILE_NAME_LENGTH];
 
 		(void) strncpy(lockFile, fileName, FILE_NAME_LENGTH - 6);
+		lockFile[FILE_NAME_LENGTH - 6] = '\0';
 		(void) strcat(lockFile, ".lock");
 		while (((lfd = open(lockFile, O_CREAT | O_EXCL, 0644)) < 0) &&
 				errno == EEXIST)
