@@ -1,7 +1,7 @@
 /*
  * @(#)Dino.c
  *
- * Copyright 1995 - 2008  David A. Bagley, bagleyd@tux.org
+ * Copyright 1995 - 2010  David A. Bagley, bagleyd@tux.org
  *
  * All rights reserved.
  *
@@ -124,7 +124,7 @@ setPuzzle(DinoWidget w, int reason)
 
 static void
 setPuzzleMove(DinoWidget w, int reason, int face, int position, int direction,
-		int style)
+		int style, int control, int fast)
 {
 	dinoCallbackStruct cb;
 
@@ -133,6 +133,8 @@ setPuzzleMove(DinoWidget w, int reason, int face, int position, int direction,
 	cb.position = position;
 	cb.direction = direction;
 	cb.style = style;
+	cb.control = control;
+	cb.fast = fast;
 	XtCallCallbacks((Widget) w, (char *) XtNselectCallback, &cb);
 }
 #endif
@@ -484,7 +486,7 @@ static DinoStack redo = {NULL, NULL, NULL, 0};
 static void
 checkPieces(DinoWidget w)
 {
-	char *buf1 = NULL;
+	char *buf1 = NULL, *buf2 = NULL;
 
 	if (w->dino.mode < PERIOD2 || w->dino.mode > BOTH) {
 		intCat(&buf1, "Mode is in error, use 2 for Period2, 3 for Period3, 4 for Both, defaulting to ",
@@ -493,6 +495,15 @@ checkPieces(DinoWidget w)
 		free(buf1);
 		w->dino.mode = DEFAULT_MODE;
 	}
+	if (w->dino.delay < 0) {
+		intCat(&buf1, "Delay can not be negative (",
+			w->dino.delay);
+		stringCat(&buf2, buf1, "), taking absolute value");
+		free(buf1);
+		DISPLAY_WARNING(buf2);
+		free(buf2);
+		w->dino.delay = -w->dino.delay;
+	}
 }
 
 static int
@@ -544,7 +555,7 @@ checkSolved(DinoWidget w)
 	return True;
 }
 
-#if DEBUG
+#ifdef DEBUG
 void
 printCube(DinoWidget w)
 {
@@ -570,6 +581,16 @@ drawTriangle(DinoWidget w, int face, int position, int offset)
 		drawTriangle3D((Dino3DWidget) w, face, position, offset);
 }
 
+static void
+drawTriangleAll(DinoWidget w, int face, int position, int offset)
+{
+	drawTriangle(w, face, position, offset);
+#ifdef HAVE_OPENGL
+	if (w->dino.dim == 4)
+		drawAllPiecesGL((DinoGLWidget) w);
+#endif
+}
+
 void
 drawAllPieces(DinoWidget w)
 {
@@ -578,11 +599,13 @@ drawAllPieces(DinoWidget w)
 #ifdef HAVE_OPENGL
 	if (w->dino.dim == 4) {
 		drawAllPiecesGL((DinoGLWidget) w);
+		return;
 	}
 #endif
-	for (face = 0; face < MAX_FACES; face++)
+	for (face = 0; face < MAX_FACES; face++) {
 		for (position = 0; position < MAX_ORIENT; position++)
 			drawTriangle(w, face, position, FALSE);
+	}
 }
 
 static void
@@ -622,11 +645,6 @@ rotateFace(DinoWidget w, int face, int direction)
 			MAX_ORIENT;
 		drawTriangle(w, face, side, FALSE);
 	}
-#ifdef HAVE_OPENGL
-	if (w->dino.dim == 4) {
-		drawAllPiecesGL((DinoGLWidget) w);
-	}
-#endif
 }
 
 static void
@@ -647,11 +665,6 @@ writeDiagonal(DinoWidget w, int face, int corner, int rotate, int h)
 	drawTriangle(w, face, corner, FALSE);
 	w->dino.cubeLoc[face][(corner + 1) % MAX_ORIENT] = w->dino.spindleLoc[h][1];
 	drawTriangle(w, face, (corner + 1) % MAX_ORIENT, FALSE);
-#ifdef HAVE_OPENGL
-	if (w->dino.dim == 4) {
-		drawAllPiecesGL((DinoGLWidget) w);
-	}
-#endif
 }
 
 static void
@@ -676,11 +689,6 @@ writeFace(DinoWidget w, int face, int rotate, int h)
 			MAX_ORIENT;
 		drawTriangle(w, face, (side + rotate) % MAX_ORIENT, FALSE);
 	}
-#ifdef HAVE_OPENGL
-	if (w->dino.dim == 4) {
-		drawAllPiecesGL((DinoGLWidget) w);
-	}
-#endif
 }
 
 static void
@@ -776,13 +784,20 @@ moveOutsideCorners(DinoWidget w, int face, int corner, int direction)
 }
 
 static void
-movePieces(DinoWidget w, int face, int position, int direction, int style)
+movePieces(DinoWidget w, int face, int position, int direction, int style,
+		int control, int fast)
 {
 	int oldFace = face, dir = direction;
 	int corner, newCorner;
 
 	corner = (position - ((((position + dir) & 1) == 0) ?
 		1 : 0) + MAX_ORIENT) % MAX_ORIENT;
+#ifdef HAVE_OPENGL
+	if (control != 2 && fast != INSTANT && w->dino.dim == 4) {
+		movePiecesGL((DinoGLWidget) w, oldFace, position, dir, style,
+			(control == 1), fast);
+	}
+#endif
 	if (style == CORNER) {
 		moveInsideCorners(w, oldFace, corner, dir);
 	} else if (style == MIDDLE) {
@@ -819,20 +834,29 @@ movePieces(DinoWidget w, int face, int position, int direction, int style)
 			dir = newDirection;
 		}
 	}
+#ifdef HAVE_OPENGL
+	if (!control && fast == INSTANT && w->dino.dim == 4) {
+		drawAllPiecesGL((DinoGLWidget) w);
+	}
+#endif
+#ifdef DEBUG
+	printCube(w);
+#endif
 }
 
 static void
-moveControlCb(DinoWidget w, int face, int position, int direction, int style)
+moveControlCb(DinoWidget w, int face, int position, int direction, int style,
+		int fast)
 {
 	int newFace, newSide, newDirection, corner, newCorner;
 
-	movePieces(w, face, position, direction, style);
-	setPuzzleMove(w, ACTION_CONTROL, face, position, direction, style);
+	movePieces(w, face, position, direction, style, 1, fast);
+	setPuzzleMove(w, ACTION_CONTROL, face, position, direction, style, 1, fast);
 	if (style == CORNER) {
 		newSide = (position + 2) % MAX_ORIENT;
-		movePieces(w, face, newSide, direction, MIDDLE);
+		movePieces(w, face, newSide, direction, MIDDLE, 2, fast);
 		setPuzzleMove(w, ACTION_CONTROL, face, newSide, direction,
-			MIDDLE);
+			MIDDLE, 2, fast);
 		corner = (position - ((((position + direction) & 1) ==
 			0) ? 1 : 0) + MAX_ORIENT) % MAX_ORIENT;
 		newFace = oppCorner[face][corner].face;
@@ -841,14 +865,14 @@ moveControlCb(DinoWidget w, int face, int position, int direction, int style)
 			((face == 1 || face == 3) ? 0 : 1)) & 1) +
 			(((newCorner & 1) == 0) ? 1 : 0);
 		newSide = newCorner;
-		movePieces(w, newFace, newSide, newDirection, CORNER);
+		movePieces(w, newFace, newSide, newDirection, CORNER, 2, fast);
 		setPuzzleMove(w, ACTION_CONTROL, newFace, newSide,
-			newDirection, CORNER);
+			newDirection, CORNER, 2, fast);
 	} else if (style == MIDDLE) {
 		newSide = (position + 2) % MAX_ORIENT;
-		movePieces(w, face, newSide, direction, CORNER);
+		movePieces(w, face, newSide, direction, CORNER, 2, fast);
 		setPuzzleMove(w, ACTION_CONTROL, face, newSide, direction,
-			CORNER);
+			CORNER, 2, fast);
 		corner = (position - ((((position + direction) & 1) ==
 			0) ? 1 : 0) + MAX_ORIENT) % MAX_ORIENT;
 		newCorner = oppCorner[face][corner].rotation;
@@ -860,27 +884,27 @@ moveControlCb(DinoWidget w, int face, int position, int direction, int style)
 		newDirection = 2 * (newDirection / 2) +
 			(((newDirection & 1) == 0) ? 1 : 0);
 		newSide = (newCorner + 2) % MAX_ORIENT;
-		movePieces(w, newFace, newSide, newDirection, CORNER);
+		movePieces(w, newFace, newSide, newDirection, CORNER, 2, fast);
 		setPuzzleMove(w, ACTION_CONTROL, newFace, newSide,
-			newDirection, CORNER);
+			newDirection, CORNER, 2, fast);
 	} else if (style == EDGE) {
 		newSide = (position + 2) % MAX_ORIENT;
-		movePieces(w, face, newSide, direction, EDGE);
+		movePieces(w, face, newSide, direction, EDGE, 2, fast);
 		setPuzzleMove(w, ACTION_CONTROL, face, newSide, direction,
-			EDGE);
+			EDGE, 2, fast);
 	}
 }
 
 void
 movePuzzle(DinoWidget w, int face, int position, int direction, int style,
-		int control)
+		int control, int fast)
 {
 	if (control)
-		moveControlCb(w, face, position, direction, style);
+		moveControlCb(w, face, position, direction, style, fast);
 	else {
-		movePieces(w, face, position, direction, style);
+		movePieces(w, face, position, direction, style, 0, fast);
 		setPuzzleMove(w, ACTION_MOVED, face, position, direction,
-			style);
+			style, 0, fast);
 	}
 #ifdef USE_SOUND
 	if (w->dino.sound) {
@@ -891,6 +915,14 @@ movePuzzle(DinoWidget w, int face, int position, int direction, int style,
 	flushMoves(w, &redo, FALSE);
 }
 
+void
+movePuzzleDelay(DinoWidget w, const int face, const int position,
+		const int direction, const int style, const int control)
+{
+	movePuzzle(w, face, position, direction, style, control, NORMAL);
+	Sleep((unsigned int) w->dino.delay);
+}
+
 static Boolean
 selectPieces(DinoWidget w, int x, int y, int *face, int *position)
 {
@@ -900,6 +932,11 @@ selectPieces(DinoWidget w, int x, int y, int *face, int *position)
 	else if (w->dino.dim == 3)
 		return selectPieces3D((Dino3DWidget) w, x, y,
 			face, position);
+#ifdef HAVE_OPENGL
+	else if (w->dino.dim == 4)
+		return selectPiecesGL((DinoGLWidget) w, x, y,
+			face, position);
+#endif
 	return False;
 }
 
@@ -936,6 +973,10 @@ narrowSelection(DinoWidget w, int *face, int *direction)
 		return narrowSelection2D((Dino2DWidget) w, face, direction);
 	else if (w->dino.dim == 3)
 		return narrowSelection3D((Dino3DWidget) w, face, direction);
+#ifdef HAVE_OPENGL
+	else if (w->dino.dim == 4)
+		return narrowSelectionGL((DinoGLWidget) w, face, direction);
+#endif
 	return False;
 }
 
@@ -967,7 +1008,7 @@ movePuzzleInput(DinoWidget w, int x, int y, int direction, int shift,
 	} else
 		style = getStyle(w, shift, control, alt);
 	control = (control) ? 1 : 0;
-	movePuzzle(w, face, position, direction, style, control);
+	movePuzzle(w, face, position, direction, style, control, NORMAL);
 	if (!control && checkSolved(w)) {
 		setPuzzle(w, ACTION_SOLVED);
 	}
@@ -1090,6 +1131,7 @@ getPieces(DinoWidget w)
 	free(lname);
 	free(fname);
 	w->dino.cheat = True; /* Assume the worst. */
+	setPuzzle(w, ACTION_CHEAT);
 }
 
 static void
@@ -1162,11 +1204,11 @@ undoPieces(DinoWidget w)
 			(direction + MAX_ORIENT / 2) % MAX_ORIENT :
 			5 * MAX_ORIENT - direction;
 		if (control)
-			moveControlCb(w, face, position, direction, style);
+			moveControlCb(w, face, position, direction, style, DOUBLE);
 		else {
-			movePieces(w, face, position, direction, style);
+			movePieces(w, face, position, direction, style, 0, DOUBLE);
 			setPuzzleMove(w, ACTION_UNDO, face, position, direction,
-				style);
+				style, 0, DOUBLE);
 			if (checkSolved(w)) {
 				setPuzzle(w, ACTION_SOLVED);
 			}
@@ -1185,11 +1227,11 @@ redoPieces(DinoWidget w)
 		setMove(&undo,
 			face, position, direction, style, control);
 		if (control)
-			moveControlCb(w, face, position, direction, style);
+			moveControlCb(w, face, position, direction, style, DOUBLE);
 		else {
-			movePieces(w, face, position, direction, style);
+			movePieces(w, face, position, direction, style, 0, DOUBLE);
 			setPuzzleMove(w, ACTION_REDO, face, position, direction,
-				style);
+				style, 0, DOUBLE);
 			if (checkSolved(w)) {
 				setPuzzle(w, ACTION_SOLVED);
 			}
@@ -1216,6 +1258,7 @@ randomizePieces(DinoWidget w)
 	int big = MAX_ORIENT * 3 + NRAND(2);
 
 	w->dino.cheat = False;
+	setPuzzle(w, ACTION_CHEAT);
 	if (w->dino.practice)
 		practicePieces(w);
 	setPuzzle(w, ACTION_RESET);
@@ -1235,7 +1278,7 @@ randomizePieces(DinoWidget w)
 			style = NRAND(3);
 		else
 			style = NRAND(2);
-		movePuzzle(w, face, position, direction, style, FALSE);
+		movePuzzle(w, face, position, direction, style, FALSE, INSTANT);
 	}
 	flushMoves(w, &undo, TRUE);
 	flushMoves(w, &redo, FALSE);
@@ -1250,7 +1293,9 @@ solvePieces(DinoWidget w)
 {
 	if (checkSolved(w))
 		return;
-	{
+	if (w->dino.mode == PERIOD3) {
+		solveSomePieces(w);
+	} else {
 		setPuzzle(w, ACTION_SOLVE_MESSAGE);
 	}
 }
@@ -1303,39 +1348,44 @@ setValuesPuzzle(DinoWidget w)
 	char szBuf[80], buf[20], charbuf[2];
 	int face;
 
-	w->dino.mode = GetPrivateProfileInt(SECTION, "mode",
-		DEFAULT_MODE, INIFILE);
-	w->dino.orient = (BOOL) GetPrivateProfileInt(SECTION, "orient",
-		DEFAULT_ORIENT, INIFILE);
-	w->dino.practice = (BOOL) GetPrivateProfileInt(SECTION, "practice",
-		DEFAULT_PRACTICE, INIFILE);
-	w->dino.dim = GetPrivateProfileInt(SECTION, "dim", 4, INIFILE);
-	w->dino.mono = (BOOL) GetPrivateProfileInt(SECTION, "mono",
-		DEFAULT_MONO, INIFILE);
-	w->dino.reverse = (BOOL) GetPrivateProfileInt(SECTION, "reverseVideo",
-		DEFAULT_REVERSE, INIFILE);
-	/* cyan */
-	(void) GetPrivateProfileString(SECTION, "frameColor", "0 255 255",
-		szBuf, sizeof (szBuf), INIFILE);
+	w->dino.mode = GetPrivateProfileInt(SECTION,
+		"mode", DEFAULT_MODE, INIFILE);
+	w->dino.orient = (BOOL) GetPrivateProfileInt(SECTION,
+		"orient", DEFAULT_ORIENT, INIFILE);
+	w->dino.practice = (BOOL) GetPrivateProfileInt(SECTION,
+		"practice", DEFAULT_PRACTICE, INIFILE);
+#ifdef HAVE_OPENGL
+        w->dino.dim = GetPrivateProfileInt(SECTION, "dim", 4, INIFILE);
+#else
+        w->dino.dim = GetPrivateProfileInt(SECTION, "dim", 3, INIFILE);
+#endif
+	w->dino.view = GetPrivateProfileInt(SECTION, "view", 1, INIFILE);
+	w->dino.mono = (BOOL) GetPrivateProfileInt(SECTION,
+		"mono", DEFAULT_MONO, INIFILE);
+	w->dino.reverse = (BOOL) GetPrivateProfileInt(SECTION,
+		"reverseVideo", DEFAULT_REVERSE, INIFILE);
+	/* Cyan */
+	(void) GetPrivateProfileString(SECTION,
+		"frameColor", "0 255 255", szBuf, sizeof (szBuf), INIFILE);
 	(void) sscanf(szBuf, "%d %d %d",
 		&(color.red), &(color.green), &(color.blue));
 	/* gray25 */
 	w->dino.frameGC = RGB(color.red, color.green, color.blue);
-	(void) GetPrivateProfileString(SECTION, "pieceBorder", "64 64 64",
-		szBuf, sizeof (szBuf), INIFILE);
+	(void) GetPrivateProfileString(SECTION,
+		"pieceBorder", "64 64 64", szBuf, sizeof (szBuf), INIFILE);
 	(void) sscanf(szBuf, "%d %d %d",
 		&(color.red), &(color.green), &(color.blue));
 	w->dino.borderGC = RGB(color.red, color.green, color.blue);
 	/* #AEB2C3 */
-	(void) GetPrivateProfileString(SECTION, "background", "174 178 195",
-		szBuf, sizeof (szBuf), INIFILE);
+	(void) GetPrivateProfileString(SECTION,
+		"background", "174 178 195", szBuf, sizeof (szBuf), INIFILE);
 	(void) sscanf(szBuf, "%d %d %d",
 		&(color.red), &(color.green), &(color.blue));
 	w->dino.inverseGC = RGB(color.red, color.green, color.blue);
 	for (face = 0; face < MAX_FACES; face++) {
 		(void) sprintf(buf, "faceColor%d", face);
-		(void) GetPrivateProfileString(SECTION, buf,
-			faceColorString[face],
+		(void) GetPrivateProfileString(SECTION,
+			buf, faceColorString[face],
 			szBuf, sizeof (szBuf), INIFILE);
 		(void) sscanf(szBuf, "%d %d %d",
 			&(color.red), &(color.green), &(color.blue));
@@ -1344,18 +1394,23 @@ setValuesPuzzle(DinoWidget w)
 		(void) sprintf(buf, "faceChar%d", face);
 		charbuf[0] = faceColorChar[face];
 		charbuf[1] = '\0';
-		(void) GetPrivateProfileString(SECTION, buf, charbuf,
-			szBuf, sizeof (szBuf), INIFILE);
+		(void) GetPrivateProfileString(SECTION,
+			buf, charbuf, szBuf, sizeof (szBuf), INIFILE);
 		w->dino.faceChar[face] = szBuf[0];
 	}
-	(void) GetPrivateProfileString(SECTION, "userName", "Guest",
-		szBuf, sizeof (szBuf), INIFILE);
-	(void) strcpy(w->dino.userName, szBuf);
-		w->dino.userName[80] = 0;
-	(void) GetPrivateProfileString(SECTION, "scoreFile", "",
-		szBuf, sizeof (szBuf), INIFILE);
-	(void) strcpy(w->dino.scoreFile, szBuf);
-		w->dino.scoreFile[80] = 0;
+        w->dino.delay = GetPrivateProfileInt(SECTION,
+		"delay", 10, INIFILE);
+	w->dino.sound = (BOOL) GetPrivateProfileInt(SECTION,
+		"sound", FALSE, INIFILE);
+	(void) GetPrivateProfileString(SECTION,
+                "moveSound", MOVESOUND, szBuf, sizeof (szBuf), INIFILE);
+        (void) strncpy(w->dino.moveSound, szBuf, 80);
+	(void) GetPrivateProfileString(SECTION,
+		"userName", "Guest", szBuf, sizeof (szBuf), INIFILE);
+	(void) strncpy(w->dino.userName, szBuf, 80);
+	(void) GetPrivateProfileString(SECTION,
+		"scoreFile", "", szBuf, sizeof (szBuf), INIFILE);
+	(void) strncpy(w->dino.scoreFile, szBuf, 80);
 }
 
 void
@@ -1414,7 +1469,7 @@ getColor(DinoWidget w, int face)
 	} else {
 		values.background = w->dino.background;
 	}
-	if (!w->dino.mono) {
+	if (!w->dino.mono || w->dino.dim == 4) {
 		if (!w->dino.faceName[face]) {
 			char *buf1;
 
@@ -1422,8 +1477,8 @@ getColor(DinoWidget w, int face)
 			DISPLAY_WARNING(buf1);
 			free(buf1);
 		} else if (XAllocNamedColor(XtDisplay(w),
-				 DefaultColormapOfScreen(XtScreen(w)),
-				 w->dino.faceName[face], &colorCell, &rgb)) {
+				DefaultColormapOfScreen(XtScreen(w)),
+				w->dino.faceName[face], &colorCell, &rgb)) {
 			values.foreground = w->dino.faceColor[face] =
 				colorCell.pixel;
 			if (w->dino.faceGC[face])
@@ -1519,6 +1574,7 @@ setValuesPuzzle(Widget current, Widget request, Widget renew)
 	Boolean redraw = False, setColors = False;
 	int face;
 
+	checkPieces(w);
 	for (face = 0; face < MAX_FACES; face++) {
 		if (strcmp(w->dino.faceName[face], c->dino.faceName[face])) {
 			setColors = True;
@@ -1540,14 +1596,14 @@ setValuesPuzzle(Widget current, Widget request, Widget renew)
 	}
 	if (w->dino.orient != c->dino.orient) {
 		resetPieces(w);
-		redraw = TRUE;
+		redraw = True;
 	} else if (w->dino.practice != c->dino.practice) {
 		resetPieces(w);
-		redraw = TRUE;
+		redraw = True;
 	}
 	if (w->dino.mode != c->dino.mode) {
 		resetPieces(w);
-		redraw = TRUE;
+		redraw = True;
 	}
 
 	if (w->dino.menu != ACTION_IGNORE) {
@@ -1603,12 +1659,18 @@ setValuesPuzzle(Widget current, Widget request, Widget renew)
 		w->dino.currentDirection = IGNORE_DIR;
 	} else if (w->dino.currentDirection == CLEAR_DIR) {
 		resetPieces(w);
-		redraw = TRUE;
+		redraw = True;
 		w->dino.currentDirection = IGNORE_DIR;
 	} else if (w->dino.currentDirection > IGNORE_DIR) {
-		movePieces(w, w->dino.currentFace, w->dino.currentPosition,
-			w->dino.currentDirection, w->dino.style);
+		int face = w->dino.currentFace;
+		int position = w->dino.currentPosition;
+		int direction = w->dino.currentDirection;
+
+		w->dino.currentFace = IGNORE_DIR;
+		w->dino.currentPosition = IGNORE_DIR;
 		w->dino.currentDirection = IGNORE_DIR;
+		movePieces(w, face, position, direction, w->dino.style,
+			w->dino.currentControl, w->dino.currentFast);
 	}
 	return redraw;
 }
@@ -1620,10 +1682,9 @@ destroyPuzzle(Widget old)
 	Display *display = XtDisplay(w);
 	int face;
 
-#if 0
 #if defined( USE_SOUND ) && defined( USE_ESOUND )
-	(void) shutdown_sound();
-#endif
+	if (w->dino.dim == 2)
+		(void) shutdown_sound();
 #endif
 	for (face = 0; face < MAX_FACES; face++)
 		XtReleaseGC(old, w->dino.faceGC[face]);
@@ -1692,10 +1753,9 @@ Widget request, Widget renew
 #ifdef USE_NAS
 	dsp = XtDisplay(w);
 #endif
-#if 0
 #ifdef USE_ESOUND
-	(void) init_sound();
-#endif
+	if (w->dino.dim == 2)
+		(void) init_sound();
 #endif
 #endif
 }
@@ -1727,11 +1787,15 @@ selectPuzzle(DinoWidget w
 	if (selectPieces(w, x, y, &(w->dino.currentFace),
 			&(w->dino.currentPosition))) {
 		if (control || w->dino.practice || !checkSolved(w))
-			drawTriangle(w, w->dino.currentFace,
+			drawTriangleAll(w, w->dino.currentFace,
 				w->dino.currentPosition, TRUE);
 	} else {
 		w->dino.currentFace = IGNORE_DIR;
 		w->dino.currentDirection = IGNORE_DIR;
+#ifdef HAVE_OPENGL
+		if (w->dino.dim == 4)
+			drawAllPiecesGL((DinoGLWidget) w);
+#endif
 	}
 }
 
@@ -1748,7 +1812,7 @@ releasePuzzle(DinoWidget w
 	int x = event->xbutton.x, y = event->xbutton.y;
 	int shift = (int) (event->xbutton.state & (ShiftMask | LockMask));
 	int control = (int) (event->xkey.state & ControlMask);
-	int alt = (int) (event->xkey.state & Mod1Mask);
+	int alt = (int) (event->xkey.state & (Mod1Mask | Mod3Mask | Mod4Mask | Mod5Mask));
 #endif
 	int style, face, position, count = -1;
 	int direction = -1;
@@ -1784,19 +1848,28 @@ releasePuzzle(DinoWidget w
 				count = 0;
 		}
 		if (count == 1) {
-			movePuzzle(w, w->dino.currentFace,
-				w->dino.currentPosition, direction,
-				style, (control) ? 1 : 0);
+			face = w->dino.currentFace;
+			position = w->dino.currentPosition;
+			w->dino.currentFace = IGNORE_DIR;
+			w->dino.currentPosition = IGNORE_DIR;
+			movePuzzle(w, face, position, direction,
+				style, (control) ? 1 : 0, NORMAL);
 			if (!control && checkSolved(w)) {
 				setPuzzle(w, ACTION_SOLVED);
 			}
 		} else if (count == 2) {
 			setPuzzle(w, ACTION_AMBIGUOUS);
-		} else if (count == 0)
+		} else if (count == 0) {
 			moveNoPieces(w);
+		}
 	}
 	w->dino.currentFace = IGNORE_DIR;
 	w->dino.currentDirection = IGNORE_DIR;
+#ifdef HAVE_OPENGL
+	if (w->dino.dim == 4 && count != 1) {
+		drawAllPiecesGL((DinoGLWidget) w);
+	}
+#endif
 }
 
 #ifndef WINVER
@@ -1943,7 +2016,7 @@ orientizePuzzle(DinoWidget w
 
 #ifndef WINVER
 void
-period2modePuzzle(DinoWidget w
+period2ModePuzzle(DinoWidget w
 , XEvent *event, char **args, int nArgs
 )
 {
@@ -1951,7 +2024,7 @@ period2modePuzzle(DinoWidget w
 }
 
 void
-period3modePuzzle(DinoWidget w
+period3ModePuzzle(DinoWidget w
 , XEvent *event, char **args, int nArgs
 )
 {
@@ -1959,7 +2032,7 @@ period3modePuzzle(DinoWidget w
 }
 
 void
-bothmodePuzzle(DinoWidget w
+bothModePuzzle(DinoWidget w
 , XEvent *event, char **args, int nArgs
 )
 {
@@ -2031,7 +2104,7 @@ leavePuzzle(DinoWidget w
 
 #ifdef WINVER
 void
-periodmodePuzzle(DinoWidget w, const int mode)
+periodModePuzzle(DinoWidget w, const int mode)
 {
 	setPuzzle(w, mode + ACTION_PERIOD2);
 }
