@@ -1,7 +1,7 @@
 /*
  * @(#)Dino.h
  *
- * Copyright 1995 - 2008  David A. Bagley, bagleyd@tux.org
+ * Copyright 1995 - 2010  David A. Bagley, bagleyd@tux.org
  *
  * All rights reserved.
  *
@@ -57,6 +57,8 @@
 #define XtNpos ((char *) "position")
 #define XtNdirection ((char *) "direction")
 #define XtNstyle ((char *) "style")
+#define XtNcontrol ((char *) "control")
+#define XtNfast ((char *) "fast")
 #define XtNpixmapSize ((char *) "pixmapSize")
 #define XtNselectCallback ((char *) "selectCallback")
 #define XtCMono ((char *) "Mono")
@@ -74,6 +76,8 @@
 #define XtCPos ((char *) "Position")
 #define XtCDirection ((char *) "Direction")
 #define XtCStyle ((char *) "Style")
+#define XtCControl ((char *) "Control")
+#define XtCFast ((char *) "Fast")
 #define XtCPixmapSize ((char *) "PixmapSize")
 
 typedef struct _DinoClassRec *DinoWidgetClass;
@@ -84,6 +88,8 @@ typedef struct {
 	XEvent     *event;
 	int         reason;
 	int         face, position, direction, style;
+	Boolean     control;
+	int         fast;
 } dinoCallbackStruct;
 #endif
 
@@ -114,6 +120,7 @@ typedef struct {
 #define ACTION_SOUND 209
 #define ACTION_VIEW 210
 #define ACTION_DIM 211
+#define ACTION_CHEAT 212
 #define ACTION_TR 300
 #define ACTION_BR 301
 #define ACTION_BL 302
