@@ -1,7 +1,7 @@
 /*
  * @(#)Dino2d.c
  *
- * Copyright 1995 - 2008  David A. Bagley, bagleyd@tux.org
+ * Copyright 1995 - 2009  David A. Bagley, bagleyd@tux.org
  *
  * All rights reserved.
  *
@@ -142,9 +142,9 @@ static XtActionsRec actionsList2D[] =
 	{(char *) "Solve", (XtActionProc) solvePuzzle},
 	{(char *) "Practice", (XtActionProc) practicePuzzle},
 	{(char *) "Orientize", (XtActionProc) orientizePuzzle},
-	{(char *) "Period2", (XtActionProc) period2modePuzzle},
-	{(char *) "Period3", (XtActionProc) period3modePuzzle},
-	{(char *) "Both", (XtActionProc) bothmodePuzzle},
+	{(char *) "Period2", (XtActionProc) period2ModePuzzle},
+	{(char *) "Period3", (XtActionProc) period3ModePuzzle},
+	{(char *) "Both", (XtActionProc) bothModePuzzle},
 	{(char *) "View", (XtActionProc) viewPuzzle},
 	{(char *) "Speed", (XtActionProc) speedUpPuzzle},
 	{(char *) "Slow", (XtActionProc) slowDownPuzzle},
@@ -175,7 +175,7 @@ static XtResource resources2D[] =
 	 XtRString, (caddr_t) "#AEB2C3" /*XtDefaultBackground*/},
 	{XtNframeColor, XtCColor, XtRPixel, sizeof (Pixel),
 	 XtOffset(DinoWidget, dino.frameColor),
-	 XtRString, (caddr_t) "cyan" /*XtDefaultForeground*/},
+	 XtRString, (caddr_t) "Cyan" /*XtDefaultForeground*/},
 	{XtNfaceColor0, XtCLabel, XtRString, sizeof (String),
 	 XtOffset(DinoWidget, dino.faceName[0]),
 	 XtRString, (caddr_t) "Red"},
@@ -251,6 +251,12 @@ static XtResource resources2D[] =
 	{XtNstyle, XtCStyle, XtRInt, sizeof (int),
 	 XtOffset(DinoWidget, dino.style),
 	 XtRString, (caddr_t) "-1"},
+	{XtNcontrol, XtCControl, XtRInt, sizeof (int),
+	 XtOffset(DinoWidget, dino.currentControl),
+	 XtRString, (caddr_t) "0"},
+	{XtNfast, XtCFast, XtRInt, sizeof (int),
+	 XtOffset(DinoWidget, dino.currentFast),
+	 XtRString, (caddr_t) "1"},
 	{XtNpixmapSize, XtCPixmapSize, XtRInt, sizeof (int),
 	 XtOffset(DinoWidget, dino.pixmapSize),
 	 XtRString, (caddr_t) "64"},
@@ -704,7 +710,7 @@ movePuzzle2DTl(Dino2DWidget w, XEvent *event, char **args, int nArgs)
 	movePuzzleInput((DinoWidget) w, event->xbutton.x, event->xbutton.y, TL,
 		(int) (event->xkey.state & (ShiftMask | LockMask)),
 		(int) (event->xkey.state & ControlMask),
-		(int) (event->xkey.state & Mod1Mask));
+		(int) (event->xkey.state & (Mod1Mask | Mod3Mask | Mod4Mask | Mod5Mask)));
 }
 
 static void
@@ -713,7 +719,7 @@ movePuzzle2DTop(Dino2DWidget w, XEvent *event, char **args, int nArgs)
 	movePuzzleInput((DinoWidget) w, event->xbutton.x, event->xbutton.y, TOP,
 		(int) (event->xkey.state & (ShiftMask | LockMask)),
 		(int) (event->xkey.state & ControlMask),
-		(int) (event->xkey.state & Mod1Mask));
+		(int) (event->xkey.state & (Mod1Mask | Mod3Mask | Mod4Mask | Mod5Mask)));
 }
 
 static void
@@ -722,7 +728,7 @@ movePuzzle2DTr(Dino2DWidget w, XEvent *event, char **args, int nArgs)
 	movePuzzleInput((DinoWidget) w, event->xbutton.x, event->xbutton.y, TR,
 		(int) (event->xkey.state & (ShiftMask | LockMask)),
 		(int) (event->xkey.state & ControlMask),
-		(int) (event->xkey.state & Mod1Mask));
+		(int) (event->xkey.state & (Mod1Mask | Mod3Mask | Mod4Mask | Mod5Mask)));
 }
 
 static void
@@ -731,7 +737,7 @@ movePuzzle2DLeft(Dino2DWidget w, XEvent *event, char **args, int nArgs)
 	movePuzzleInput((DinoWidget) w, event->xbutton.x, event->xbutton.y, LEFT,
 		(int) (event->xkey.state & (ShiftMask | LockMask)),
 		(int) (event->xkey.state & ControlMask),
-		(int) (event->xkey.state & Mod1Mask));
+		(int) (event->xkey.state & (Mod1Mask | Mod3Mask | Mod4Mask | Mod5Mask)));
 }
 
 static void
@@ -740,7 +746,7 @@ movePuzzle2DRight(Dino2DWidget w, XEvent *event, char **args, int nArgs)
 	movePuzzleInput((DinoWidget) w, event->xbutton.x, event->xbutton.y, RIGHT,
 		(int) (event->xkey.state & (ShiftMask | LockMask)),
 		(int) (event->xkey.state & ControlMask),
-		(int) (event->xkey.state & Mod1Mask));
+		(int) (event->xkey.state & (Mod1Mask | Mod3Mask | Mod4Mask | Mod5Mask)));
 }
 
 static void
@@ -749,7 +755,7 @@ movePuzzle2DBl(Dino2DWidget w, XEvent *event, char **args, int nArgs)
 	movePuzzleInput((DinoWidget) w, event->xbutton.x, event->xbutton.y, BL,
 		(int) (event->xkey.state & (ShiftMask | LockMask)),
 		(int) (event->xkey.state & ControlMask),
-		(int) (event->xkey.state & Mod1Mask));
+		(int) (event->xkey.state & (Mod1Mask | Mod3Mask | Mod4Mask | Mod5Mask)));
 }
 
 static void
@@ -758,7 +764,7 @@ movePuzzle2DBottom(Dino2DWidget w, XEvent *event, char **args, int nArgs)
 	movePuzzleInput((DinoWidget) w, event->xbutton.x, event->xbutton.y, BOTTOM,
 		(int) (event->xkey.state & (ShiftMask | LockMask)),
 		(int) (event->xkey.state & ControlMask),
-		(int) (event->xkey.state & Mod1Mask));
+		(int) (event->xkey.state & (Mod1Mask | Mod3Mask | Mod4Mask | Mod5Mask)));
 }
 
 static void
@@ -767,6 +773,6 @@ movePuzzle2DBr(Dino2DWidget w, XEvent *event, char **args, int nArgs)
 	movePuzzleInput((DinoWidget) w, event->xbutton.x, event->xbutton.y, BR,
 		(int) (event->xkey.state & (ShiftMask | LockMask)),
 		(int) (event->xkey.state & ControlMask),
-		(int) (event->xkey.state & Mod1Mask));
+		(int) (event->xkey.state & (Mod1Mask | Mod3Mask | Mod4Mask | Mod5Mask)));
 }
 #endif
