@@ -1,7 +1,7 @@
 /*
  * @(#)Dino3d.c
  *
- * Copyright 1995 - 2008  David A. Bagley, bagleyd@tux.org
+ * Copyright 1995 - 2009  David A. Bagley, bagleyd@tux.org
  *
  * All rights reserved.
  *
@@ -62,6 +62,7 @@ static char translations3D[] =
  <KeyPress>0x3C: Slow()\n\
  <KeyPress>0x2C: Slow()\n\
  Shift<KeyPress>2: Sound()\n\
+ <KeyPress>F11: MoveCcw()\n\
  <KeyPress>KP_Divide: MoveCcw()\n\
  <KeyPress>R5: MoveCcw()\n\
  <KeyPress>Home: MoveTl()\n\
@@ -80,6 +81,7 @@ static char translations3D[] =
  <KeyPress>KP_Left: MoveLeft()\n\
  <KeyPress>KP_4: MoveLeft()\n\
  <KeyPress>R10: MoveLeft()\n\
+ <KeyPress>F12: MoveCw()\n\
  <KeyPress>Begin: MoveCw()\n\
  <KeyPress>KP_5: MoveCw()\n\
  <KeyPress>R11: MoveCw()\n\
@@ -152,9 +154,9 @@ static XtActionsRec actionsList3D[] =
 	{(char *) "Solve", (XtActionProc) solvePuzzle},
 	{(char *) "Practice", (XtActionProc) practicePuzzle},
 	{(char *) "Orientize", (XtActionProc) orientizePuzzle},
-	{(char *) "Period2", (XtActionProc) period2modePuzzle},
-	{(char *) "Period3", (XtActionProc) period3modePuzzle},
-	{(char *) "Both", (XtActionProc) bothmodePuzzle},
+	{(char *) "Period2", (XtActionProc) period2ModePuzzle},
+	{(char *) "Period3", (XtActionProc) period3ModePuzzle},
+	{(char *) "Both", (XtActionProc) bothModePuzzle},
 	{(char *) "View", (XtActionProc) viewPuzzle},
 	{(char *) "Speed", (XtActionProc) speedUpPuzzle},
 	{(char *) "Slow", (XtActionProc) slowDownPuzzle},
@@ -185,7 +187,7 @@ static XtResource resources3D[] =
 	 XtRString, (caddr_t) "#AEB2C3" /*XtDefaultBackground*/},
 	{XtNframeColor, XtCColor, XtRPixel, sizeof (Pixel),
 	 XtOffset(DinoWidget, dino.frameColor),
-	 XtRString, (caddr_t) "cyan" /*XtDefaultForeground*/},
+	 XtRString, (caddr_t) "Cyan" /*XtDefaultForeground*/},
 	{XtNfaceColor0, XtCLabel, XtRString, sizeof (String),
 	 XtOffset(DinoWidget, dino.faceName[0]),
 	 XtRString, (caddr_t) "Red"},
@@ -261,6 +263,12 @@ static XtResource resources3D[] =
 	{XtNstyle, XtCStyle, XtRInt, sizeof (int),
 	 XtOffset(DinoWidget, dino.style),
 	 XtRString, (caddr_t) "-1"},
+	{XtNcontrol, XtCControl, XtRInt, sizeof (int),
+	 XtOffset(DinoWidget, dino.currentControl),
+	 XtRString, (caddr_t) "0"},
+	{XtNfast, XtCFast, XtRInt, sizeof (int),
+	 XtOffset(DinoWidget, dino.currentFast),
+	 XtRString, (caddr_t) "1"},
 	{XtNpixmapSize, XtCPixmapSize, XtRInt, sizeof (int),
 	 XtOffset(DinoWidget, dino.pixmapSize),
 	 XtRString, (caddr_t) "64"},
@@ -545,7 +553,8 @@ drawTriangle3D(Dino3DWidget w, int face, int position, int offset)
 			borderGC = w->dino.inverseGC;
 		}
 		DRAWTEXT(w, dr, borderGC,
-			letterX + w->dino.letterOffset.x, letterY + w->dino.letterOffset.y,
+			letterX + w->dino.letterOffset.x,
+			letterY + w->dino.letterOffset.y,
 			buf, 1);
 	}
 	if (w->dino.orient) {
@@ -956,7 +965,7 @@ narrowSelection3D(Dino3DWidget w, int *face, int *direction)
 			else if (*face == 4)
 				*direction = (*direction + 2) % MAX_ORIENT +
 					2 * MAX_ORIENT;
-			if (*face == 5)
+			else if (*face == 5)
 				*direction = (*direction + 2) % MAX_ORIENT;
 		}
 		break;
@@ -1127,7 +1136,7 @@ movePuzzle3DTl(Dino3DWidget w, XEvent *event, char **args, int nArgs)
 	movePuzzleInput((DinoWidget) w, event->xbutton.x, event->xbutton.y, TL,
 		(int) (event->xkey.state & (ShiftMask | LockMask)),
 		(int) (event->xkey.state & ControlMask),
-		(int) (event->xkey.state & Mod1Mask));
+		(int) (event->xkey.state & (Mod1Mask | Mod3Mask | Mod4Mask | Mod5Mask)));
 }
 
 static void
@@ -1136,7 +1145,7 @@ movePuzzle3DTop(Dino3DWidget w, XEvent *event, char **args, int nArgs)
 	movePuzzleInput((DinoWidget) w, event->xbutton.x, event->xbutton.y, TOP,
 		(int) (event->xkey.state & (ShiftMask | LockMask)),
 		(int) (event->xkey.state & ControlMask),
-		(int) (event->xkey.state & Mod1Mask));
+		(int) (event->xkey.state & (Mod1Mask | Mod3Mask | Mod4Mask | Mod5Mask)));
 }
 
 static void
@@ -1145,7 +1154,7 @@ movePuzzle3DTr(Dino3DWidget w, XEvent *event, char **args, int nArgs)
 	movePuzzleInput((DinoWidget) w, event->xbutton.x, event->xbutton.y, TR,
 		(int) (event->xkey.state & (ShiftMask | LockMask)),
 		(int) (event->xkey.state & ControlMask),
-		(int) (event->xkey.state & Mod1Mask));
+		(int) (event->xkey.state & (Mod1Mask | Mod3Mask | Mod4Mask | Mod5Mask)));
 }
 
 static void
@@ -1154,7 +1163,7 @@ movePuzzle3DLeft(Dino3DWidget w, XEvent *event, char **args, int nArgs)
 	movePuzzleInput((DinoWidget) w, event->xbutton.x, event->xbutton.y, LEFT,
 		(int) (event->xkey.state & (ShiftMask | LockMask)),
 		(int) (event->xkey.state & ControlMask),
-		(int) (event->xkey.state & Mod1Mask));
+		(int) (event->xkey.state & (Mod1Mask | Mod3Mask | Mod4Mask | Mod5Mask)));
 }
 
 static void
@@ -1163,7 +1172,7 @@ movePuzzle3DCw(Dino3DWidget w, XEvent *event, char **args, int nArgs)
 	movePuzzleInput((DinoWidget) w, event->xbutton.x, event->xbutton.y, CW,
 		(int) (event->xkey.state & (ShiftMask | LockMask)),
 		(int) (event->xkey.state & ControlMask),
-		(int) (event->xkey.state & Mod1Mask));
+		(int) (event->xkey.state & (Mod1Mask | Mod3Mask | Mod4Mask | Mod5Mask)));
 }
 
 static void
@@ -1172,7 +1181,7 @@ movePuzzle3DRight(Dino3DWidget w, XEvent *event, char **args, int nArgs)
 	movePuzzleInput((DinoWidget) w, event->xbutton.x, event->xbutton.y, RIGHT,
 		(int) (event->xkey.state & (ShiftMask | LockMask)),
 		(int) (event->xkey.state & ControlMask),
-		(int) (event->xkey.state & Mod1Mask));
+		(int) (event->xkey.state & (Mod1Mask | Mod3Mask | Mod4Mask | Mod5Mask)));
 }
 
 static void
@@ -1181,7 +1190,7 @@ movePuzzle3DBl(Dino3DWidget w, XEvent *event, char **args, int nArgs)
 	movePuzzleInput((DinoWidget) w, event->xbutton.x, event->xbutton.y, BL,
 		(int) (event->xkey.state & (ShiftMask | LockMask)),
 		(int) (event->xkey.state & ControlMask),
-		(int) (event->xkey.state & Mod1Mask));
+		(int) (event->xkey.state & (Mod1Mask | Mod3Mask | Mod4Mask | Mod5Mask)));
 }
 
 static void
@@ -1190,7 +1199,7 @@ movePuzzle3DBottom(Dino3DWidget w, XEvent *event, char **args, int nArgs)
 	movePuzzleInput((DinoWidget) w, event->xbutton.x, event->xbutton.y, BOTTOM,
 		(int) (event->xkey.state & (ShiftMask | LockMask)),
 		(int) (event->xkey.state & ControlMask),
-		(int) (event->xkey.state & Mod1Mask));
+		(int) (event->xkey.state & (Mod1Mask | Mod3Mask | Mod4Mask | Mod5Mask)));
 }
 
 static void
@@ -1199,7 +1208,7 @@ movePuzzle3DBr(Dino3DWidget w, XEvent *event, char **args, int nArgs)
 	movePuzzleInput((DinoWidget) w, event->xbutton.x, event->xbutton.y, BR,
 		(int) (event->xkey.state & (ShiftMask | LockMask)),
 		(int) (event->xkey.state & ControlMask),
-		(int) (event->xkey.state & Mod1Mask));
+		(int) (event->xkey.state & (Mod1Mask | Mod3Mask | Mod4Mask | Mod5Mask)));
 }
 
 static void
@@ -1208,6 +1217,6 @@ movePuzzle3DCcw(Dino3DWidget w, XEvent *event, char **args, int nArgs)
 	movePuzzleInput((DinoWidget) w, event->xbutton.x, event->xbutton.y, CCW,
 		(int) (event->xkey.state & (ShiftMask | LockMask)),
 		(int) (event->xkey.state & ControlMask),
-		(int) (event->xkey.state & Mod1Mask));
+		(int) (event->xkey.state & (Mod1Mask | Mod3Mask | Mod4Mask | Mod5Mask)));
 }
 #endif
