@@ -1,7 +1,7 @@
 /*
  * @(#)DinoP.h
  *
- * Copyright 1995 - 2008  David A. Bagley, bagleyd@tux.org
+ * Copyright 1995 - 2010  David A. Bagley, bagleyd@tux.org
  *
  * All rights reserved.
  *
@@ -33,12 +33,12 @@ extern void resizePuzzle(DinoWidget w);
 extern void sizePuzzle(DinoWidget w);
 extern void initializePuzzle(DinoWidget w, HBRUSH brush);
 extern void exposePuzzle(DinoWidget w);
-extern void periodmodePuzzle(DinoWidget w, const int mode);
+extern void periodModePuzzle(DinoWidget w, const int mode);
 extern void dimPuzzle(DinoWidget w);
 extern int  movePuzzleDir(DinoWidget w, const int direction);
 extern void setPuzzle(DinoWidget w, int reason);
 extern void setPuzzleMove(DinoWidget w, int reason, int face, int position,
-	int direction, int style);
+	int direction, int style, int control, int fast);
 
 #else
 
@@ -82,6 +82,10 @@ extern void quitPuzzle(DinoWidget w, XEvent *event, char **args, int nArgs);
 #define EDGE 2
 #define FACE 3
 
+#define NORMAL 1
+#define DOUBLE 2
+#define INSTANT 3
+
 typedef struct _DinoCornerLoc {
 	int         face, rotation;
 } DinoCornerLoc;
@@ -112,7 +116,8 @@ typedef struct _DinoPart {
 	DinoCornerLoc faceLoc[MAX_ORIENT];
 	DinoCornerLoc rowLoc[MAX_ORIENT][MAX_ORIENT];
 	DinoCornerLoc spindleLoc[MAX_ROTATE][2];
-	int         currentFace, currentPosition, currentDirection;
+	int         currentFace, currentPosition, currentDirection, currentFast;
+	int         currentControl;
 	Boolean     started, cheat, sound;
 	Boolean     practice, orient, vertical, mono, reverse, focus;
 	Boolean     scoreOnly, versionOnly;
@@ -147,7 +152,7 @@ typedef struct _DinoRec {
 } DinoRec;
 
 typedef struct _RowNext {
-	int         face, direction, side_face;
+	int         face, direction, sideFace;
 } RowNext;
 
 extern void hidePuzzle(
@@ -261,27 +266,26 @@ extern void leavePuzzle(DinoWidget w
 #endif
 );
 #ifndef WINVER
-extern void period2modePuzzle(DinoWidget w
+extern void period2ModePuzzle(DinoWidget w
 , XEvent *event, char **args, int nArgs
 );
-extern void period3modePuzzle(DinoWidget w
+extern void period3ModePuzzle(DinoWidget w
 , XEvent *event, char **args, int nArgs
 );
-extern void bothmodePuzzle(DinoWidget w
+extern void bothModePuzzle(DinoWidget w
 , XEvent *event, char **args, int nArgs
 );
 #endif
 
 extern void movePuzzleInput(DinoWidget w, int x, int y, int direction, int shift,
 	int control, int alt);
+extern void setPuzzle(DinoWidget w, int reason);
 extern void movePuzzle(DinoWidget w, int face, int position, int direction,
-	int style, int control);
+	int style, int control, int speed);
+extern void movePuzzleDelay(DinoWidget w,
+	int face, int position, int direction, int style, int control);
 extern void setAllColors(DinoWidget w);
-#if 0
-/* For future auto-solver */
-extern void solvePieces(DinoWidget w);
-
-#endif
+extern void solveSomePieces(DinoWidget w);
 extern void drawAllPieces(DinoWidget w);
 extern Boolean checkSolved(DinoWidget w);
 extern void newMoves(DinoStack *s);
