@@ -1,7 +1,7 @@
 /*
  * @(#)xdino.c
  *
- * Copyright 1995 - 2009  David A. Bagley, bagleyd@tux.org
+ * Copyright 1995 - 2010  David A. Bagley, bagleyd@tux.org
  *
  * All rights reserved.
  *
@@ -21,8 +21,9 @@
 /* Driver file for Dino */
 
 #ifndef WINVER
+#include "version.h"
 static const char aboutHelp[] = {
-"Dino Version 7.5\n"
+"Dino Version " VERSION "\n"
 "Send bugs (reports or fixes) to the author: "
 "David Bagley <bagleyd@tux.org>\n"
 "The latest version is at: "
@@ -81,8 +82,8 @@ static const char featuresHelp[] = {
 "\n"
 "Press \"C\" or \"c\" keys to clear the puzzle.\n"
 "\n"
-"\"S\" or \"s\" keys reserved for the auto-solver "
-"(not implemented).\n"
+"\"S\" or \"s\" keys to start auto-solver.  Only works for "
+"Period 3 mode.\n"
 "\n"
 "Press \"O\" or \"o\" keys to toggle the orient mode.  One "
 "has to orient the faces in orient mode, besides\n"
@@ -97,11 +98,9 @@ static const char featuresHelp[] = {
 "\n"
 "Press \"V\" or \"v\" keys to change the view of the cube.\n"
 "\n"
-"Press \">\" or \".\" keys to speed up the movement of pieces "
-"(not implemented).\n"
+"Press \">\" or \".\" keys to speed up the movement of pieces.\n"
 "\n"
-"Press \"<\" or \",\" keys to slow down the movement of pieces "
-"(not implemented).\n"
+"Press \"<\" or \",\" keys to slow down the movement of pieces.\n"
 "\n"
 "Press \"@\" key to toggle the sound.\n"
 "\n"
@@ -145,7 +144,7 @@ static const char referencesHelp[] = {
 #endif
 
 static const char solveHelp[] = {
-"Auto-solver: sorry, not implemented."
+"Auto-solver: sorry, only implemented for Period 3 mode."
 };
 
 #include "file.h"
@@ -176,6 +175,7 @@ static DinoRec widget;
 #include <Xm/MessageB.h>
 #include <Xm/PushBG.h>
 #include <Xm/CascadeB.h>
+#include <Xm/Scale.h>
 #include <Xm/ToggleB.h>
 #include <Xm/ToggleBG.h>
 #ifdef MOUSEBITMAPS
@@ -189,9 +189,10 @@ static DinoRec widget;
 #define SET_STARTED(w,b) XtVaSetValues(w, XtNstart, b, NULL)
 #include "Dino.h"
 #include "Dino2d.h"
-#include "Dino3d.h"
 #ifdef HAVE_OPENGL
 #include "DinoGL.h"
+#else
+#include "Dino3d.h"
 #endif
 #ifdef HAVE_XPM
 #include <X11/xpm.h>
@@ -259,7 +260,10 @@ static char progDsp[PROGRAM_NAME_LENGTH] = TITLE;
 static char userNameDsp[USER_NAME_LENGTH] = "Guest";
 #else
 #ifdef HAVE_MOTIF
-static Widget movesText, recordText, message, modes[MAX_MODES];
+#define MIN_SPEED 1
+#define MAX_SPEED 50
+static Widget movesText, recordText, message;
+static Widget modes[MAX_MODES], speedSlider;
 static Widget orientizeSwitch, practiceSwitch;
 static char buff[21];
 static const char *modeString[] =
@@ -272,15 +276,9 @@ static Widget solveDialog, practiceDialog, randomizeDialog;
 static Arg arg[3];
 #else
 static Widget shell;
-#ifdef HAVE_OPENGL
-static Widget shellGL;
-#endif
 #endif
 static Pixmap pixmap = None;
 static Widget topLevel, puzzle2d, puzzle3d;
-#ifdef HAVE_OPENGL
-static Widget puzzleGL;
-#endif
 static char *progDsp;
 static char userNameDsp[USER_NAME_LENGTH] = "";
 
@@ -406,6 +404,7 @@ writeRecords(void)
 		char lockFile[FILE_NAME_LENGTH];
 
 		(void) strncpy(lockFile, fileName, FILE_NAME_LENGTH - 6);
+		lockFile[FILE_NAME_LENGTH - 6] = '\0';
 		(void) strcat(lockFile, ".lock");
 		while (((lfd = open(lockFile, O_CREAT | O_EXCL, 0644)) < 0) &&
 				errno == EEXIST)
@@ -460,7 +459,7 @@ printRecord(int mode, Boolean orient, Boolean practice)
  * but I do not know it off hand. */
 static void
 makeEquivalent(String *userName, String *scoreFile, int *mode,
-		Boolean *orient, Boolean *practice)
+		Boolean *orient, Boolean *practice, int *delay)
 {
 	Boolean mono, reverse;
 	Boolean scoreOnly, versionOnly;
@@ -475,6 +474,7 @@ makeEquivalent(String *userName, String *scoreFile, int *mode,
 		XtNpractice, practice,
 		XtNmono, &mono,
 		XtNreverseVideo, &reverse,
+		XtNdelay, delay,
 		XtNforeground, &foreground,
 		XtNbackground, &background,
 		XtNpieceBorder, &pieceBorder,
@@ -508,6 +508,7 @@ makeEquivalent(String *userName, String *scoreFile, int *mode,
 		XtNpractice, *practice,
 		XtNmono, mono,
 		XtNreverseVideo, reverse,
+		XtNdelay, *delay,
 		XtNdirection, IGNORE_DIR,
 		XtNstart, False,
 		XtNforeground, foreground,
@@ -519,25 +520,6 @@ makeEquivalent(String *userName, String *scoreFile, int *mode,
 		XtNfaceColor3, faceColor[3],
 		XtNfaceColor4, faceColor[4],
 		XtNfaceColor5, faceColor[5], NULL);
-#ifdef HAVE_OPENGL
-	XtVaSetValues(puzzleGL,
-		XtNuserName, *userName,
-		XtNorient, *orient,
-		XtNpractice, *practice,
-		XtNmono, mono,
-		XtNreverseVideo, reverse,
-		XtNdirection, IGNORE_DIR,
-		XtNstart, False,
-		XtNforeground, foreground,
-		XtNbackground, background,
-		XtNpieceBorder, pieceBorder,
-		XtNfaceColor0, faceColor[0],
-		XtNfaceColor1, faceColor[1],
-		XtNfaceColor2, faceColor[2],
-		XtNfaceColor3, faceColor[3],
-		XtNfaceColor4, faceColor[4],
-		XtNfaceColor5, faceColor[5], NULL);
-#endif
 }
 #endif
 
@@ -570,11 +552,6 @@ printStatus(char *msg, int nMoves
 #ifdef WINVER
 	SetWindowText(widget.core.hWnd, (LPSTR) titleDsp);
 #else
-#ifdef HAVE_OPENGL
-	if (dim == 4)
-		XtVaSetValues(XtParent(puzzleGL), XtNtitle, titleDsp, NULL);
-	else
-#endif
 	XtVaSetValues(XtParent((dim == 2) ? puzzle2d : puzzle3d),
 		XtNtitle, titleDsp, NULL);
 #endif
@@ -633,11 +610,15 @@ void
 	if (strcmp(scoreFile, ""))
 		(void) strncpy(scoreFileName, scoreFile, FILE_NAME_LENGTH);
 #else
-	makeEquivalent(&userName, &scoreFile, &mode, &orient, &practice);
+	int delay;
+
+	makeEquivalent(&userName, &scoreFile, &mode,
+		&orient, &practice, &delay);
 #ifdef HAVE_MOTIF
 	XmToggleButtonSetState(modes[mode - PERIOD2], True, False);
 	XmToggleButtonSetState(orientizeSwitch, orient, True);
 	XmToggleButtonSetState(practiceSwitch, practice, True);
+	XmScaleSetValue(speedSlider, MAX_SPEED + MIN_SPEED - delay - 1);
 #endif
 #endif
 	initRecords();
@@ -674,9 +655,10 @@ void
 	printStatus(messageDsp, movesDsp);
 #else
 	printStatus(messageDsp, movesDsp, 2, mode);
-	printStatus(messageDsp, movesDsp, 3, mode);
 #ifdef HAVE_OPENGL
 	printStatus(messageDsp, movesDsp, 4, mode);
+#else
+	printStatus(messageDsp, movesDsp, 3, mode);
 #endif
 #endif
 #endif
@@ -696,53 +678,32 @@ puzzleListener(Widget w, caddr_t clientData, dinoCallbackStruct *callData)
 	int dim = 0;
 #else
 	int reason = callData->reason;
-	Widget otherw1 = (Widget) NULL;
-#ifdef HAVE_OPENGL
-	Widget otherw2 = (Widget) NULL;
-#endif
+	Widget otherw = (Widget) NULL;
 #ifndef HAVE_MOTIF
-	int dim = 0, otherdim1 = 0;
-#ifdef HAVE_OPENGL
-	int otherdim2 = 0;
-#endif
+	int dim = 0, otherdim = 0;
 #endif
 
 	if (w == puzzle2d) {
-		otherw1 = puzzle3d;
-#ifdef HAVE_OPENGL
-		otherw2 = puzzleGL;
-#endif
+		otherw = puzzle3d;
 #ifndef HAVE_MOTIF
 		dim = 2;
-		otherdim1 = 3;
 #ifdef HAVE_OPENGL
-		otherdim2 = 4;
+		otherdim = 4;
+#else
+		otherdim = 3;
 #endif
 #endif
 	} else if (w == puzzle3d) {
-		otherw1 = puzzle2d;
-#ifdef HAVE_OPENGL
-		otherw2 = puzzleGL;
-#endif
+		otherw = puzzle2d;
 #ifndef HAVE_MOTIF
-		dim = 3;
-		otherdim1 = 2;
+		otherdim = 2;
 #ifdef HAVE_OPENGL
-		otherdim2 = 4;
-#endif
-#endif
-	}
-#ifdef HAVE_OPENGL
-	else if (w == puzzleGL) {
-		otherw1 = puzzle2d;
-		otherw2 = puzzle3d;
-#ifndef HAVE_MOTIF
 		dim = 4;
-		otherdim1 = 2;
-		otherdim2 = 3;
+#else
+		dim = 3;
+#endif
 #endif
 	}
-#endif
 #endif
 	(void) strcpy(messageDsp, "");
 #ifdef WINVER
@@ -772,11 +733,6 @@ puzzleListener(Widget w, caddr_t clientData, dinoCallbackStruct *callData)
 		(void) XIconifyWindow(XtDisplay(shell),
 			XtWindow(shell),
 			XScreenNumberOfScreen(XtScreen(shell)));
-#ifdef HAVE_OPENGL
-		(void) XIconifyWindow(XtDisplay(shellGL),
-			XtWindow(shellGL),
-			XScreenNumberOfScreen(XtScreen(shellGL)));
-#endif
 #endif
 #endif
 		break;
@@ -819,11 +775,7 @@ puzzleListener(Widget w, caddr_t clientData, dinoCallbackStruct *callData)
 		movesDsp = 0;
 		randomized = False;
 #ifndef WINVER
-#ifdef HAVE_OPENGL
-		XtVaSetValues(otherw2,
-			XtNdirection, RESTORE_DIR, NULL);
-#endif
-		XtVaSetValues(otherw1,
+		XtVaSetValues(otherw,
 			XtNdirection, RESTORE_DIR, NULL);
 		XtVaSetValues(w,
 			XtNdirection, RESTORE_DIR, NULL);
@@ -833,11 +785,7 @@ puzzleListener(Widget w, caddr_t clientData, dinoCallbackStruct *callData)
 		movesDsp = 0;
 		randomized = False;
 #ifndef WINVER
-#ifdef HAVE_OPENGL
-		XtVaSetValues(otherw2,
-			XtNdirection, CLEAR_DIR, NULL);
-#endif
-		XtVaSetValues(otherw1,
+		XtVaSetValues(otherw,
 			XtNdirection, CLEAR_DIR, NULL);
 		XtVaSetValues(w,
 			XtNdirection, CLEAR_DIR, NULL);
@@ -862,35 +810,24 @@ puzzleListener(Widget w, caddr_t clientData, dinoCallbackStruct *callData)
 #ifndef WINVER
 	case ACTION_MOVED:
 		movesDsp++;
-#ifdef HAVE_OPENGL
-		XtVaSetValues(otherw2,
+		XtVaSetValues(otherw,
 			XtNstart, True,
 			XtNface, callData->face,
 			XtNpos, callData->position,
 			XtNdirection, callData->direction,
-			XtNstyle, callData->style, NULL);
-#endif
-		XtVaSetValues(otherw1,
-			XtNstart, True,
-			XtNface, callData->face,
-			XtNpos, callData->position,
-			XtNdirection, callData->direction,
-			XtNstyle, callData->style, NULL);
+			XtNstyle, callData->style,
+			XtNcontrol, callData->control,
+			XtNfast, callData->fast, NULL);
 		SET_STARTED(w, True);
 		break;
 	case ACTION_CONTROL:
-#ifdef HAVE_OPENGL
-		XtVaSetValues(otherw2,
+		XtVaSetValues(otherw,
 			XtNface, callData->face,
 			XtNpos, callData->position,
 			XtNdirection, callData->direction,
-			XtNstyle, callData->style, NULL);
-#endif
-		XtVaSetValues(otherw1,
-			XtNface, callData->face,
-			XtNpos, callData->position,
-			XtNdirection, callData->direction,
-			XtNstyle, callData->style, NULL);
+			XtNstyle, callData->style,
+			XtNcontrol, callData->control,
+			XtNfast, callData->fast, NULL);
 		break;
 #endif
 	case ACTION_SOLVED:
@@ -907,20 +844,14 @@ puzzleListener(Widget w, caddr_t clientData, dinoCallbackStruct *callData)
 				MESSAGE_LENGTH);
 		SET_STARTED(w, False);
 #ifndef WINVER
-#ifdef HAVE_OPENGL
-		SET_STARTED(otherw2, False);
-#endif
-		SET_STARTED(otherw1, False);
+		SET_STARTED(otherw, False);
 #endif
 		randomized = False;
 		break;
 	case ACTION_COMPUTED:
 		SET_STARTED(w, False);
 #ifndef WINVER
-#ifdef HAVE_OPENGL
-		SET_STARTED(otherw2, False);
-#endif
-		SET_STARTED(otherw1, False);
+		SET_STARTED(otherw, False);
 #endif
 		break;
 	case ACTION_PRACTICE:
@@ -938,12 +869,7 @@ puzzleListener(Widget w, caddr_t clientData, dinoCallbackStruct *callData)
 		XtVaSetValues(w,
 			XtNpractice, practice,
 			XtNstart, False, NULL);
-#ifdef HAVE_OPENGL
-		XtVaSetValues(otherw2,
-			XtNpractice, practice,
-			XtNstart, False, NULL);
-#endif
-		XtVaSetValues(otherw1,
+		XtVaSetValues(otherw,
 			XtNpractice, practice,
 			XtNstart, False, NULL);
 #ifdef HAVE_MOTIF
@@ -961,12 +887,7 @@ puzzleListener(Widget w, caddr_t clientData, dinoCallbackStruct *callData)
 		XtVaSetValues(w,
 			XtNpractice, False,
 			XtNstart, False, NULL);
-#ifdef HAVE_OPENGL
-		XtVaSetValues(otherw2,
-			XtNpractice, False,
-			XtNstart, False, NULL);
-#endif
-		XtVaSetValues(otherw1,
+		XtVaSetValues(otherw,
 			XtNpractice, False,
 			XtNstart, False, NULL);
 #endif
@@ -979,14 +900,14 @@ puzzleListener(Widget w, caddr_t clientData, dinoCallbackStruct *callData)
 #ifdef WINVER
 			view = w->dino.view;
 #else
-			XtVaGetValues(puzzleGL,
+			XtVaGetValues(puzzle3d,
 				XtNview, &view, NULL);
 #endif
 			view = (view + 1) % (2 * MAX_VIEWS);
 #ifdef WINVER
 			w->dino.view = view;
 #else
-			XtVaSetValues(puzzleGL,
+			XtVaSetValues(puzzle3d,
 				XtNview, view, NULL);
 #endif
 		}
@@ -1001,11 +922,7 @@ puzzleListener(Widget w, caddr_t clientData, dinoCallbackStruct *callData)
 #else
 		XtVaSetValues(w,
 			XtNorient, orient, NULL);
-#ifdef HAVE_OPENGL
-		XtVaSetValues(otherw2,
-			XtNorient, orient, NULL);
-#endif
-		XtVaSetValues(otherw1,
+		XtVaSetValues(otherw,
 			XtNorient, orient, NULL);
 #ifdef HAVE_MOTIF
 		XmToggleButtonSetState(orientizeSwitch, orient, True);
@@ -1023,11 +940,7 @@ puzzleListener(Widget w, caddr_t clientData, dinoCallbackStruct *callData)
 #else
 		XtVaSetValues(w,
 			XtNmode, mode, NULL);
-#ifdef HAVE_OPENGL
-		XtVaSetValues(otherw2,
-			XtNmode, mode, NULL);
-#endif
-		XtVaSetValues(otherw1,
+		XtVaSetValues(otherw,
 			XtNmode, mode, NULL);
 #ifdef HAVE_MOTIF
 		XmToggleButtonSetState(modes[mode - PERIOD2], True, True);
@@ -1037,35 +950,19 @@ puzzleListener(Widget w, caddr_t clientData, dinoCallbackStruct *callData)
 #ifndef WINVER
 	case ACTION_UNDO:
 		movesDsp--;
-#ifdef HAVE_OPENGL
-		XtVaSetValues(otherw2,
+		XtVaSetValues(otherw,
 			XtNstart, True,
 			XtNface, callData->face,
 			XtNpos, callData->position,
 			XtNdirection, callData->direction,
 			XtNstyle, callData->style, NULL);
-#endif
-		XtVaSetValues(otherw1,
-			XtNstart, True,
-			XtNface, callData->face,
-			XtNpos, callData->position,
-			XtNdirection, callData->direction,
-			XtNstyle, callData->style, NULL);
-		SET_STARTED(w, False);
+		SET_STARTED(w, True);
 		break;
 #endif
 #ifndef WINVER
 	case ACTION_REDO:
 		movesDsp++;
-#ifdef HAVE_OPENGL
-		XtVaSetValues(otherw2,
-			XtNstart, True,
-			XtNface, callData->face,
-			XtNpos, callData->position,
-			XtNdirection, callData->direction,
-			XtNstyle, callData->style, NULL);
-#endif
-		XtVaSetValues(otherw1,
+		XtVaSetValues(otherw,
 			XtNstart, True,
 			XtNface, callData->face,
 			XtNpos, callData->position,
@@ -1078,13 +975,23 @@ puzzleListener(Widget w, caddr_t clientData, dinoCallbackStruct *callData)
 	case ACTION_DIM:
 		dim++;
 #ifdef HAVE_OPENGL
-		if (dim > 4)
+		if (dim == 3)
+			dim = 4;
+		else if (dim > 4)
 #else
 		if (dim > 3)
 #endif
 			dim = 2;
 		w->dino.dim = dim;
 		break;
+#endif
+#ifndef WINVER
+	case ACTION_CHEAT:
+		XtVaSetValues(w,
+			XtNcheat, cheat, NULL);
+		XtVaSetValues(otherw,
+			XtNcheat, cheat, NULL);
+		break;
 #endif
 	}
 #ifdef WINVER
@@ -1094,10 +1001,7 @@ puzzleListener(Widget w, caddr_t clientData, dinoCallbackStruct *callData)
 	printStatus(messageDsp, movesDsp);
 #else
 	printStatus(messageDsp, movesDsp, dim, mode);
-	printStatus(messageDsp, movesDsp, otherdim1, mode);
-#ifdef HAVE_OPENGL
-	printStatus(messageDsp, movesDsp, otherdim2, mode);
-#endif
+	printStatus(messageDsp, movesDsp, otherdim, mode);
 #endif
 #endif
 }
@@ -1105,7 +1009,7 @@ puzzleListener(Widget w, caddr_t clientData, dinoCallbackStruct *callData)
 #ifdef WINVER
 void
 setPuzzleMove(DinoWidget w, int reason, int face, int position, int direction,
-		int style)
+		int style, int control, int fast)
 {
 	int mode;
 	/* Boolean orient, practice, cheat; */
@@ -1444,7 +1348,7 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 		case ACTION_PERIOD2:
 		case ACTION_PERIOD3:
 		case ACTION_BOTH:
-			periodmodePuzzle(&widget,
+			periodModePuzzle(&widget,
 				(int) LOWORD(wParam) - ACTION_PERIOD2);
 			sizePuzzle(&widget);
 			(void) InvalidateRect(hWnd, NULL, TRUE);
@@ -1586,7 +1490,8 @@ static XrmOptionDescRec options[] =
 
 #ifdef HAVE_MOTIF
 static void
-puzzlePracticeListener(Widget w, XtPointer clientData, XmAnyCallbackStruct *cbs)
+puzzlePracticeListener(Widget w, XtPointer clientData,
+		XmAnyCallbackStruct *cbs)
 {
 	if (cbs->reason == XmCR_OK) {
 		XtVaSetValues(puzzle2d, XtNmenu, ACTION_PRACTICE, NULL);
@@ -1594,7 +1499,8 @@ puzzlePracticeListener(Widget w, XtPointer clientData, XmAnyCallbackStruct *cbs)
 }
 
 static void
-puzzleRandomizeListener(Widget w, XtPointer clientData, XmAnyCallbackStruct *cbs)
+puzzleRandomizeListener(Widget w, XtPointer clientData,
+		XmAnyCallbackStruct *cbs)
 {
 	if (cbs->reason == XmCR_OK) {
 		XtVaSetValues(puzzle2d, XtNmenu, ACTION_RANDOMIZE, NULL);
@@ -1613,10 +1519,6 @@ modeToggle(Widget w, int mode, XmToggleButtonCallbackStruct *cbs)
 			XtNmode, mode + PERIOD2, NULL);
 		XtVaSetValues(puzzle3d,
 			XtNmode, mode + PERIOD2, NULL);
-#ifdef HAVE_OPENGL
-		XtVaSetValues(puzzleGL,
-			XtNmode, mode + PERIOD2, NULL);
-#endif
 		movesDsp = 0;
 		(void) sprintf(buff, "%d", movesDsp);
 		printState(movesText, buff);
@@ -1627,7 +1529,8 @@ modeToggle(Widget w, int mode, XmToggleButtonCallbackStruct *cbs)
 }
 
 static void
-orientToggle(Widget w, XtPointer clientData, XmToggleButtonCallbackStruct *cbs)
+orientToggle(Widget w, XtPointer clientData,
+		XmToggleButtonCallbackStruct *cbs)
 {
 	int mode;
 	Boolean orient = cbs->set, practice;
@@ -1639,10 +1542,6 @@ orientToggle(Widget w, XtPointer clientData, XmToggleButtonCallbackStruct *cbs)
 		XtNorient, orient, NULL);
 	XtVaSetValues(puzzle3d,
 		XtNorient, orient, NULL);
-#ifdef HAVE_OPENGL
-	XtVaSetValues(puzzleGL,
-		XtNorient, orient, NULL);
-#endif
 	movesDsp = 0;
 	(void) sprintf(buff, "%d", movesDsp);
 	printState(movesText, buff);
@@ -1664,11 +1563,6 @@ practiceToggle(Widget w, XtPointer clientData,
 	XtVaSetValues(puzzle3d,
 		XtNpractice, practice,
 		XtNstart, False, NULL);
-#ifdef HAVE_OPENGL
-	XtVaSetValues(puzzleGL,
-		XtNpractice, practice,
-		XtNstart, False, NULL);
-#endif
 	XtVaGetValues(puzzle2d,
 		XtNmode, &mode,
 		XtNpractice, &orient, NULL);
@@ -1683,6 +1577,20 @@ practiceToggle(Widget w, XtPointer clientData,
 	printState(message, messageDsp);
 }
 
+static void
+speedChangeListener(Widget w, XtPointer clientData,
+		XmScaleCallbackStruct *cbs)
+{
+	int delay = MAX_SPEED + MIN_SPEED - cbs->value - 1, oldDelay;
+
+	XtVaGetValues(puzzle2d,
+		XtNdelay, &oldDelay, NULL);
+	if (oldDelay != delay) {
+		XtVaSetValues(puzzle3d, XtNdelay, delay, NULL);
+		XtVaSetValues(puzzle2d, XtNdelay, delay, NULL);
+	}
+}
+
 static void
 fileMenuListener(Widget w, void *value, void *clientData)
 {
@@ -1844,7 +1752,7 @@ main(int argc, char **argv)
 	clearString = XmStringCreateSimple((char *) "Clear");
 	practiceString = XmStringCreateSimple((char *) "Practice");
 	randomizeString = XmStringCreateSimple((char *) "Randomize");
-	solveString = XmStringCreateSimple((char *) "(Auto-solve)");
+	solveString = XmStringCreateSimple((char *) "Auto-solve");
 	orientizeString = XmStringCreateSimple((char *) "Orientize");
 	speedString = XmStringCreateSimple((char *) "Speed >");
 	slowString = XmStringCreateSimple((char *) "Slow <");
@@ -1931,7 +1839,7 @@ main(int argc, char **argv)
 		XmNseparatorOn, False,
 		XmNsashWidth, 1,
 		XmNsashHeight, 1, NULL);
-	movesRowCol = XtVaCreateManagedWidget("Rowcol",
+	movesRowCol = XtVaCreateManagedWidget("movesRowcol",
 		xmRowColumnWidgetClass, controlPanel,
 		XmNnumColumns, 2,
 		XmNorientation, XmHORIZONTAL,
@@ -2019,6 +1927,16 @@ main(int argc, char **argv)
 		XmNset, DEFAULT_PRACTICE, NULL);
 	XtAddCallback(practiceSwitch, XmNvalueChangedCallback,
 		(XtCallbackProc) practiceToggle, (XtPointer) NULL);
+	speedSlider = XtVaCreateManagedWidget("speedSlider",
+		xmScaleWidgetClass, switchRowCol,
+		XtVaTypedArg, XmNtitleString, XmRString, "Animation Speed", 16,
+		XmNminimum, MIN_SPEED,
+		XmNmaximum, MAX_SPEED,
+		XmNvalue, MAX_SPEED - 10,
+		XmNshowValue, True,
+		XmNorientation, XmHORIZONTAL, NULL);
+	XtAddCallback(speedSlider, XmNvalueChangedCallback,
+		(XtCallbackProc) speedChangeListener, (XtPointer) NULL);
 	messageRowCol = XtVaCreateManagedWidget("messageRowCol",
 		xmRowColumnWidgetClass, controlPanel,
 		XmNnumColumns, 1,
@@ -2032,30 +1950,28 @@ main(int argc, char **argv)
 		XtNheight, 200, NULL);
 	XtAddCallback(puzzle2d, XtNselectCallback,
 		(XtCallbackProc) puzzleListener, (XtPointer) NULL);
+#ifdef HAVE_OPENGL
+	puzzle3d = XtCreateManagedWidget("dino",
+		dinoGLWidgetClass, mainPanel, NULL, 0);
+#else
 	puzzle3d = XtCreateManagedWidget("dino",
 		dino3dWidgetClass, mainPanel, NULL, 0);
+#endif
 	XtVaSetValues(puzzle3d,
 		XtNheight, 200, NULL);
-#ifdef HAVE_OPENGL
-	puzzleGL = XtCreateManagedWidget("dino",
-		dinoGLWidgetClass, mainPanel, NULL, 0);
-	XtVaSetValues(puzzleGL,
-		XtNheight, 200, NULL);
-#endif
 #else
 	shell = XtCreateApplicationShell(argv[0],
 		topLevelShellWidgetClass, NULL, 0);
-#ifdef HAVE_OPENGL
-	shellGL = XtCreateApplicationShell(argv[0],
-		topLevelShellWidgetClass, NULL, 0);
-#endif
 	puzzle2d = XtCreateManagedWidget("dino",
 		dino2dWidgetClass, topLevel, NULL, 0);
+	XtAddCallback(puzzle2d, XtNselectCallback,
+		(XtCallbackProc) puzzleListener, (XtPointer) NULL);
+#ifdef HAVE_OPENGL
+	puzzle3d = XtCreateManagedWidget("dino",
+		dinoGLWidgetClass, shell, NULL, 0);
+#else
 	puzzle3d = XtCreateManagedWidget("dino",
 		dino3dWidgetClass, shell, NULL, 0);
-#ifdef HAVE_OPENGL
-	puzzleGL = XtCreateManagedWidget("dino",
-		dinoGLWidgetClass, shellGL, NULL, 0);
 #endif
 #endif
 	XtVaGetValues(puzzle2d,
@@ -2097,22 +2013,10 @@ main(int argc, char **argv)
 #endif
 	XtAddCallback(puzzle3d, XtNselectCallback,
 		(XtCallbackProc) puzzleListener, (XtPointer) NULL);
-#ifdef HAVE_OPENGL
-#ifndef HAVE_MOTIF
-	XtVaSetValues(shellGL,
-		XtNinput, True,
-		XtNiconPixmap, pixmap, NULL);
-#endif
-	XtAddCallback(puzzleGL, XtNselectCallback,
-		(XtCallbackProc) puzzleListener, (XtPointer) NULL);
-#endif
 	initialize();
 	XtRealizeWidget(topLevel);
 #ifndef HAVE_MOTIF
 	XtRealizeWidget(shell);
-#ifdef HAVE_OPENGL
-	XtRealizeWidget(shellGL);
-#endif
 #endif
 	XGrabButton(XtDisplay(puzzle2d), (unsigned int) AnyButton, AnyModifier,
 		XtWindow(puzzle2d), TRUE, (unsigned int) (ButtonPressMask |
@@ -2124,13 +2028,6 @@ main(int argc, char **argv)
 		ButtonMotionMask | ButtonReleaseMask),
 		GrabModeAsync, GrabModeAsync, XtWindow(puzzle3d),
 		XCreateFontCursor(XtDisplay(puzzle3d), XC_hand2));
-#ifdef HAVE_OPENGL
-	XGrabButton(XtDisplay(puzzleGL), (unsigned int) AnyButton, AnyModifier,
-		XtWindow(puzzleGL), TRUE, (unsigned int) (ButtonPressMask |
-		ButtonMotionMask | ButtonReleaseMask),
-		GrabModeAsync, GrabModeAsync, XtWindow(puzzleGL),
-		XCreateFontCursor(XtDisplay(puzzleGL), XC_crosshair));
-#endif
 	XtMainLoop();
 
 #ifdef VMS
