@@ -1,7 +1,7 @@
 /*
  * @(#)Hexagons.c
  *
- * Copyright 1994 - 2008  David A. Bagley, bagleyd@tux.org
+ * Copyright 1994 - 2010  David A. Bagley, bagleyd@tux.org
  *
  * All rights reserved.
  *
@@ -2573,21 +2573,21 @@ setValuesPuzzle(HexagonsWidget w)
 	} color;
 	char szBuf[80];
 
-	w->hexagons.sizeX = GetPrivateProfileInt(SECTION, "sizeX",
-		DEFAULT_TILESX, INIFILE);
-	w->hexagons.sizeY = GetPrivateProfileInt(SECTION, "sizeY",
-		DEFAULT_TILESY, INIFILE);
-	w->hexagons.base = GetPrivateProfileInt(SECTION, "base",
-		DEFAULT_BASE, INIFILE);
-	w->hexagons.corners = (BOOL) GetPrivateProfileInt(SECTION, "corners",
-		DEFAULT_CORNERS, INIFILE);
-	w->hexagons.mono = (BOOL) GetPrivateProfileInt(SECTION, "mono",
-		DEFAULT_MONO, INIFILE);
+	w->hexagons.sizeX = GetPrivateProfileInt(SECTION,
+		"sizeX", DEFAULT_TILESX, INIFILE);
+	w->hexagons.sizeY = GetPrivateProfileInt(SECTION,
+		"sizeY", DEFAULT_TILESY, INIFILE);
+	w->hexagons.base = GetPrivateProfileInt(SECTION,
+		"base", DEFAULT_BASE, INIFILE);
+	w->hexagons.corners = (BOOL) GetPrivateProfileInt(SECTION,
+		"corners", DEFAULT_CORNERS, INIFILE);
+	w->hexagons.mono = (BOOL) GetPrivateProfileInt(SECTION,
+		"mono", DEFAULT_MONO, INIFILE);
 	w->hexagons.reverse = (BOOL) GetPrivateProfileInt(SECTION,
 		"reverseVideo", DEFAULT_REVERSE, INIFILE);
 	/* gray75 */
-	(void) GetPrivateProfileString(SECTION, "tileColor", "191 191 191",
-		szBuf, sizeof (szBuf), INIFILE);
+	(void) GetPrivateProfileString(SECTION,
+		"tileColor", "191 191 191", szBuf, sizeof (szBuf), INIFILE);
 	(void) sscanf(szBuf, "%d %d %d",
 		&(color.red), &(color.green), &(color.blue));
 	w->hexagons.tileGC[1] = RGB(color.red, color.green, color.blue);
@@ -2596,14 +2596,14 @@ setValuesPuzzle(HexagonsWidget w)
         w->hexagons.tileGC[2] = RGB(darker(color.red),
 	       darker(color.green), darker(color.blue));
 	/* gray25 */
-	(void) GetPrivateProfileString(SECTION, "textColor", "64 64 64",
-		szBuf, sizeof (szBuf), INIFILE);
+	(void) GetPrivateProfileString(SECTION,
+		"textColor", "64 64 64", szBuf, sizeof (szBuf), INIFILE);
 	(void) sscanf(szBuf, "%d %d %d",
 		&(color.red), &(color.green), &(color.blue));
 	w->hexagons.textGC = RGB(color.red, color.green, color.blue);
 	/* #AEB2C3 */
-	(void) GetPrivateProfileString(SECTION, "background", "174 178 195",
-		szBuf, sizeof (szBuf), INIFILE);
+	(void) GetPrivateProfileString(SECTION,
+		"background", "174 178 195", szBuf, sizeof (szBuf), INIFILE);
 	(void) sscanf(szBuf, "%d %d %d",
 		&(color.red), &(color.green), &(color.blue));
 	w->hexagons.inverseGC[1] = RGB(color.red, color.green, color.blue);
@@ -2616,14 +2616,19 @@ setValuesPuzzle(HexagonsWidget w)
         w->hexagons.inverseGC[4] = RGB(darker(darker(darker(color.red))),
 	       darker(darker(darker(color.green))),
 	       darker(darker(darker(color.blue))));
-	(void) GetPrivateProfileString(SECTION, "userName", "Guest",
-		szBuf, sizeof (szBuf), INIFILE);
-	(void) strcpy(w->hexagons.userName, szBuf);
-	w->hexagons.userName[80] = 0;
-	(void) GetPrivateProfileString(SECTION, "scoreFile", "",
-		szBuf, sizeof (szBuf), INIFILE);
-	(void) strcpy(w->hexagons.scoreFile, szBuf);
-	w->hexagons.scoreFile[80] = 0;
+        w->hexagons.delay = GetPrivateProfileInt(SECTION,
+		"delay", 10, INIFILE);
+	w->hexagons.sound = (BOOL) GetPrivateProfileInt(SECTION,
+		"sound", FALSE, INIFILE);
+	(void) GetPrivateProfileString(SECTION,
+                "bumpSound", BUMPSOUND, szBuf, sizeof (szBuf), INIFILE);
+        (void) strncpy(w->hexagons.bumpSound, szBuf, 80);
+	(void) GetPrivateProfileString(SECTION,
+		"userName", "Guest", szBuf, sizeof (szBuf), INIFILE);
+	(void) strncpy(w->hexagons.userName, szBuf, 80);
+	(void) GetPrivateProfileString(SECTION,
+		"scoreFile", "", szBuf, sizeof (szBuf), INIFILE);
+	(void) strncpy(w->hexagons.scoreFile, szBuf, 80);
 }
 
 void
@@ -2866,10 +2871,8 @@ destroyPuzzle(Widget old)
 	Display *display = XtDisplay(w);
 	int i;
 
-#if 0
 #if defined( USE_SOUND ) && defined( USE_ESOUND )
 	(void) shutdown_sound();
-#endif
 #endif
 	XtReleaseGC(old, w->hexagons.textGC);
 	for (i = 0; i < FG_SHADES; i++)
@@ -3120,12 +3123,10 @@ Widget request, Widget renew
 #ifdef USE_NAS
 	dsp = XtDisplay(w);
 #endif
-#if 0
 #ifdef USE_ESOUND
 	(void) init_sound();
 #endif
 #endif
-#endif
 }
 
 #ifndef WINVER
