@@ -1,7 +1,7 @@
 /*
  * @(#)Mball.h
  *
- * Copyright 1994 - 2008  David A. Bagley, bagleyd@tux.org
+ * Copyright 1994 - 2010  David A. Bagley, bagleyd@tux.org
  *
  * All rights reserved.
  *
@@ -49,10 +49,11 @@
 #define XtNsound ((char *) "sound")
 #define XtNmoveSound ((char *) "moveSound")
 #define XtNwedges ((char *) "wedges")
-#define XtNrings ((char *) "rings")
+#define XtNbands ((char *) "bands")
 #define XtNorient ((char *) "orient")
 #define XtNpractice ((char *) "practice")
 #define XtNbase ((char *) "base")
+#define XtNperspective ((char *) "perspective")
 #define XtNuserName ((char *) "userName")
 #define XtNscoreFile ((char *) "scoreFile")
 #define XtNscoreOnly ((char *) "scoreOnly")
@@ -67,10 +68,11 @@
 #define XtCSound ((char *) "Sound")
 #define XtCMoveSound ((char *) "MoveSound")
 #define XtCWedges ((char *) "Wedges")
-#define XtCRings ((char *) "Rings")
+#define XtCBands ((char *) "Bands")
 #define XtCOrient ((char *) "Orient")
 #define XtCPractice ((char *) "Practice")
 #define XtCBase ((char *) "Base")
+#define XtCPerspective ((char *) "Perspective")
 #define XtCUserName ((char *) "UserName")
 #define XtCScoreFile ((char *) "ScoreFile")
 #define XtCMenu ((char *) "Menu")
@@ -110,15 +112,16 @@ typedef struct {
 #define ACTION_INCREMENT 206
 #define ACTION_DECREMENT 207
 #define ACTION_ORIENTIZE 208
-#define ACTION_WEDGE2 209
-#define ACTION_WEDGE4 210
-#define ACTION_WEDGE6 211
-#define ACTION_WEDGE8 212
-#define ACTION_WEDGE10 213
-#define ACTION_WEDGE12 214
-#define ACTION_SPEED 215
-#define ACTION_SLOW 216
-#define ACTION_SOUND 217
+#define ACTION_SPEED 209
+#define ACTION_SLOW 210
+#define ACTION_SOUND 211
+#define ACTION_PERSPECTIVE 212
+#define ACTION_WEDGE2 213
+#define ACTION_WEDGE4 214
+#define ACTION_WEDGE6 215
+#define ACTION_WEDGE8 216
+#define ACTION_WEDGE10 217
+#define ACTION_WEDGE12 218
 #define ACTION_TOP 300
 #define ACTION_TTR 301
 #define ACTION_TR 302
@@ -155,11 +158,12 @@ typedef struct {
 
 #define MIN_WEDGES 2
 #define MAX_WEDGES 12
-#define MIN_RINGS 1
+#define MIN_BANDS 1
 #define DEFAULT_WEDGES 8
-#define DEFAULT_RINGS 4
+#define DEFAULT_BANDS 4
 #define DEFAULT_ORIENT FALSE
 #define DEFAULT_PRACTICE TRUE
+#define DEFAULT_PERSPECTIVE FALSE
 #ifdef MONOTEST
 #define DEFAULT_MONO TRUE
 #else
