@@ -1,7 +1,7 @@
 /*
  * @(#)xmball.c
  *
- * Copyright 1994 - 2009  David A. Bagley, bagleyd@tux.org
+ * Copyright 1994 - 2010  David A. Bagley, bagleyd@tux.org
  *
  * All rights reserved.
  *
@@ -21,8 +21,9 @@
 /* Driver file for Mball */
 
 #ifndef WINVER
+#include "version.h"
 static const char aboutHelp[] = {
-"Mball Version 7.5\n"
+"Mball Version " VERSION "\n"
 "Send bugs (reports or fixes) to the author: "
 "David Bagley <bagleyd@tux.org>\n"
 "The latest version is at: "
@@ -36,16 +37,17 @@ static const char optionsHelp[] = {
 "[-wedge{0|1|2|3|4|5|6|7|8|9|10|11} {color}]\n"
 "[-{border|bd} {color}] [-delay msecs] [-[no]sound]\n"
 "[-moveSound {filename}] [-{font|fn} {fontname}]\n"
-"[-wedges {int}] [-ring {int}] [-[no]orient]\n"
-"[-[no]practice] [-base {int}] [-userName {string}]\n"
-"[-scoreFile {filename}] [-scores] [-version]"
+"[-[no]perspective] [-wedges {int}] [-band {int}]\n"
+"[-[no]orient] [-[no]practice] [-base {int}]\n"
+"[-userName {string}] [-scoreFile {filename}]\n"
+"[-scores] [-version]"
 };
 #endif
 
 #if defined(HAVE_MOTIF) || defined(WINVER)
 static const char descriptionHelp[] = {
-"The original puzzle has 8 sectors on a sphere "
-"(longitudinal cuts), with each sector divided into 4 segments\n"
+"The original puzzle has 8 wedges on a sphere "
+"(longitudinal cuts), with each wedge divided into 4 bands\n"
 "(latitudinal cuts).  There are essentially 3 varieties: "
 "Geomaster 8 colors (beachball, default colors in this\n"
 "puzzle), Duomaster 2 colors (black and white beachball), "
@@ -59,7 +61,11 @@ static const char descriptionHelp[] = {
 "be arranged in 355,682,548,566,633,480,192,000,000 different "
 "possible combinations.  Masterball was invented by Dr.\n"
 "Geza Gyovai Hungarian Engineer, manufactured by Whole "
-"Systems Design, Inc.."
+"Systems Design, Inc..\n"
+"\n"
+"Related puzzles are the Saturn Puzzle, an oriented Masterball "
+"with one band, and the harder Hockey Puck Puzzle, like\n"
+"the Saturn Puzzle but with 12 wedges instead of 8."
 };
 
 static const char featuresHelp[] = {
@@ -67,7 +73,9 @@ static const char featuresHelp[] = {
 "\"mouse-left\" button on a piece and the pieces will\n"
 "then turn towards where the mouse button was released.  "
 "Usually, a click and release on the same wedge is\n"
-"ambiguous and the puzzle will not turn.\n"
+"ambiguous and the puzzle will not turn.  If there is "
+"some ambiguity between a turn or a flip, a flip is\n"
+"assumed, except if shift key is used.\n"
 "\n"
 "Click \"mouse-center\" button, or press \"P\" or \"p\" "
 "keys, to toggle the practice mode (in practice mode the\n"
@@ -88,8 +96,8 @@ static const char featuresHelp[] = {
 "\n"
 "Press \"C\" or \"c\" keys to clear the puzzle.\n"
 "\n"
-"\"S\" or \"s\" keys reserved for the auto-solver "
-"(not implemented).\n"
+"\"S\" or \"s\" keys to start auto-solver.  Only works for "
+"wedges <= 8 or 1 band.\n"
 "\n"
 "Press \"O\" or \"o\" keys to toggle the orient mode.  One "
 "has to orient the wedges in orient mode, besides\n"
@@ -97,9 +105,9 @@ static const char featuresHelp[] = {
 "one has to get the numbers to be on the same side\n"
 "of the ball in clockwise order.\n"
 "\n"
-"Press \"I\" or \"i\" keys to increase the number of rings.\n"
+"Press \"I\" or \"i\" keys to increase the number of bands.\n"
 "\n"
-"Press \"D\" or \"d\" keys to decrease the number of rings.\n"
+"Press \"D\" or \"d\" keys to decrease the number of bands.\n"
 "\n"
 "Press \"2\", \"4\", \"6\", \"8\", \"0\", or \"=\" keys "
 "(not the keypad 2, 4, 6, 8, 0) to change to 2, 4, 6, 8, 10,\n"
@@ -107,11 +115,11 @@ static const char featuresHelp[] = {
 "number of wedges, there would be no 180 degree turn and\n"
 "therefore the puzzle would be inoperable.\n"
 "\n"
-"Press \">\" or \".\" keys to speed up the movement of pieces "
-"(not implemented).\n"
+"Press \"T\" or \"t\" keys to toggle the perspective look.\n"
 "\n"
-"Press \"<\" or \",\" keys to slow down the movement of pieces "
-"(not implemented).\n"
+"Press \">\" or \".\" keys to speed up the movement of pieces.\n"
+"\n"
+"Press \"<\" or \",\" keys to slow down the movement of pieces.\n"
 "\n"
 "Press \"@\" key to toggle the sound.\n"
 "\n"
@@ -139,7 +147,7 @@ static const char referencesHelp[] = {
 #endif
 
 static const char solveHelp[] = {
-"Auto-solver: sorry, not implemented."
+"Auto-solver: sorry, only implemented for wedges <= 8 or 1 band."
 };
 
 #include "file.h"
@@ -220,7 +228,7 @@ static MballRec widget;
 #define SCOREFILE "mball.scores"
 #endif
 
-#define MAX_RINGS 6
+#define MAX_BANDS 6
 #define NEVER (-1)
 #define FILE_NAME_LENGTH 1024
 #define USER_NAME_LENGTH 120
@@ -235,14 +243,17 @@ typedef struct {
 } PuzzleRecord;
 
 static PuzzleRecord puzzleRecord[2][(MAX_WEDGES - MIN_WEDGES) / 2 + 1]
-[MAX_RINGS - MIN_RINGS + 1];
+[MAX_BANDS - MIN_BANDS + 1];
 static int movesDsp = 0;
 static char messageDsp[MESSAGE_LENGTH] = "Welcome";
 static char recordDsp[MESSAGE_LENGTH] = "NOT RECORDED";
 
 #ifdef HAVE_MOTIF
+#define MIN_SPEED 1
+#define MAX_SPEED 50
+#define MULTSPEED 20
 static Widget movesText, recordText, message, orientizeSwitch, practiceSwitch;
-static Widget wedge[(MAX_WEDGES - MIN_WEDGES) / 2 + 1], ringSlider;
+static Widget wedge[(MAX_WEDGES - MIN_WEDGES) / 2 + 1], bandSlider, speedSlider;
 static char buff[21];
 static const char *wedgeString[] =
 {
@@ -287,10 +298,10 @@ printRecords(void)
 	int i, j, orient;
 
 	(void) printf("              MBALL  HALL OF FAME\n\n");
-	(void) printf("ORIENT WEDGE RING USER            MOVES\n");
+	(void) printf("ORIENT WEDGE BAND USER            MOVES\n");
 	for (orient = 0; orient < 2; orient++)
 		for (i = 0; i < (MAX_WEDGES - MIN_WEDGES) / 2 + 1; i++)
-			for (j = 0; j < MAX_RINGS - MIN_RINGS + 1; j++) {
+			for (j = 0; j < MAX_BANDS - MIN_BANDS + 1; j++) {
 				if (puzzleRecord[orient][i][j].score > 0)
 					(void) printf("%6d%6d%5d %-12s%9d\n",
 						orient, 2 * i + 1, j + 1,
@@ -307,7 +318,7 @@ initRecords(void)
 
 	for (orient = 0; orient < 2; orient++)
 		for (i = 0; i < (MAX_WEDGES - MIN_WEDGES) / 2 + 1; i++)
-			for (j = 0; j < MAX_RINGS - MIN_RINGS + 1; j++) {
+			for (j = 0; j < MAX_BANDS - MIN_BANDS + 1; j++) {
 				puzzleRecord[orient][i][j].score = NEVER;
 				(void) strncpy(puzzleRecord[orient][i][j].name,
 					NOACCESS, USER_NAME_LENGTH);
@@ -362,7 +373,7 @@ readRecords(void)
 	free(fname);
 	for (orient = 0; orient < 2; orient++)
 		for (i = 0; i < (MAX_WEDGES - MIN_WEDGES) / 2 + 1; i++)
-			for (j = 0; j < MAX_RINGS - MIN_RINGS + 1; j++) {
+			for (j = 0; j < MAX_BANDS - MIN_BANDS + 1; j++) {
 				(void) fscanf(fp, "%d %s\n", &n, userName);
 				if (n <= puzzleRecord[orient][i][j].score ||
 						puzzleRecord[orient][i][j].score <= NEVER) {
@@ -393,6 +404,7 @@ writeRecords(void)
 		char lockFile[FILE_NAME_LENGTH];
 
 		(void) strncpy(lockFile, fileName, FILE_NAME_LENGTH - 6);
+		lockFile[FILE_NAME_LENGTH - 6] = '\0';
 		(void) strcat(lockFile, ".lock");
 		while (((lfd = open(lockFile, O_CREAT | O_EXCL, 0644)) < 0) &&
 				errno == EEXIST)
@@ -410,7 +422,7 @@ writeRecords(void)
 #endif
 		for (orient = 0; orient < 2; orient++) {
 			for (i = 0; i < (MAX_WEDGES - MIN_WEDGES) / 2 + 1; i++) {
-				for (j = 0; j < MAX_RINGS - MIN_RINGS + 1; j++)
+				for (j = 0; j < MAX_BANDS - MIN_BANDS + 1; j++)
 					(void) fprintf(fp, "%d %s\n",
 						puzzleRecord[orient][i][j].score,
 						puzzleRecord[orient][i][j].name);
@@ -427,15 +439,15 @@ writeRecords(void)
 }
 
 static void
-printRecord(int wedges, int rings, Boolean orient, Boolean practice)
+printRecord(int wedges, int bands, Boolean orient, Boolean practice)
 {
 	int i = (orient) ? 1 : 0;
 	int w = (wedges - MIN_WEDGES) / 2;
-	int r = rings - MIN_RINGS;
+	int r = bands - MIN_BANDS;
 
 	if (practice) {
 		(void) strncpy(recordDsp, "practice", MESSAGE_LENGTH);
-	} else if (rings > MAX_RINGS) {
+	} else if (bands > MAX_BANDS) {
 		(void) strncpy(recordDsp, "NOT RECORDED", MESSAGE_LENGTH);
 	} else if (puzzleRecord[i][w][r].score <= NEVER) {
 		(void) sprintf(recordDsp, "NEVER %s", NOACCESS);
@@ -451,7 +463,7 @@ printRecord(int wedges, int rings, Boolean orient, Boolean practice)
 static void
 printStatus(char *msg, int nMoves
 #ifndef HAVE_MOTIF
-		, int wedges, int rings
+		, int wedges, int bands
 #endif
 		)
 {
@@ -461,7 +473,7 @@ printStatus(char *msg, int nMoves
 	printState(movesText, buff);
 #else
 	(void) sprintf(titleDsp, "%s.%d: %d@ (%d/%s) - %s",
-		progDsp, wedges, rings, nMoves, recordDsp, msg);
+		progDsp, wedges, bands, nMoves, recordDsp, msg);
 #ifdef WINVER
 	SetWindowText(widget.core.hWnd, (LPSTR) titleDsp);
 #else
@@ -471,13 +483,13 @@ printStatus(char *msg, int nMoves
 }
 
 static Boolean
-handleSolved(int counter, int wedges, int rings, Boolean orient)
+handleSolved(int counter, int wedges, int bands, Boolean orient)
 {
 	int i = (orient) ? 1 : 0;
 	int w = (wedges - MIN_WEDGES) / 2;
-	int r = rings - MIN_RINGS;
+	int r = bands - MIN_BANDS;
 
-	if (rings <= MAX_RINGS && (counter < puzzleRecord[i][w][r].score ||
+	if (bands <= MAX_BANDS && (counter < puzzleRecord[i][w][r].score ||
 			puzzleRecord[i][w][r].score <= NEVER)) {
 		readRecords();	/* Maybe its been updated by another */
 		puzzleRecord[i][w][r].score = counter;
@@ -490,7 +502,7 @@ handleSolved(int counter, int wedges, int rings, Boolean orient)
 				USER_NAME_LENGTH);
 		}
 		writeRecords();
-		printRecord(wedges, rings, orient, False);
+		printRecord(wedges, bands, orient, False);
 		return True;
 	}
 	return False;
@@ -505,7 +517,7 @@ Widget w
 #endif
 )
 {
-	int wedges, rings;
+	int wedges, bands;
 	Boolean orient, practice;
 	char *userName, *scoreFile;
 
@@ -513,7 +525,7 @@ Widget w
 	initializePuzzle(w, brush);
 
 	wedges = w->mball.wedges;
-	rings = w->mball.rings;
+	bands = w->mball.bands;
 	orient = w->mball.orient;
 	practice = w->mball.practice;
 	userName = w->mball.userName;
@@ -527,7 +539,7 @@ Widget w
 		XtNuserName, &userName,
 		XtNscoreFile, &scoreFile,
 		XtNwedges, &wedges,
-		XtNrings, &rings,
+		XtNbands, &bands,
 		XtNorient, &orient,
 		XtNpractice, &practice,
 		XtNscoreOnly, &scoreOnly,
@@ -546,11 +558,18 @@ Widget w
 	}
 #ifdef HAVE_MOTIF
 	XmToggleButtonSetState(wedge[(wedges - MIN_WEDGES) / 2], True, False);
-	if (rings > MAX_RINGS)
-		XtVaSetValues(ringSlider, XmNmaximum, rings, NULL);
-	XmScaleSetValue(ringSlider, rings);
+	if (bands > MAX_BANDS)
+		XtVaSetValues(bandSlider, XmNmaximum, bands, NULL);
+	XmScaleSetValue(bandSlider, bands);
 	XmToggleButtonSetState(orientizeSwitch, orient, True);
 	XmToggleButtonSetState(practiceSwitch, practice, True);
+	{
+		int delay;
+
+		XtVaGetValues(w, XtNdelay, &delay, NULL);
+		XmScaleSetValue(speedSlider,
+			MAX_SPEED + MIN_SPEED - delay / MULTSPEED - 1);
+	}
 #endif
 #endif
 	SET_STARTED(w, False);
@@ -580,10 +599,10 @@ Widget w
 			(void) sprintf(userNameDsp, "%s", "guest");
 #endif
 	}
-	printRecord(wedges, rings, orient, practice);
+	printRecord(wedges, bands, orient, practice);
 	printStatus(messageDsp, movesDsp
 #ifndef HAVE_MOTIF
-		, wedges, rings
+		, wedges, bands
 #endif
 		);
 }
@@ -599,25 +618,27 @@ puzzleListener(Widget w, caddr_t clientData, mballCallbackStruct *callData)
 #ifndef WINVER
 	int reason = callData->reason;
 #endif
-	int wedges, rings;
-	Boolean orient, practice, start, cheat;
+	int wedges, bands;
+	Boolean orient, practice, start, cheat, perspective;
 
 	(void) strcpy(messageDsp, "");
 #ifdef WINVER
 	wedges = w->mball.wedges;
-	rings = w->mball.rings;
+	bands = w->mball.bands;
 	orient = w->mball.orient;
 	practice = w->mball.practice;
 	cheat = w->mball.cheat;
 	start = w->mball.started;
+	perspective = w->mball.perspective;
 #else
 	XtVaGetValues(w,
 		XtNwedges, &wedges,
-		XtNrings, &rings,
+		XtNbands, &bands,
 		XtNorient, &orient,
 		XtNpractice, &practice,
 		XtNstart, &start,
-		XtNcheat, &cheat, NULL);
+		XtNcheat, &cheat,
+		XtNperspective, &perspective, NULL);
 #endif
 	switch (reason) {
 	case ACTION_HIDE:
@@ -696,7 +717,7 @@ puzzleListener(Widget w, caddr_t clientData, mballCallbackStruct *callData)
 		else if (cheat)
 			(void) sprintf(messageDsp,
 				"No cheating %s!!", userNameDsp);
-		else if (handleSolved(movesDsp, wedges, rings, orient))
+		else if (handleSolved(movesDsp, wedges, bands, orient))
 			(void) sprintf(messageDsp,
 				"Congratulations %s!!", userNameDsp);
 		else
@@ -715,7 +736,7 @@ puzzleListener(Widget w, caddr_t clientData, mballCallbackStruct *callData)
 		if (!practice)
 			(void) strncpy(messageDsp, "Randomize to start",
 				MESSAGE_LENGTH);
-		printRecord(wedges, rings, orient, practice);
+		printRecord(wedges, bands, orient, practice);
 #ifdef WINVER
 		w->mball.practice = practice;
 		w->mball.started = False;
@@ -742,38 +763,38 @@ puzzleListener(Widget w, caddr_t clientData, mballCallbackStruct *callData)
 		break;
 	case ACTION_INCREMENT:
 		movesDsp = 0;
-		rings++;
-		printRecord(wedges, rings, orient, practice);
+		bands++;
+		printRecord(wedges, bands, orient, practice);
 #ifdef WINVER
-		w->mball.rings = rings;
+		w->mball.bands = bands;
 #else
-		XtVaSetValues(w, XtNrings, rings, NULL);
+		XtVaSetValues(w, XtNbands, bands, NULL);
 #ifdef HAVE_MOTIF
-		if (rings > MAX_RINGS)
-			XtVaSetValues(ringSlider, XmNmaximum, rings, NULL);
-		XmScaleSetValue(ringSlider, rings);
+		if (bands > MAX_BANDS)
+			XtVaSetValues(bandSlider, XmNmaximum, bands, NULL);
+		XmScaleSetValue(bandSlider, bands);
 #endif
 #endif
 		break;
 	case ACTION_DECREMENT:
 		movesDsp = 0;
-		rings--;
-		printRecord(wedges, rings, orient, practice);
+		bands--;
+		printRecord(wedges, bands, orient, practice);
 #ifdef WINVER
-		w->mball.rings = rings;
+		w->mball.bands = bands;
 #else
-		XtVaSetValues(w, XtNrings, rings, NULL);
+		XtVaSetValues(w, XtNbands, bands, NULL);
 #ifdef HAVE_MOTIF
-		XmScaleSetValue(ringSlider, rings);
-		if (rings >= MAX_RINGS)
-			XtVaSetValues(ringSlider, XmNmaximum, rings, NULL);
+		XmScaleSetValue(bandSlider, bands);
+		if (bands >= MAX_BANDS)
+			XtVaSetValues(bandSlider, XmNmaximum, bands, NULL);
 #endif
 #endif
 		break;
 	case ACTION_ORIENTIZE:
 		movesDsp = 0;
 		orient = !orient;
-		printRecord(wedges, rings, orient, practice);
+		printRecord(wedges, bands, orient, practice);
 #ifdef WINVER
 		w->mball.orient = orient;
 #else
@@ -791,7 +812,7 @@ puzzleListener(Widget w, caddr_t clientData, mballCallbackStruct *callData)
 	case ACTION_WEDGE12:
 		movesDsp = 0;
 		wedges = 2 * (reason - ACTION_WEDGE2) + MIN_WEDGES;
-		printRecord(wedges, rings, orient, practice);
+		printRecord(wedges, bands, orient, practice);
 #ifdef WINVER
 		w->mball.wedges = wedges;
 #else
@@ -810,10 +831,38 @@ puzzleListener(Widget w, caddr_t clientData, mballCallbackStruct *callData)
 		movesDsp++;
 		SET_STARTED(w, True);
 		break;
+#ifdef HAVE_MOTIF
+	case ACTION_SPEED:
+		{
+			int oldDelay, delay;
+
+			XtVaGetValues(puzzle, XtNdelay, &delay, NULL);
+			oldDelay = delay;
+			if (delay > MAX_SPEED - MIN_SPEED)
+				delay = MAX_SPEED - MIN_SPEED;
+			if (delay < 0)
+				delay = 0;
+			if (delay != oldDelay) {
+				XtVaSetValues(w,
+					XtNdelay, delay, NULL);
+			}
+			XmScaleSetValue(speedSlider,
+				MAX_SPEED + MIN_SPEED - delay - 1);
+		}
+		return;
+#endif
+	case ACTION_PERSPECTIVE:
+		perspective = !perspective;
+#ifdef WINVER
+		w->mball.perspective = perspective;
+#else
+		XtVaSetValues(w, XtNperspective, perspective, NULL);
+#endif
+		break;
 	}
 	printStatus(messageDsp, movesDsp
 #ifndef HAVE_MOTIF
-		, wedges, rings
+		, wedges, bands
 #endif
 		);
 }
@@ -891,6 +940,8 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 		(void) SelectObject(widget.core.hDC,
 			GetStockObject(NULL_PEN));
 		releasePuzzle(&widget, LOWORD(lParam), HIWORD(lParam),
+			((GetKeyState(VK_SHIFT) >> 1) ||
+			(GetKeyState(VK_CAPITAL) & 1)),
 			(GetKeyState(VK_CONTROL) >> 1) ? 1 : 0);
 		(void) ReleaseDC(hWnd, widget.core.hDC);
 		break;
@@ -984,6 +1035,11 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 			sizePuzzle(&widget);
 			(void) InvalidateRect(hWnd, NULL, TRUE);
 			break;
+		case ACTION_PERSPECTIVE:
+			perspectivePuzzle(&widget);
+			resizePuzzle(&widget);
+			(void) InvalidateRect(hWnd, NULL, TRUE);
+			break;
 		case ACTION_TOP:
 		case ACTION_TTR:
 		case ACTION_TR:
@@ -1196,8 +1252,10 @@ static XrmOptionDescRec options[] =
 	{(char *) "-nosound", (char *) "*mball.sound", XrmoptionNoArg, (char *) "FALSE"},
 	{(char *) "-fn", (char *) "*mball.font", XrmoptionSepArg, NULL},
 	{(char *) "-font", (char *) "*mball.font", XrmoptionSepArg, NULL},
+	{(char *) "-perspective", (char *) "*mball.perspective", XrmoptionNoArg, (char *) "TRUE"},
+	{(char *) "-noperspective", (char *) "*mball.perspective", XrmoptionNoArg, (char *) "FALSE"},
 	{(char *) "-wedges", (char *) "*mball.wedges", XrmoptionSepArg, NULL},
-	{(char *) "-rings", (char *) "*mball.rings", XrmoptionSepArg, NULL},
+	{(char *) "-bands", (char *) "*mball.bands", XrmoptionSepArg, NULL},
 	{(char *) "-orient", (char *) "*mball.orient", XrmoptionNoArg, (char *) "TRUE"},
 	{(char *) "-noorient", (char *) "*mball.orient", XrmoptionNoArg, (char *) "FALSE"},
 	{(char *) "-practice", (char *) "*mball.practice", XrmoptionNoArg, (char *) "TRUE"},
@@ -1231,12 +1289,12 @@ puzzleRandomizeListener(Widget w, XtPointer clientData,
 static void
 wedgeToggle(Widget w, int bit, XmToggleButtonCallbackStruct *cbs)
 {
-	int wedges, rings;
+	int wedges, bands;
 	Boolean orient, practice;
 
 	if (cbs->set) {
 		XtVaGetValues(puzzle,
-			XtNrings, &rings,
+			XtNbands, &bands,
 			XtNorient, &orient,
 			XtNpractice, &practice, NULL);
 		wedges = bit * 2 + MIN_WEDGES;
@@ -1245,31 +1303,31 @@ wedgeToggle(Widget w, int bit, XmToggleButtonCallbackStruct *cbs)
 		movesDsp = 0;
 		(void) sprintf(buff, "%d", movesDsp);
 		printState(movesText, buff);
-		printRecord(wedges, rings, orient, practice);
+		printRecord(wedges, bands, orient, practice);
 		(void) strcpy(messageDsp, "");
 		printState(message, messageDsp);
 	}
 }
 
 static void
-ringChangeListener(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
+bandChangeListener(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
 {
-	int wedges, rings = cbs->value, old;
+	int wedges, bands = cbs->value, old;
 	Boolean orient, practice;
 
 	XtVaGetValues(puzzle,
 		XtNwedges, &wedges,
-		XtNrings, &old,
+		XtNbands, &old,
 		XtNorient, &orient,
 		XtNpractice, &practice, NULL);
-	if (old == rings)
+	if (old == bands)
 		return;
 	XtVaSetValues(puzzle,
-		XtNrings, rings, NULL);
+		XtNbands, bands, NULL);
 	movesDsp = 0;
 	(void) sprintf(buff, "%d", movesDsp);
 	printState(movesText, buff);
-	printRecord(wedges, rings, orient, practice);
+	printRecord(wedges, bands, orient, practice);
 	(void) strcpy(messageDsp, "");
 	printState(message, messageDsp);
 }
@@ -1277,12 +1335,12 @@ ringChangeListener(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
 static void
 orientToggle(Widget w, XtPointer clientData, XmToggleButtonCallbackStruct *cbs)
 {
-	int wedges, rings;
+	int wedges, bands;
 	Boolean orient = cbs->set, practice, oldOrient;
 
 	XtVaGetValues(puzzle,
 		XtNwedges, &wedges,
-		XtNrings, &rings,
+		XtNbands, &bands,
 		XtNorient, &oldOrient,
 		XtNpractice, &practice, NULL);
 	if (oldOrient == orient)
@@ -1292,7 +1350,7 @@ orientToggle(Widget w, XtPointer clientData, XmToggleButtonCallbackStruct *cbs)
 	movesDsp = 0;
 	(void) sprintf(buff, "%d", movesDsp);
 	printState(movesText, buff);
-	printRecord(wedges, rings, orient, practice);
+	printRecord(wedges, bands, orient, practice);
 	(void) strcpy(messageDsp, "");
 	printState(message, messageDsp);
 }
@@ -1301,12 +1359,12 @@ static void
 practiceToggle(Widget w, XtPointer clientData,
 		XmToggleButtonCallbackStruct *cbs)
 {
-	int wedges, rings;
+	int wedges, bands;
 	Boolean orient, practice = cbs->set, oldPract;
 
 	XtVaGetValues(puzzle,
 		XtNwedges, &wedges,
-		XtNrings, &rings,
+		XtNbands, &bands,
 		XtNorient, &orient,
 		XtNpractice, &oldPract, NULL);
 	if (oldPract == practice)
@@ -1317,7 +1375,7 @@ practiceToggle(Widget w, XtPointer clientData,
 	movesDsp = 0;
 	(void) sprintf(buff, "%d", movesDsp);
 	printState(movesText, buff);
-	printRecord(wedges, rings, orient, practice);
+	printRecord(wedges, bands, orient, practice);
 	if (practice)
 		(void) strcpy(messageDsp, "");
 	else
@@ -1325,6 +1383,17 @@ practiceToggle(Widget w, XtPointer clientData,
 	printState(message, messageDsp);
 }
 
+static void
+speedChangeListener(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
+{
+	int delay = MULTSPEED * (MAX_SPEED + MIN_SPEED - cbs->value - 1), oldDelay;
+	XtVaGetValues(puzzle,
+		XtNdelay, &oldDelay, NULL);
+	if (oldDelay != delay) {
+		XtVaSetValues(puzzle, XtNdelay, delay, NULL);
+	}
+}
+
 static void
 fileMenuListener(Widget w, void *value, void *clientData)
 {
@@ -1437,14 +1506,14 @@ main(int argc, char **argv)
 #ifdef HAVE_MOTIF
 	Widget menuBar, pullDownMenu, widget;
 	Widget menuBarPanel, mainPanel, controlPanel;
-	Widget movesRowCol, labelRowCol, wedgesRowCol, ringsRowCol;
+	Widget movesRowCol, labelRowCol, wedgesRowCol, bandsRowCol;
 	Widget messageRowCol;
 	XmString fileString, playString;
 	XmString getString, writeString, quitString;
 	XmString undoString, redoString;
 	XmString clearString, randomizeString, practiceString, solveString;
 	XmString incrementString, decrementString, orientizeString;
-	XmString speedString, slowString, soundString;
+	XmString speedString, slowString, soundString, perspectiveString;
 	unsigned int i;
 #endif
 
@@ -1486,13 +1555,14 @@ main(int argc, char **argv)
 	clearString = XmStringCreateSimple((char *) "Clear");
 	practiceString = XmStringCreateSimple((char *) "Practice");
 	randomizeString = XmStringCreateSimple((char *) "Randomize");
-	solveString = XmStringCreateSimple((char *) "(Auto-solve)");
-	incrementString = XmStringCreateSimple((char *) "Increment Rings");
-	decrementString = XmStringCreateSimple((char *) "Decrement Rings");
+	solveString = XmStringCreateSimple((char *) "Auto-solve");
+	incrementString = XmStringCreateSimple((char *) "Increment Bands");
+	decrementString = XmStringCreateSimple((char *) "Decrement Bands");
 	orientizeString = XmStringCreateSimple((char *) "Orientize");
 	speedString = XmStringCreateSimple((char *) "Speed >");
 	slowString = XmStringCreateSimple((char *) "Slow <");
 	soundString = XmStringCreateSimple((char *) "Sound @");
+	perspectiveString = XmStringCreateSimple((char *) "Perspective");
 	(void) XmVaCreateSimplePulldownMenu(menuBar, (char *) "play_menu",
 		1, playCB,
 		XmVaPUSHBUTTON, undoString, 'U', NULL, NULL,
@@ -1507,6 +1577,7 @@ main(int argc, char **argv)
 		XmVaPUSHBUTTON, speedString, '>', NULL, NULL,
 		XmVaPUSHBUTTON, slowString, '<', NULL, NULL,
 		XmVaPUSHBUTTON, soundString, '@', NULL, NULL,
+		XmVaPUSHBUTTON, perspectiveString, 't', NULL, NULL,
 		NULL);
 	XmStringFree(undoString);
 	XmStringFree(redoString);
@@ -1520,6 +1591,7 @@ main(int argc, char **argv)
 	XmStringFree(speedString);
 	XmStringFree(slowString);
 	XmStringFree(soundString);
+	XmStringFree(perspectiveString);
 	pullDownMenu = XmCreatePulldownMenu(menuBar,
 		(char *) "helpPullDown", NULL, 0);
 	widget = XtVaCreateManagedWidget("Help",
@@ -1648,28 +1720,38 @@ main(int argc, char **argv)
 		XtAddCallback(wedge[i], XmNvalueChangedCallback,
 			(XtCallbackProc) wedgeToggle, (XtPointer) i);
 	}
-	ringsRowCol = XtVaCreateManagedWidget("ringsRowCol",
+	bandsRowCol = XtVaCreateManagedWidget("bandsRowCol",
 		xmRowColumnWidgetClass, controlPanel,
 		XmNnumColumns, 1,
 		XmNorientation, XmHORIZONTAL,
 		XmNpacking, XmPACK_COLUMN, NULL);
-	ringSlider = XtVaCreateManagedWidget("ringSlider",
-		xmScaleWidgetClass, ringsRowCol,
-		XtVaTypedArg, XmNtitleString, XmRString, "Rings", 6,
-		XmNminimum, MIN_RINGS,
-		XmNmaximum, MAX_RINGS,
-		XmNvalue, DEFAULT_RINGS,
+	bandSlider = XtVaCreateManagedWidget("bandSlider",
+		xmScaleWidgetClass, bandsRowCol,
+		XtVaTypedArg, XmNtitleString, XmRString, "Bands", 6,
+		XmNminimum, MIN_BANDS,
+		XmNmaximum, MAX_BANDS,
+		XmNvalue, DEFAULT_BANDS,
 		XmNshowValue, True,
 		XmNorientation, XmHORIZONTAL, NULL);
-	XtAddCallback(ringSlider, XmNvalueChangedCallback,
-		(XtCallbackProc) ringChangeListener, (XtPointer) NULL);
+	XtAddCallback(bandSlider, XmNvalueChangedCallback,
+		(XtCallbackProc) bandChangeListener, (XtPointer) NULL);
+	speedSlider = XtVaCreateManagedWidget("speedSlider",
+		xmScaleWidgetClass, bandsRowCol,
+		XtVaTypedArg, XmNtitleString, XmRString, "Animation Speed", 16,
+		XmNminimum, MIN_SPEED,
+		XmNmaximum, MAX_SPEED,
+		XmNvalue, MAX_SPEED - 10,
+		XmNshowValue, True,
+		XmNorientation, XmHORIZONTAL, NULL);
+	XtAddCallback(speedSlider, XmNvalueChangedCallback,
+		(XtCallbackProc) speedChangeListener, (XtPointer) NULL);
 	orientizeSwitch = XtVaCreateManagedWidget("Oriented",
-		xmToggleButtonWidgetClass, ringsRowCol,
+		xmToggleButtonWidgetClass, bandsRowCol,
 		XmNset, DEFAULT_ORIENT, NULL);
 	XtAddCallback(orientizeSwitch, XmNvalueChangedCallback,
 		(XtCallbackProc) orientToggle, (XtPointer) NULL);
 	practiceSwitch = XtVaCreateManagedWidget("Practice",
-		xmToggleButtonWidgetClass, ringsRowCol,
+		xmToggleButtonWidgetClass, bandsRowCol,
 		XmNset, DEFAULT_PRACTICE, NULL);
 	XtAddCallback(practiceSwitch, XmNvalueChangedCallback,
 		(XtCallbackProc) practiceToggle, (XtPointer) NULL);
