@@ -1,7 +1,7 @@
 /*
  * @(#)Mlink.c
  *
- * Copyright 1994 - 2008  David A. Bagley, bagleyd@tux.org
+ * Copyright 1994 - 2010  David A. Bagley, bagleyd@tux.org
  *
  * All rights reserved.
  *
@@ -2064,37 +2064,37 @@ setValuesPuzzle(MlinkWidget w)
 	char szBuf[80], buf[20], charbuf[2];
 	int face;
 
-	w->mlink.tiles = GetPrivateProfileInt(SECTION, "tiles",
-		DEFAULT_TILES, INIFILE);
-	w->mlink.faces = GetPrivateProfileInt(SECTION, "faces",
-		DEFAULT_FACES, INIFILE);
-	w->mlink.orient = (BOOL) GetPrivateProfileInt(SECTION, "orient",
-		DEFAULT_ORIENT, INIFILE);
-	w->mlink.middle = (BOOL) GetPrivateProfileInt(SECTION, "middle",
-		DEFAULT_MIDDLE, INIFILE);
-	w->mlink.practice = (BOOL) GetPrivateProfileInt(SECTION, "practice",
-		DEFAULT_PRACTICE, INIFILE);
-	w->mlink.base = GetPrivateProfileInt(SECTION, "base",
-		DEFAULT_BASE, INIFILE);
-	w->mlink.mono = (BOOL) GetPrivateProfileInt(SECTION, "mono",
-		DEFAULT_MONO, INIFILE);
-	w->mlink.reverse = (BOOL) GetPrivateProfileInt(SECTION, "reverseVideo",
-		DEFAULT_REVERSE, INIFILE);
+	w->mlink.tiles = GetPrivateProfileInt(SECTION,
+		"tiles", DEFAULT_TILES, INIFILE);
+	w->mlink.faces = GetPrivateProfileInt(SECTION,
+		"faces", DEFAULT_FACES, INIFILE);
+	w->mlink.orient = (BOOL) GetPrivateProfileInt(SECTION,
+		"orient", DEFAULT_ORIENT, INIFILE);
+	w->mlink.middle = (BOOL) GetPrivateProfileInt(SECTION,
+		"middle", DEFAULT_MIDDLE, INIFILE);
+	w->mlink.practice = (BOOL) GetPrivateProfileInt(SECTION,
+		"practice", DEFAULT_PRACTICE, INIFILE);
+	w->mlink.base = GetPrivateProfileInt(SECTION,
+		"base", DEFAULT_BASE, INIFILE);
+	w->mlink.mono = (BOOL) GetPrivateProfileInt(SECTION,
+		"mono", DEFAULT_MONO, INIFILE);
+	w->mlink.reverse = (BOOL) GetPrivateProfileInt(SECTION,
+		"reverseVideo", DEFAULT_REVERSE, INIFILE);
 	/* cyan */
-	(void) GetPrivateProfileString(SECTION, "frameColor", "0 255 255",
-		szBuf, sizeof (szBuf), INIFILE);
+	(void) GetPrivateProfileString(SECTION,
+		"frameColor", "0 255 255", szBuf, sizeof (szBuf), INIFILE);
 	(void) sscanf(szBuf, "%d %d %d",
 		&(color.red), &(color.green), &(color.blue));
 	w->mlink.frameGC = RGB(color.red, color.green, color.blue);
 	/* black */
-	(void) GetPrivateProfileString(SECTION, "tileColor", "0 0 0",
-		szBuf, sizeof (szBuf), INIFILE);
+	(void) GetPrivateProfileString(SECTION,
+		"tileColor", "0 0 0", szBuf, sizeof (szBuf), INIFILE);
 	(void) sscanf(szBuf, "%d %d %d",
 		&(color.red), &(color.green), &(color.blue));
 	w->mlink.tileGC[1] = RGB(color.red, color.green, color.blue);
 	/* gray25 */
-	(void) GetPrivateProfileString(SECTION, "tileBorder", "64 64 64",
-		szBuf, sizeof (szBuf), INIFILE);
+	(void) GetPrivateProfileString(SECTION,
+		"tileBorder", "64 64 64", szBuf, sizeof (szBuf), INIFILE);
 	(void) sscanf(szBuf, "%d %d %d",
 		&(color.red), &(color.green), &(color.blue));
 	w->mlink.tileGC[0] = RGB(brighter(color.red),
@@ -2103,8 +2103,8 @@ setValuesPuzzle(MlinkWidget w)
 		darker(color.green), darker(color.blue));
 	w->mlink.borderGC = RGB(color.red, color.green, color.blue);
 	/* #AEB2C3 */
-	(void) GetPrivateProfileString(SECTION, "background", "174 178 195",
-		szBuf, sizeof (szBuf), INIFILE);
+	(void) GetPrivateProfileString(SECTION,
+		"background", "174 178 195", szBuf, sizeof (szBuf), INIFILE);
 	(void) sscanf(szBuf, "%d %d %d",
 		&(color.red), &(color.green), &(color.blue));
 	w->mlink.inverseGC = RGB(color.red, color.green, color.blue);
@@ -2120,34 +2120,30 @@ setValuesPuzzle(MlinkWidget w)
 		(void) sprintf(buf, "faceChar%d", face);
 		charbuf[0] = faceColorChar[face];
 		charbuf[1] = '\0';
-		(void) GetPrivateProfileString(SECTION, buf, charbuf,
-			szBuf, sizeof (szBuf), INIFILE);
+		(void) GetPrivateProfileString(SECTION,
+			buf, charbuf, szBuf, sizeof (szBuf), INIFILE);
 		w->mlink.faceChar[face] = szBuf[0];
 	}
-	(void) GetPrivateProfileString(SECTION, "picture", PICTURE,
-		szBuf, sizeof (szBuf), INIFILE);
-	(void) strcpy(w->mlink.picture, szBuf);
-	w->mlink.picture[80] = 0;
-	w->mlink.delay = GetPrivateProfileInt(SECTION, "delay",
-		DEFAULT_DELAY, INIFILE);
-	w->mlink.sound = (BOOL)
-		GetPrivateProfileInt(SECTION, "sound", 0, INIFILE);
-	(void) GetPrivateProfileString(SECTION, "bumpSound", BUMPSOUND,
-		szBuf, sizeof (szBuf), INIFILE);
-	(void) strcpy(w->mlink.bumpSound, szBuf);
-	w->mlink.bumpSound[80] = 0;
-	(void) GetPrivateProfileString(SECTION, "moveSound", MOVESOUND,
-		szBuf, sizeof (szBuf), INIFILE);
-	(void) strcpy(w->mlink.moveSound, szBuf);
+	(void) GetPrivateProfileString(SECTION,
+		"picture", PICTURE, szBuf, sizeof (szBuf), INIFILE);
+	(void) strncpy(w->mlink.picture, szBuf, 80);
+	w->mlink.delay = GetPrivateProfileInt(SECTION,
+		"delay", DEFAULT_DELAY, INIFILE);
+	w->mlink.sound = (BOOL) GetPrivateProfileInt(SECTION,
+		"sound", 0, INIFILE);
+	(void) GetPrivateProfileString(SECTION,
+		"bumpSound", BUMPSOUND, szBuf, sizeof (szBuf), INIFILE);
+	(void) strncpy(w->mlink.bumpSound, szBuf, 80);
+	(void) GetPrivateProfileString(SECTION,
+		"moveSound", MOVESOUND, szBuf, sizeof (szBuf), INIFILE);
+	(void) strncpy(w->mlink.moveSound, szBuf, 80);
 	w->mlink.moveSound[80] = 0;
-	(void) GetPrivateProfileString(SECTION, "userName", "Guest",
-		szBuf, sizeof (szBuf), INIFILE);
-	(void) strcpy(w->mlink.userName, szBuf);
-	w->mlink.userName[80] = 0;
-	(void) GetPrivateProfileString(SECTION, "scoreFile", "",
-		szBuf, sizeof (szBuf), INIFILE);
-	(void) strcpy(w->mlink.scoreFile, szBuf);
-	w->mlink.scoreFile[80] = 0;
+	(void) GetPrivateProfileString(SECTION,
+		"userName", "Guest", szBuf, sizeof (szBuf), INIFILE);
+	(void) strncpy(w->mlink.userName, szBuf, 80);
+	(void) GetPrivateProfileString(SECTION,
+		"scoreFile", "", szBuf, sizeof (szBuf), INIFILE);
+	(void) strncpy(w->mlink.scoreFile, szBuf, 80);
 }
 
 void
@@ -2457,10 +2453,8 @@ destroyPuzzle(Widget old)
 	Display *display = XtDisplay(w);
 	int i;
 
-#if 0
 #if defined( USE_SOUND ) && defined( USE_ESOUND )
 	(void) shutdown_sound();
-#endif
 #endif
 	for (i = 0; i < MAX_FACES; i++)
 		XtReleaseGC(old, w->mlink.faceGC[i]);
@@ -2686,12 +2680,10 @@ Widget request, Widget renew
 #ifdef USE_NAS
 	dsp = XtDisplay(w);
 #endif
-#if 0
 #ifdef USE_ESOUND
 	(void) init_sound();
 #endif
 #endif
-#endif
 }
 
 #ifndef WINVER
