@@ -1,7 +1,7 @@
 /*
  * @(#)xmlink.c
  *
- * Copyright 1994 - 2009  David A. Bagley, bagleyd@tux.org
+ * Copyright 1994 - 2010  David A. Bagley, bagleyd@tux.org
  *
  * All rights reserved.
  *
@@ -21,8 +21,9 @@
 /* Driver file for Mlink */
 
 #ifndef WINVER
+#include "version.h"
 static const char aboutHelp[] = {
-"Mlink Version 7.5\n"
+"Mlink Version " VERSION "\n"
 "Send bugs (reports or fixes) to the author: "
 "David Bagley <bagleyd@tux.org>\n"
 "The latest version is at: "
@@ -378,6 +379,7 @@ writeRecords(void)
 		char lockFile[FILE_NAME_LENGTH];
 
 		(void) strncpy(lockFile, fileName, FILE_NAME_LENGTH - 6);
+		lockFile[FILE_NAME_LENGTH - 6] = '\0';
 		(void) strcat(lockFile, ".lock");
 		while (((lfd = open(lockFile, O_CREAT | O_EXCL, 0644)) < 0) &&
 				errno == EEXIST)
