@@ -1,7 +1,7 @@
 /*
  * @(#)Oct.c
  *
- * Copyright 1994 - 2008  David A. Bagley, bagleyd@tux.org
+ * Copyright 1994 - 2010  David A. Bagley, bagleyd@tux.org
  *
  * All rights reserved.
  *
@@ -139,6 +139,7 @@ static char translations[] =
  <KeyPress>0x3C: Slow()\n\
  <KeyPress>0x2C: Slow()\n\
  Shift<KeyPress>2: Sound()\n\
+ <KeyPress>F11: MoveCcw()\n\
  <KeyPress>KP_Divide: MoveCcw()\n\
  <KeyPress>R5: MoveCcw()\n\
  <KeyPress>Home: MoveTl()\n\
@@ -157,6 +158,7 @@ static char translations[] =
  <KeyPress>KP_Left: MoveLeft()\n\
  <KeyPress>KP_4: MoveLeft()\n\
  <KeyPress>R10: MoveLeft()\n\
+ <KeyPress>F12: MoveCw()\n\
  <KeyPress>Begin: MoveCw()\n\
  <KeyPress>KP_5: MoveCw()\n\
  <KeyPress>R11: MoveCw()\n\
@@ -1409,16 +1411,7 @@ moveControlCb(OctWidget w, int face, int direction, int style)
 				setPuzzle(w, ACTION_CONTROL);
 		} else		/* (style == PERIOD4) */
 			for (i = 0; i < 3; i++) {
-				if (i < 2) {
-					if (i == 1)
-						j = i + 2;
-					else
-						j = i;
-					rtt.row = j;
-					rtt.trbl = j;
-					rtt.tlbr = j;
-					movePieces(w, face, rtt, direction, style);
-				} else {
+				if (i == 2) {
 					if (direction == CW || direction == CCW) {
 						j = i - 2;
 						rtt.row = j;
@@ -1444,6 +1437,15 @@ moveControlCb(OctWidget w, int face, int direction, int style)
 							(direction + 2) % MAX_FACES :
 							(direction + 6) % MAX_FACES, style);
 					}
+				} else {
+					if (i == 1)
+						j = i + 2;
+					else
+						j = i;
+					rtt.row = j;
+					rtt.trbl = j;
+					rtt.tlbr = j;
+					movePieces(w, face, rtt, direction, style);
 				}
 				setPuzzle(w, ACTION_CONTROL);
 			}
@@ -1516,6 +1518,14 @@ movePuzzle(OctWidget w, int face, int position, int direction, int style,
 	flushMoves(w, &redo, FALSE);
 }
 
+void
+movePuzzleDelay(OctWidget w, int face, int position, int direction,
+	int style, int control)
+{
+	movePuzzle(w, face, position, direction, style, control);
+	Sleep((unsigned int) w->oct.delay);
+}
+
 static Boolean
 selectPieces(OctWidget w, int positionX, int positionY, int *face, RTT * rtt)
 {
@@ -2422,7 +2432,10 @@ solvePieces(OctWidget w)
 {
 	if (checkSolved(w) || w->oct.currentFace > IGNORE_DIR)
 		return;
-	{
+	if ((w->oct.size == 2 || w->oct.size == 3) &&
+			w->oct.mode == PERIOD4)
+		solveSomePieces(w);
+	else {
 		setPuzzle(w, ACTION_SOLVE_MESSAGE);
 	}
 }
@@ -2490,42 +2503,42 @@ setValuesPuzzle(OctWidget w)
 	char szBuf[80], buf[20], charbuf[2];
 	int face;
 
-	w->oct.size = GetPrivateProfileInt(SECTION, "size",
-		DEFAULTFACETS, INIFILE);
-	w->oct.mode = GetPrivateProfileInt(SECTION, "mode",
-		DEFAULT_MODE, INIFILE);
-	w->oct.sticky = (BOOL) GetPrivateProfileInt(SECTION, "sticky",
-		DEFAULTSTICKY, INIFILE);
-	w->oct.orient = (BOOL) GetPrivateProfileInt(SECTION, "orient",
-		DEFAULT_ORIENT, INIFILE);
-	w->oct.practice = (BOOL) GetPrivateProfileInt(SECTION, "practice",
-		DEFAULT_PRACTICE, INIFILE);
-	w->oct.mono = (BOOL) GetPrivateProfileInt(SECTION, "mono",
-		DEFAULT_MONO, INIFILE);
-	w->oct.reverse = (BOOL) GetPrivateProfileInt(SECTION, "reverseVideo",
-		DEFAULT_REVERSE, INIFILE);
+	w->oct.size = GetPrivateProfileInt(SECTION,
+		"size", DEFAULTFACETS, INIFILE);
+	w->oct.mode = GetPrivateProfileInt(SECTION,
+		"mode", DEFAULT_MODE, INIFILE);
+	w->oct.sticky = (BOOL) GetPrivateProfileInt(SECTION,
+		"sticky", DEFAULTSTICKY, INIFILE);
+	w->oct.orient = (BOOL) GetPrivateProfileInt(SECTION,
+		"orient", DEFAULT_ORIENT, INIFILE);
+	w->oct.practice = (BOOL) GetPrivateProfileInt(SECTION,
+		"practice", DEFAULT_PRACTICE, INIFILE);
+	w->oct.mono = (BOOL) GetPrivateProfileInt(SECTION,
+		"mono", DEFAULT_MONO, INIFILE);
+	w->oct.reverse = (BOOL) GetPrivateProfileInt(SECTION,
+		"reverseVideo", DEFAULT_REVERSE, INIFILE);
 	/* cyan */
-	(void) GetPrivateProfileString(SECTION, "frameColor", "0 255 255",
-		szBuf, sizeof (szBuf), INIFILE);
+	(void) GetPrivateProfileString(SECTION,
+		"frameColor", "0 255 255", szBuf, sizeof (szBuf), INIFILE);
 	(void) sscanf(szBuf, "%d %d %d",
 		&(color.red), &(color.green), &(color.blue));
 	w->oct.frameGC = RGB(color.red, color.green, color.blue);
 	/* gray25 */
-	(void) GetPrivateProfileString(SECTION, "pieceBorder", "64 64 64",
-		szBuf, sizeof (szBuf), INIFILE);
+	(void) GetPrivateProfileString(SECTION,
+		"pieceBorder", "64 64 64", szBuf, sizeof (szBuf), INIFILE);
 	(void) sscanf(szBuf, "%d %d %d",
 		&(color.red), &(color.green), &(color.blue));
 	w->oct.borderGC = RGB(color.red, color.green, color.blue);
 	/* #AEB2C3 */
-	(void) GetPrivateProfileString(SECTION, "background", "174 178 195",
-		szBuf, sizeof (szBuf), INIFILE);
+	(void) GetPrivateProfileString(SECTION,
+		"background", "174 178 195", szBuf, sizeof (szBuf), INIFILE);
 	(void) sscanf(szBuf, "%d %d %d",
 		&(color.red), &(color.green), &(color.blue));
 	w->oct.inverseGC = RGB(color.red, color.green, color.blue);
 	for (face = 0; face < MAX_FACES; face++) {
 		(void) sprintf(buf, "faceColor%d", face);
-		(void) GetPrivateProfileString(SECTION, buf,
-			faceColorString[face],
+		(void) GetPrivateProfileString(SECTION,
+			buf, faceColorString[face],
 			szBuf, sizeof (szBuf), INIFILE);
 		(void) sscanf(szBuf, "%d %d %d",
 			&(color.red), &(color.green), &(color.blue));
@@ -2534,18 +2547,23 @@ setValuesPuzzle(OctWidget w)
 		(void) sprintf(buf, "faceChar%d", face);
 		charbuf[0] = faceColorChar[face];
 		charbuf[1] = '\0';
-		(void) GetPrivateProfileString(SECTION, buf, charbuf,
-			szBuf, sizeof (szBuf), INIFILE);
+		(void) GetPrivateProfileString(SECTION,
+			buf, charbuf, szBuf, sizeof (szBuf), INIFILE);
 		w->oct.faceChar[face] = szBuf[0];
 	}
-	(void) GetPrivateProfileString(SECTION, "userName", "Guest",
-		szBuf, sizeof (szBuf), INIFILE);
-	(void) strcpy(w->oct.userName, szBuf);
-		w->oct.userName[80] = 0;
-	(void) GetPrivateProfileString(SECTION, "scoreFile", "",
-		szBuf, sizeof (szBuf), INIFILE);
-	(void) strcpy(w->oct.scoreFile, szBuf);
-		w->oct.scoreFile[80] = 0;
+        w->oct.delay = GetPrivateProfileInt(SECTION,
+		"delay", 10, INIFILE);
+	w->oct.sound = (BOOL) GetPrivateProfileInt(SECTION,
+		"sound", FALSE, INIFILE);
+	(void) GetPrivateProfileString(SECTION,
+                "moveSound", MOVESOUND, szBuf, sizeof (szBuf), INIFILE);
+        (void) strncpy(w->oct.moveSound, szBuf, 80);
+	(void) GetPrivateProfileString(SECTION,
+		"userName", "Guest", szBuf, sizeof (szBuf), INIFILE);
+	(void) strncpy(w->oct.userName, szBuf, 80);
+	(void) GetPrivateProfileString(SECTION,
+		"scoreFile", "", szBuf, sizeof (szBuf), INIFILE);
+	(void) strncpy(w->oct.scoreFile, szBuf, 80);
 }
 
 void
@@ -2769,10 +2787,8 @@ destroyPuzzle(Widget old)
 	Display *display = XtDisplay(w);
 	int face;
 
-#if 0
 #if defined( USE_SOUND ) && defined( USE_ESOUND )
 	(void) shutdown_sound();
-#endif
 #endif
 	for (face = 0; face < MAX_FACES; face++)
 		XtReleaseGC(old, w->oct.faceGC[face]);
@@ -2895,12 +2911,10 @@ Widget request, Widget renew
 #ifdef USE_NAS
 	dsp = XtDisplay(w);
 #endif
-#if 0
 #ifdef USE_ESOUND
 	(void) init_sound();
 #endif
 #endif
-#endif
 }
 
 #ifndef WINVER
