@@ -1,7 +1,7 @@
 /*
  * @(#)xoct.c
  *
- * Copyright 1993 - 2009  David A. Bagley, bagleyd@tux.org
+ * Copyright 1993 - 2010  David A. Bagley, bagleyd@tux.org
  *
  * All rights reserved.
  *
@@ -21,8 +21,9 @@
 /* Driver file for Oct */
 
 #ifndef WINVER
+#include "version.h"
 static const char aboutHelp[] = {
-"Oct Version 7.5\n"
+"Oct Version " VERSION "\n"
 "Send bugs (reports or fixes) to the author: "
 "David Bagley <bagleyd@tux.org>\n"
 "The latest version is at: "
@@ -121,11 +122,9 @@ static const char featuresHelp[] = {
 "\n"
 "Press \"D\" or \"d\" keys to decrease the number of pieces.\n"
 "\n"
-"Press \">\" or \".\" keys to speed up the movement of pieces "
-"(not implemented).\n"
+"Press \">\" or \".\" keys to speed up the movement of pieces.\n"
 "\n"
-"Press \"<\" or \",\" keys to slow down the movement of pieces "
-"(not implemented).\n"
+"Press \"<\" or \",\" keys to slow down the movement of pieces.\n"
 "\n"
 "Press \"@\" key to toggle the sound.\n"
 "\n"
@@ -159,7 +158,8 @@ static const char referencesHelp[] = {
 #endif
 
 static const char solveHelp[] = {
-"Auto-solver: sorry, not implemented."
+"Auto-solver: sorry, only implemented for size < 4 where "
+"period = 4."
 };
 
 #include "file.h"
@@ -261,9 +261,12 @@ static char recordDsp[MESSAGE_LENGTH] = "NOT RECORDED";
 static int oldSize;
 
 #ifdef HAVE_MOTIF
+#define MIN_SPEED 1
+#define MAX_SPEED 50
+#define MULTSPEED 20
 static Widget movesText, recordText, message;
 static Widget modes[MAX_MODES], orientizeSwitch;
-static Widget stickySwitch, practiceSwitch, facetSlider;
+static Widget stickySwitch, practiceSwitch, facetSlider, speedSlider;
 static char buff[21];
 static const char *modeString[] =
 {
@@ -414,6 +417,7 @@ writeRecords(void)
 		char lockFile[FILE_NAME_LENGTH];
 
 		(void) strncpy(lockFile, fileName, FILE_NAME_LENGTH - 6);
+		lockFile[FILE_NAME_LENGTH - 6] = '\0';
 		(void) strcat(lockFile, ".lock");
 		while (((lfd = open(lockFile, O_CREAT | O_EXCL, 0644)) < 0) &&
 				errno == EEXIST)
@@ -513,7 +517,8 @@ handleSolved(int counter, int size, int mode, Boolean orient, Boolean sticky)
 			puzzleRecord[i][j][k].score <= NEVER)) {
 		readRecords();	/* Maybe its been updated by another */
 		puzzleRecord[i][j][k].score = counter;
-		(void) strncpy(puzzleRecord[i][j][k].name, userNameDsp, USER_NAME_LENGTH);
+		(void) strncpy(puzzleRecord[i][j][k].name, userNameDsp,
+			USER_NAME_LENGTH);
 		if ((size < 2 && mode != PERIOD4) ||
 				(size < 4 && mode == PERIOD4) || (orient &&
 				(counter < puzzleRecord[i][!j][k].score ||
@@ -587,6 +592,13 @@ Widget w
 	XmToggleButtonSetState(orientizeSwitch, orient, True);
 	XmToggleButtonSetState(stickySwitch, sticky, True);
 	XmToggleButtonSetState(practiceSwitch, practice, True);
+	{
+		int delay;
+
+		XtVaGetValues(w, XtNdelay, &delay, NULL);
+		XmScaleSetValue(speedSlider,
+			MAX_SPEED + MIN_SPEED - delay / MULTSPEED - 1);
+	}
 #endif
 #endif
 	SET_STARTED(w, False);
@@ -630,7 +642,8 @@ void
 setPuzzle(OctWidget w, int reason)
 #else
 static void
-puzzleListener(Widget w, caddr_t clientData, octCallbackStruct *callData)
+puzzleListener(Widget w, caddr_t clientData,
+		octCallbackStruct *callData)
 #endif
 {
 #ifndef WINVER
@@ -872,6 +885,26 @@ puzzleListener(Widget w, caddr_t clientData, octCallbackStruct *callData)
 		movesDsp++;
 		SET_STARTED(w, True);
 		break;
+#ifdef HAVE_MOTIF
+	case ACTION_SPEED:
+		{
+			int oldDelay, delay;
+
+			XtVaGetValues(puzzle, XtNdelay, &delay, NULL);
+			oldDelay = delay;
+			if (delay > MAX_SPEED - MIN_SPEED)
+				delay = MAX_SPEED - MIN_SPEED;
+			if (delay < 0)
+				delay = 0;
+			if (delay != oldDelay) {
+				XtVaSetValues(w,
+					XtNdelay, delay, NULL);
+			}
+			XmScaleSetValue(speedSlider,
+				MAX_SPEED + MIN_SPEED - delay - 1);
+		}
+		return;
+#endif
 	}
 	printStatus(messageDsp, movesDsp
 #ifndef HAVE_MOTIF
@@ -1441,6 +1474,17 @@ practiceToggle(Widget w, XtPointer clientData,
 	printState(message, messageDsp);
 }
 
+static void
+speedChangeListener(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
+{
+	int delay = MULTSPEED * (MAX_SPEED + MIN_SPEED - cbs->value - 1), oldDelay; 
+	XtVaGetValues(puzzle,
+		XtNdelay, &oldDelay, NULL);
+	if (oldDelay != delay) {
+		XtVaSetValues(puzzle, XtNdelay, delay, NULL);
+	}
+}
+
 static void
 fileMenuListener(Widget w, void *value, void *clientData)
 {
@@ -1602,7 +1646,7 @@ main(int argc, char **argv)
 	clearString = XmStringCreateSimple((char *) "Clear");
 	practiceString = XmStringCreateSimple((char *) "Practice");
 	randomizeString = XmStringCreateSimple((char *) "Randomize");
-	solveString = XmStringCreateSimple((char *) "(Auto-solve)");
+	solveString = XmStringCreateSimple((char *) "Auto-solve");
 	incrementString = XmStringCreateSimple((char *) "Increment");
 	decrementString = XmStringCreateSimple((char *) "Decrement");
 	orientizeString = XmStringCreateSimple((char *) "Orientize");
@@ -1764,6 +1808,16 @@ main(int argc, char **argv)
 		XmNorientation, XmHORIZONTAL, NULL);
 	XtAddCallback(facetSlider, XmNvalueChangedCallback,
 		(XtCallbackProc) pieceChangeListener, (XtPointer) NULL);
+	speedSlider = XtVaCreateManagedWidget("speedSlider",
+		xmScaleWidgetClass, facetRowCol,
+		XtVaTypedArg, XmNtitleString, XmRString, "Animation Speed", 16,
+		XmNminimum, MIN_SPEED,
+		XmNmaximum, MAX_SPEED,
+		XmNvalue, MAX_SPEED - 10,
+		XmNshowValue, True,
+		XmNorientation, XmHORIZONTAL, NULL);
+	XtAddCallback(speedSlider, XmNvalueChangedCallback,
+		(XtCallbackProc) speedChangeListener, (XtPointer) NULL);
 	labelRowCol = XtVaCreateManagedWidget("labelRowCol",
 		xmRowColumnWidgetClass, controlPanel, NULL);
 	(void) XtVaCreateManagedWidget("PeriodText",
