@@ -1,7 +1,7 @@
 /*
  * @(#)Panex.c
  *
- * Copyright 1996 - 2008  David A. Bagley, bagleyd@tux.org
+ * Copyright 1996 - 2010  David A. Bagley, bagleyd@tux.org
  *
  * All rights reserved.
  *
@@ -1602,18 +1602,18 @@ setValuesPuzzle(PanexWidget w)
 	char szBuf[80], buf[20], charbuf[2];
 	int pyramid;
 
-	w->panex.tiles = GetPrivateProfileInt(SECTION, "tiles",
-		DEFAULT_TILES, INIFILE);
-	w->panex.mode = GetPrivateProfileInt(SECTION, "mode",
-		DEFAULT_MODE, INIFILE);
+	w->panex.tiles = GetPrivateProfileInt(SECTION,
+		"tiles", DEFAULT_TILES, INIFILE);
+	w->panex.mode = GetPrivateProfileInt(SECTION,
+		"mode", DEFAULT_MODE, INIFILE);
 	w->panex.stacks = ((w->panex.mode == HANOI) ? 1 : 2);
-	w->panex.mono = (BOOL) GetPrivateProfileInt(SECTION, "mono",
-		DEFAULT_MONO, INIFILE);
-	w->panex.reverse = (BOOL) GetPrivateProfileInt(SECTION, "reverseVideo",
-		DEFAULT_REVERSE, INIFILE);
+	w->panex.mono = (BOOL) GetPrivateProfileInt(SECTION,
+		"mono", DEFAULT_MONO, INIFILE);
+	w->panex.reverse = (BOOL) GetPrivateProfileInt(SECTION,
+		"reverseVideo", DEFAULT_REVERSE, INIFILE);
 	/* gray75 */
-	(void) GetPrivateProfileString(SECTION, "tileColor", "191 191 191",
-		szBuf, sizeof (szBuf), INIFILE);
+	(void) GetPrivateProfileString(SECTION,
+		"tileColor", "191 191 191", szBuf, sizeof (szBuf), INIFILE);
 	(void) sscanf(szBuf, "%d %d %d",
 		&(color.red), &(color.green), &(color.blue));
 	w->panex.tileGC[1] = RGB(color.red, color.green, color.blue);
@@ -1622,8 +1622,8 @@ setValuesPuzzle(PanexWidget w)
 	w->panex.tileGC[2] = RGB(darker(color.red),
 		darker(color.green), darker(color.blue));
 	/* #AEB2C3 */
-	(void) GetPrivateProfileString(SECTION, "background", "174 178 195",
-		szBuf, sizeof (szBuf), INIFILE);
+	(void) GetPrivateProfileString(SECTION,
+		"background", "174 178 195", szBuf, sizeof (szBuf), INIFILE);
 	(void) sscanf(szBuf, "%d %d %d",
 		&(color.red), &(color.green), &(color.blue));
 	w->panex.inverseGC[1] = RGB(color.red, color.green, color.blue);
@@ -1648,28 +1648,26 @@ setValuesPuzzle(PanexWidget w)
 		(void) sprintf(buf, "pyramidChar%d", pyramid);
 		charbuf[0] = pyramidColorChar[pyramid];
 		charbuf[1] = '\0';
-		(void) GetPrivateProfileString(SECTION, buf, charbuf,
-			szBuf, sizeof (szBuf), INIFILE);
+		(void) GetPrivateProfileString(SECTION,
+			buf, charbuf, szBuf, sizeof (szBuf), INIFILE);
 		w->panex.pyramidChar[pyramid] = szBuf[0];
 	}
-	w->panex.delay = GetPrivateProfileInt(SECTION, "delay",
-		DEFAULT_DELAY, INIFILE);
-	w->panex.sound = (BOOL)
-		GetPrivateProfileInt(SECTION, "sound", 0, INIFILE);
-	(void) GetPrivateProfileString(SECTION, "moveSound", MOVESOUND,
-		szBuf, sizeof (szBuf), INIFILE);
-	(void) GetPrivateProfileString(SECTION, "dripSound", DRIPSOUND,
-		szBuf, sizeof (szBuf), INIFILE);
-	(void) strcpy(w->panex.moveSound, szBuf);
-		w->panex.moveSound[80] = 0;
-	(void) GetPrivateProfileString(SECTION, "userName", "Guest",
-		szBuf, sizeof (szBuf), INIFILE);
-	(void) strcpy(w->panex.userName, szBuf);
-	w->panex.userName[80] = 0;
-	(void) GetPrivateProfileString(SECTION, "scoreFile", "",
-		szBuf, sizeof (szBuf), INIFILE);
-	(void) strcpy(w->panex.scoreFile, szBuf);
-	w->panex.scoreFile[80] = 0;
+	w->panex.delay = GetPrivateProfileInt(SECTION,
+		"delay", DEFAULT_DELAY, INIFILE);
+	w->panex.sound = (BOOL) GetPrivateProfileInt(SECTION,
+		"sound", 0, INIFILE);
+	(void) GetPrivateProfileString(SECTION,
+		"moveSound", MOVESOUND, szBuf, sizeof (szBuf), INIFILE);
+	(void) strncpy(w->panex.moveSound, szBuf, 80);
+	(void) GetPrivateProfileString(SECTION,
+		"dripSound", DRIPSOUND, szBuf, sizeof (szBuf), INIFILE);
+	(void) strncpy(w->panex.dripSound, szBuf, 80);
+	(void) GetPrivateProfileString(SECTION,
+		"userName", "Guest", szBuf, sizeof (szBuf), INIFILE);
+	(void) strncpy(w->panex.userName, szBuf, 80);
+	(void) GetPrivateProfileString(SECTION,
+		"scoreFile", "", szBuf, sizeof (szBuf), INIFILE);
+	(void) strncpy(w->panex.scoreFile, szBuf, 80);
 }
 
 void
@@ -1981,10 +1979,8 @@ destroyPuzzle(Widget old)
 	Display *display = XtDisplay(w);
 	int i;
 
-#if 0
 #if defined( USE_SOUND ) && defined( USE_ESOUND )
 	(void) shutdown_sound();
-#endif
 #endif
 	for (i = 0; i < w->panex.stacks; i++)
 		XtReleaseGC(old, w->panex.pyramidGC[i]);
@@ -2154,12 +2150,10 @@ Widget request, Widget renew
 #ifdef USE_NAS
 	dsp = XtDisplay(w);
 #endif
-#if 0
 #ifdef USE_ESOUND
 	(void) init_sound();
 #endif
 #endif
-#endif
 }
 
 void
