@@ -188,7 +188,7 @@ scanMoves(FILE *fp, PanexWidget w, int moves)
 	for (l = 0; l < moves; l++) {
 		while ((c = getc(fp)) != EOF && c != SYMBOL);
 		(void) fscanf(fp, "%d %d", &fromStack, &toStack);
-#if DEBUG
+#ifdef DEBUG
 		(void) printf("%d %d\n", fromStack, toStack);
 #endif
 		if ((fromPosition = topOfStack(w, fromStack, 0)) < 0 ||
@@ -224,7 +224,7 @@ scanStartPosition(FILE *fp, PanexWidget w)
 			(void) fscanf(fp, "%d %d",
 				&(startLoc[stack][position].stack),
 				&(startLoc[stack][position].loc));
-#if DEBUG
+#ifdef DEBUG
 			(void) printf("%d %d\n",
 				startLoc[stack][position].stack,
 				startLoc[stack][position].loc);
