@@ -1,7 +1,7 @@
 /*
  * @(#)Pyraminx.c
  *
- * Copyright 1994 - 2008  David A. Bagley, bagleyd@tux.org
+ * Copyright 1994 - 2010  David A. Bagley, bagleyd@tux.org
  *
  * All rights reserved.
  *
@@ -99,13 +99,13 @@ static void decrementPuzzle(PyraminxWidget w,
 	XEvent *event, char **args, int nArgs);
 static void orientizePuzzle(PyraminxWidget w,
 	XEvent *event, char **args, int nArgs);
-static void stickymodePuzzle(PyraminxWidget w,
+static void stickyModePuzzle(PyraminxWidget w,
 	XEvent *event, char **args, int nArgs);
 static void period2ModePuzzle(PyraminxWidget w,
 	XEvent *event, char **args, int nArgs);
-static void period3modePuzzle(PyraminxWidget w,
+static void period3ModePuzzle(PyraminxWidget w,
 	XEvent *event, char **args, int nArgs);
-static void bothmodePuzzle(PyraminxWidget w,
+static void bothModePuzzle(PyraminxWidget w,
 	XEvent *event, char **args, int nArgs);
 static void speedUpPuzzle(PyraminxWidget w,
 	XEvent *event, char **args, int nArgs);
@@ -153,6 +153,7 @@ static char translations[] =
  <KeyPress>0x3C: Slow()\n\
  <KeyPress>0x2C: Slow()\n\
  Shift<KeyPress>2: Sound()\n\
+ <KeyPress>F11: MoveCcw()\n\
  <KeyPress>KP_Divide: MoveCcw()\n\
  <KeyPress>R5: MoveCcw()\n\
  <KeyPress>Up: MoveTop()\n\
@@ -168,6 +169,7 @@ static char translations[] =
  <KeyPress>KP_Left: MoveLeft()\n\
  <KeyPress>KP_4: MoveLeft()\n\
  <KeyPress>R10: MoveLeft()\n\
+ <KeyPress>F12: MoveCw()\n\
  <KeyPress>Begin: MoveCw()\n\
  <KeyPress>KP_5: MoveCw()\n\
  <KeyPress>R11: MoveCw()\n\
@@ -240,9 +242,9 @@ static XtActionsRec actionsList[] =
 	{(char *) "Decrement", (XtActionProc) decrementPuzzle},
 	{(char *) "Orientize", (XtActionProc) orientizePuzzle},
 	{(char *) "Period2", (XtActionProc) period2ModePuzzle},
-	{(char *) "Period3", (XtActionProc) period3modePuzzle},
-	{(char *) "Both", (XtActionProc) bothmodePuzzle},
-	{(char *) "Sticky", (XtActionProc) stickymodePuzzle},
+	{(char *) "Period3", (XtActionProc) period3ModePuzzle},
+	{(char *) "Both", (XtActionProc) bothModePuzzle},
+	{(char *) "Sticky", (XtActionProc) stickyModePuzzle},
 	{(char *) "Speed", (XtActionProc) speedUpPuzzle},
 	{(char *) "Slow", (XtActionProc) slowDownPuzzle},
 	{(char *) "Sound", (XtActionProc) toggleSoundPuzzle},
@@ -2388,42 +2390,42 @@ setValuesPuzzle(PyraminxWidget w)
 	char szBuf[80], buf[20], charbuf[2];
 	int face;
 
-	w->pyraminx.size = GetPrivateProfileInt(SECTION, "size",
-		DEFAULTFACETS, INIFILE);
-	w->pyraminx.mode = GetPrivateProfileInt(SECTION, "mode",
-		DEFAULT_MODE, INIFILE);
-	w->pyraminx.sticky = (BOOL) GetPrivateProfileInt(SECTION, "sticky",
-		DEFAULTSTICKY, INIFILE);
-	w->pyraminx.orient = (BOOL) GetPrivateProfileInt(SECTION, "orient",
-		DEFAULT_ORIENT, INIFILE);
-	w->pyraminx.practice = (BOOL) GetPrivateProfileInt(SECTION, "practice",
-		DEFAULT_PRACTICE, INIFILE);
-	w->pyraminx.mono = (BOOL) GetPrivateProfileInt(SECTION, "mono",
-		DEFAULT_MONO, INIFILE);
-	w->pyraminx.reverse = (BOOL) GetPrivateProfileInt(SECTION, "reverseVideo",
-		DEFAULT_REVERSE, INIFILE);
+	w->pyraminx.size = GetPrivateProfileInt(SECTION,
+		"size", DEFAULTFACETS, INIFILE);
+	w->pyraminx.mode = GetPrivateProfileInt(SECTION,
+		"mode", DEFAULT_MODE, INIFILE);
+	w->pyraminx.sticky = (BOOL) GetPrivateProfileInt(SECTION,
+		"sticky", DEFAULTSTICKY, INIFILE);
+	w->pyraminx.orient = (BOOL) GetPrivateProfileInt(SECTION,
+		"orient", DEFAULT_ORIENT, INIFILE);
+	w->pyraminx.practice = (BOOL) GetPrivateProfileInt(SECTION,
+		"practice", DEFAULT_PRACTICE, INIFILE);
+	w->pyraminx.mono = (BOOL) GetPrivateProfileInt(SECTION,
+		"mono", DEFAULT_MONO, INIFILE);
+	w->pyraminx.reverse = (BOOL) GetPrivateProfileInt(SECTION,
+		"reverseVideo", DEFAULT_REVERSE, INIFILE);
 	/* cyan */
-	(void) GetPrivateProfileString(SECTION, "frameColor", "0 255 255",
-		szBuf, sizeof (szBuf), INIFILE);
+	(void) GetPrivateProfileString(SECTION,
+		"frameColor", "0 255 255", szBuf, sizeof (szBuf), INIFILE);
 	(void) sscanf(szBuf, "%d %d %d",
 		&(color.red), &(color.green), &(color.blue));
 	w->pyraminx.frameGC = RGB(color.red, color.green, color.blue);
 	/* gray25 */
-	(void) GetPrivateProfileString(SECTION, "pieceBorder", "64 64 64",
-		szBuf, sizeof (szBuf), INIFILE);
+	(void) GetPrivateProfileString(SECTION,
+		"pieceBorder", "64 64 64", szBuf, sizeof (szBuf), INIFILE);
 	(void) sscanf(szBuf, "%d %d %d",
 		&(color.red), &(color.green), &(color.blue));
 	w->pyraminx.borderGC = RGB(color.red, color.green, color.blue);
 	/* #AEB2C3 */
-	(void) GetPrivateProfileString(SECTION, "background", "174 178 195",
-		szBuf, sizeof (szBuf), INIFILE);
+	(void) GetPrivateProfileString(SECTION,
+		"background", "174 178 195", szBuf, sizeof (szBuf), INIFILE);
 	(void) sscanf(szBuf, "%d %d %d",
 		&(color.red), &(color.green), &(color.blue));
 	w->pyraminx.inverseGC = RGB(color.red, color.green, color.blue);
 	for (face = 0; face < MAX_FACES; face++) {
 		(void) sprintf(buf, "faceColor%d", face);
-		(void) GetPrivateProfileString(SECTION, buf,
-			faceColorString[face],
+		(void) GetPrivateProfileString(SECTION,
+			buf, faceColorString[face],
 			szBuf, sizeof (szBuf), INIFILE);
 		(void) sscanf(szBuf, "%d %d %d",
 			&(color.red), &(color.green), &(color.blue));
@@ -2432,18 +2434,23 @@ setValuesPuzzle(PyraminxWidget w)
 		(void) sprintf(buf, "faceChar%d", face);
 		charbuf[0] = faceColorChar[face];
 		charbuf[1] = '\0';
-		(void) GetPrivateProfileString(SECTION, buf, charbuf,
-			szBuf, sizeof (szBuf), INIFILE);
+		(void) GetPrivateProfileString(SECTION,
+			buf, charbuf, szBuf, sizeof (szBuf), INIFILE);
 		w->pyraminx.faceChar[face] = szBuf[0];
 	}
-	(void) GetPrivateProfileString(SECTION, "userName", "Guest",
-		szBuf, sizeof (szBuf), INIFILE);
-	(void) strcpy(w->pyraminx.userName, szBuf);
-		w->pyraminx.userName[80] = 0;
-	(void) GetPrivateProfileString(SECTION, "scoreFile", "",
-		szBuf, sizeof (szBuf), INIFILE);
-	(void) strcpy(w->pyraminx.scoreFile, szBuf);
-		w->pyraminx.scoreFile[80] = 0;
+	w->pyraminx.delay = GetPrivateProfileInt(SECTION,
+		"delay", 10, INIFILE);
+	w->pyraminx.sound = (BOOL) GetPrivateProfileInt(SECTION,
+		"sound", FALSE, INIFILE);
+	(void) GetPrivateProfileString(SECTION,
+		"moveSound", MOVESOUND, szBuf, sizeof (szBuf), INIFILE);
+	(void) strncpy(w->pyraminx.moveSound, szBuf, 80);
+	(void) GetPrivateProfileString(SECTION,
+		"userName", "Guest", szBuf, sizeof (szBuf), INIFILE);
+	(void) strncpy(w->pyraminx.userName, szBuf, 80);
+	(void) GetPrivateProfileString(SECTION,
+		"scoreFile", "", szBuf, sizeof (szBuf), INIFILE);
+	(void) strncpy(w->pyraminx.scoreFile, szBuf, 80);
 }
 
 void
@@ -2668,10 +2675,8 @@ destroyPuzzle(Widget old)
 	Display *display = XtDisplay(w);
 	int face;
 
-#if 0
 #if defined( USE_SOUND ) && defined( USE_ESOUND )
 	(void) shutdown_sound();
-#endif
 #endif
 	for (face = 0; face < MAX_FACES; face++)
 		XtReleaseGC(old, w->pyraminx.faceGC[face]);
@@ -2800,12 +2805,10 @@ Widget request, Widget renew
 #ifdef USE_NAS
 	dsp = XtDisplay(w);
 #endif
-#if 0
 #ifdef USE_ESOUND
 	(void) init_sound();
 #endif
 #endif
-#endif
 }
 
 #ifndef WINVER
@@ -3138,7 +3141,7 @@ orientizePuzzle(PyraminxWidget w
 static
 #endif
 void
-stickymodePuzzle(PyraminxWidget w
+stickyModePuzzle(PyraminxWidget w
 #ifndef WINVER
 , XEvent *event, char **args, int nArgs
 #endif
@@ -3157,7 +3160,7 @@ period2ModePuzzle(PyraminxWidget w
 }
 
 static void
-period3modePuzzle(PyraminxWidget w
+period3ModePuzzle(PyraminxWidget w
 , XEvent *event, char **args, int nArgs
 )
 {
@@ -3166,7 +3169,7 @@ period3modePuzzle(PyraminxWidget w
 
 static
 void
-bothmodePuzzle(PyraminxWidget w
+bothModePuzzle(PyraminxWidget w
 , XEvent *event, char **args, int nArgs
 )
 {
@@ -3243,7 +3246,7 @@ leavePuzzle(PyraminxWidget w
 
 #ifdef WINVER
 void
-periodmodePuzzle(PyraminxWidget w, const int mode)
+periodModePuzzle(PyraminxWidget w, const int mode)
 {
 	setPuzzle(w, mode + ACTION_PERIOD2);
 }
