@@ -6,7 +6,7 @@
  * and Puzzles by John Ewing & Czes Kosniowski)
  * Break ability taken from the X puzzle by Don Bennett, HP Labs
  *
- * Copyright 1999 - 2008  David A. Bagley, bagleyd@tux.org
+ * Copyright 1999 - 2010  David A. Bagley, bagleyd@tux.org
  *
  * All rights reserved.
  *
@@ -59,38 +59,14 @@
 #define B_MINUS_WHOLE rotateWholeCCW(w,topFaceTrans(topFace,1)) /* Bottom Corner CCW */
 
 
-typedef struct _PyraminxSLoc {
-	int face, position;
-} PyraminxSLoc;
-
-static int IndexToEdges[3] =
-{ 1, 3, 6};
-
-static int EdgesToIndex[9] =
-{ 3, 0, 3, 1, 3, 3, 2, 3, 3};
-
-static PyraminxSLoc EdgeMate[MAX_FACES][3] =
+static int indexToEdges[3] = {1, 3, 6};
+static int edgesToIndex[9] = {3, 0, 3, 1, 3, 3, 2, 3, 3};
+static int edgeMateFace[MAX_FACES][3] =
 {
-	{
-		{2, 1},
-		{3, 3},
-		{1, 6},
-	},
-	{
-		{3, 1},
-		{2, 3},
-		{0, 6},
-	},
-	{
-		{0, 1},
-		{1, 3},
-		{3, 6},
-	},
-	{
-		{1, 1},
-		{0, 3},
-		{2, 6},
-	}
+	{2, 3, 1},
+	{3, 2, 0},
+	{0, 1, 3},
+	{1, 0, 2}
 };
 
 static Boolean solvingFlag = False;
@@ -259,13 +235,13 @@ checkPiece(PyraminxWidget w, int color, int face, int position)
 {
 	int newFace, newPosition, positionIndex;
 
-	positionIndex = EdgesToIndex[position];
+	positionIndex = edgesToIndex[position];
 	if (positionIndex == 3) {
 		positionIndex = 0;
 		(void) printf("position %d incorrect\n", position);
 	}
-	newFace = EdgeMate[face][positionIndex].face;
-	newPosition = EdgeMate[face][positionIndex].position;
+	newFace = edgeMateFace[face][positionIndex];
+	newPosition = indexToEdges[positionIndex];
 	if (w->pyraminx.facetLoc[newFace][newPosition].face == color) {
 		return True;
 	}
@@ -279,7 +255,7 @@ findPiece(PyraminxWidget w, int color0, int color1, int *face, int *position)
 
 	/* Check starting face first */
 	for (positionIndex = 0; positionIndex < 3; positionIndex++) {
-		*position = IndexToEdges[positionIndex];
+		*position = indexToEdges[positionIndex];
 		if (w->pyraminx.facetLoc[*face][*position].face == color0 &&
 				checkPiece(w, color1, *face, *position)) {
 			return;
@@ -293,7 +269,7 @@ findPiece(PyraminxWidget w, int color0, int color1, int *face, int *position)
 	for (*face = 0; *face < MAX_FACES; (*face)++) {
 		if (*face != faceSkip) {
 			for (positionIndex = 0; positionIndex < 3; positionIndex++) {
-				*position = IndexToEdges[positionIndex];
+				*position = indexToEdges[positionIndex];
 				if (w->pyraminx.facetLoc[*face][*position].face == color0 &&
 						checkPiece(w, color1, *face, *position)) {
 					return;
@@ -343,9 +319,8 @@ faceCorners(PyraminxWidget w, int face, int faceColor)
 static void
 faceEdge(PyraminxWidget w, int topFace, int position, int faceColor)
 {
-	int color0, color1, newFace, newPosition;
+	int otherColor, newFace, newPosition;
 
-	color0 = w->pyraminx.facetLoc[topFace][2].face;
 	switch (position) {
 		case 1:
 			newFace = (topFace + 2) % 4;
@@ -362,26 +337,26 @@ faceEdge(PyraminxWidget w, int topFace, int position, int faceColor)
 		default:
 			(void) printf("Wrong position %d.\n", position);
 	}
-	color1 = w->pyraminx.facetLoc[newFace][newPosition].face;
+	otherColor = w->pyraminx.facetLoc[newFace][newPosition].face;
 	/* newFace and newPosition variables are reused here */
-	newFace = topFace; /* This makes narrows down cases */
-	findPiece(w, color0, color1, &newFace, &newPosition);
-	(void) printf("topFace %d, position %d, newFace %d, newPosition %d, color0 %d, color1 %d\n", topFace, position, newFace, newPosition, color0, color1);
+	newFace = topFace; /* This narrows down the cases */
+	findPiece(w, faceColor, otherColor, &newFace, &newPosition);
+	(void) printf("topFace %d, position %d, newFace %d, newPosition %d, faceColor %d, otherColor %d\n", topFace, position, newFace, newPosition, faceColor, otherColor);
 }
 #else
+/* Move to position 6 and then into correct position. */
 static void
 faceEdge6(PyraminxWidget w, int topFace, int faceColor)
 {
-	int color0, color1, newFace, newPosition, position;
+	int otherColor, newFace, newPosition, position;
 
 	position = 6;
-	color0 = w->pyraminx.facetLoc[topFace][2].face;
 	newFace = MAX_FACES - 1 - ((topFace + 2) % 4);
 	newPosition = position - 1;
-	color1 = w->pyraminx.facetLoc[newFace][newPosition].face;
+	otherColor = w->pyraminx.facetLoc[newFace][newPosition].face;
 	/* newFace and newPosition variables are reused here */
-	newFace = topFace; /* This makes narrows down cases below */
-	findPiece(w, color0, color1, &newFace, &newPosition);
+	newFace = topFace; /* This narrows down the cases below */
+	findPiece(w, faceColor, otherColor, &newFace, &newPosition);
 	if (newFace == topFace) {
 		switch (newPosition) {
 			case 1: /* Move LT to FT */
