@@ -1,7 +1,7 @@
 /*
  * @(#)xpyraminx.c
  *
- * Copyright 1993 - 2009  David A. Bagley, bagleyd@tux.org
+ * Copyright 1993 - 2010  David A. Bagley, bagleyd@tux.org
  *
  * All rights reserved.
  *
@@ -21,8 +21,9 @@
 /* Driver file for Pyraminx */
 
 #ifndef WINVER
+#include "version.h"
 static const char aboutHelp[] = {
-"Pyraminx Version 7.5\n"
+"Pyraminx Version " VERSION "\n"
 "Send bugs (reports or fixes) to the author: "
 "David Bagley <bagleyd@tux.org>\n"
 "The latest version is at: "
@@ -433,6 +434,7 @@ writeRecords(void)
 		char lockFile[FILE_NAME_LENGTH];
 
 		(void) strncpy(lockFile, fileName, FILE_NAME_LENGTH - 6);
+		lockFile[FILE_NAME_LENGTH - 6] = '\0';
 		(void) strcat(lockFile, ".lock");
 		while (((lfd = open(lockFile, O_CREAT | O_EXCL, 0644)) < 0) &&
 				errno == EEXIST)
@@ -921,7 +923,6 @@ puzzleListener(Widget w, caddr_t clientData,
 		}
 		return;
 #endif
-
 	}
 	printStatus(messageDsp, movesDsp
 #ifndef HAVE_MOTIF
@@ -1104,7 +1105,7 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 			(void) InvalidateRect(hWnd, NULL, TRUE);
 			break;
 		case ACTION_STICKY:
-			(void) stickymodePuzzle(&widget);
+			(void) stickyModePuzzle(&widget);
 			sizePuzzle(&widget);
 			(void) InvalidateRect(hWnd, NULL, TRUE);
 			break;
@@ -1194,7 +1195,7 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 		case ACTION_PERIOD2:
 		case ACTION_PERIOD3:
 		case ACTION_BOTH:
-			periodmodePuzzle(&widget,
+			periodModePuzzle(&widget,
 				(int) LOWORD(wParam) - ACTION_PERIOD2);
 			sizePuzzle(&widget);
 			(void) InvalidateRect(hWnd, NULL, TRUE);
