@@ -1,7 +1,7 @@
 /*
  * @(#)Rubik.c
  *
- * Copyright 1994 - 2008  David A. Bagley, bagleyd@tux.org
+ * Copyright 1994 - 2010  David A. Bagley, bagleyd@tux.org
  *
  * All rights reserved.
  *
@@ -425,6 +425,16 @@ drawSquare(const RubikWidget w, const int face, const int position, const int of
 		drawSquare3D((Rubik3DWidget) w, face, position, offset);
 }
 
+static void
+drawSquareAll(const RubikWidget w, const int face, const int position, const int offset)
+{
+	drawSquare(w, face, position, offset);
+#ifdef HAVE_OPENGL
+	if (w->rubik.dim == 4)
+		drawAllPiecesGL((RubikGLWidget) w);
+#endif
+}
+
 void
 drawAllPieces(const RubikWidget w)
 {
@@ -470,7 +480,7 @@ rotateFace(RubikWidget w, int face, int direction)
 	sizeOnPlane = sizeOfRow * sizeOfColumn;
 	if ((faceLoc = (RubikLoc *) malloc(sizeOnPlane * sizeof (RubikLoc))) ==
 				NULL) {
-			DISPLAY_ERROR("Not enough memory for rubik face position info, exiting.");
+		DISPLAY_ERROR("Not enough memory for rubik face position info, exiting.");
 	}
 	/* Read Face */
 	for (position = 0; position < sizeOnPlane; position++)
@@ -786,14 +796,20 @@ movePuzzleDelay(RubikWidget w, const int face, const int position,
 }
 
 static Boolean
-selectPieces(RubikWidget w, const int x, const int y, int *face, int *position)
+selectPieces(RubikWidget w, const int x, const int y,
+		int *face, int *position)
 {
 	if (w->rubik.dim == 2)
 		return selectPieces2D((Rubik2DWidget) w, x, y,
-					face, position);
+			face, position);
 	else if (w->rubik.dim == 3)
 		return selectPieces3D((Rubik3DWidget) w, x, y,
-					face, position);
+			face, position);
+#ifdef HAVE_OPENGL
+	else if (w->rubik.dim == 4)
+		return selectPiecesGL((RubikGLWidget) w, x, y,
+			face, position);
+#endif
 	return False;
 }
 
@@ -828,6 +844,10 @@ narrowSelection(RubikWidget w, int *face, int *position, int *direction)
 		return narrowSelection2D((Rubik2DWidget) w, face, position, direction);
 	else if (w->rubik.dim == 3)
 		return narrowSelection3D((Rubik3DWidget) w, face, position, direction);
+#ifdef HAVE_OPENGL
+	else if (w->rubik.dim == 4)
+		return narrowSelectionGL((RubikGLWidget) w, face, position, direction);
+#endif
 	return False;
 }
 
@@ -1035,6 +1055,7 @@ getPieces(RubikWidget w)
 	free(lname);
 	free(fname);
 	w->rubik.cheat = True; /* Assume the worst. */
+	setPuzzle(w, ACTION_CHEAT);
 }
 
 static void
@@ -1157,6 +1178,7 @@ randomizePieces(RubikWidget w)
 			3 + NRAND(2);
 
 	w->rubik.cheat = False;
+	setPuzzle(w, ACTION_CHEAT);
 	if (big > 100)
 		big = 100;
 	if (w->rubik.practice)
@@ -1184,8 +1206,8 @@ solvePieces(RubikWidget w)
 {
 	if (checkSolved(w, w->rubik.orient))
 		return;
-	if ((w->rubik.sizex == 2 && w->rubik.sizey == 2 && w->rubik.sizez == 2) ||
-	    (w->rubik.sizex == 3 && w->rubik.sizey == 3 && w->rubik.sizez == 3))
+	if (w->rubik.sizex == w->rubik.sizey && w->rubik.sizex == w->rubik.sizez &&
+			w->rubik.sizex < 4)
 		solveSomePieces(w);
 	else {
 		setPuzzle(w, ACTION_SOLVE_MESSAGE);
@@ -1262,43 +1284,48 @@ setValuesPuzzle(RubikWidget w)
 	char szBuf[80], buf[20], charbuf[2];
 	int face;
 
-	w->rubik.sizex = GetPrivateProfileInt(SECTION, "sizeX",
-		DEFAULTFACETS, INIFILE);
-	w->rubik.sizey = GetPrivateProfileInt(SECTION, "sizeY",
-		DEFAULTFACETS, INIFILE);
-	w->rubik.sizez = GetPrivateProfileInt(SECTION, "sizeZ",
-		DEFAULTFACETS, INIFILE);
-	w->rubik.orient = (BOOL) GetPrivateProfileInt(SECTION, "orient",
-		DEFAULT_ORIENT, INIFILE);
-	w->rubik.practice = (BOOL) GetPrivateProfileInt(SECTION, "practice",
-		DEFAULT_PRACTICE, INIFILE);
+	w->rubik.sizex = GetPrivateProfileInt(SECTION,
+		"sizeX", DEFAULTFACETS, INIFILE);
+	w->rubik.sizey = GetPrivateProfileInt(SECTION,
+		"sizeY", DEFAULTFACETS, INIFILE);
+	w->rubik.sizez = GetPrivateProfileInt(SECTION,
+		"sizeZ", DEFAULTFACETS, INIFILE);
+	w->rubik.orient = (BOOL) GetPrivateProfileInt(SECTION,
+		"orient", DEFAULT_ORIENT, INIFILE);
+	w->rubik.practice = (BOOL) GetPrivateProfileInt(SECTION,
+		"practice", DEFAULT_PRACTICE, INIFILE);
+#ifdef HAVE_OPENGL
+	w->rubik.dim = GetPrivateProfileInt(SECTION, "dim", 4, INIFILE);
+#else
 	w->rubik.dim = GetPrivateProfileInt(SECTION, "dim", 3, INIFILE);
-	w->rubik.mono = (BOOL) GetPrivateProfileInt(SECTION, "mono",
-		DEFAULT_MONO, INIFILE);
-	w->rubik.reverse = (BOOL) GetPrivateProfileInt(SECTION, "reverseVideo",
-		DEFAULT_REVERSE, INIFILE);
-	/* cyan */
-	(void) GetPrivateProfileString(SECTION, "frameColor", "0 255 255",
-		szBuf, sizeof (szBuf), INIFILE);
+#endif
+	w->rubik.view = GetPrivateProfileInt(SECTION, "view", 1, INIFILE);
+	w->rubik.mono = (BOOL) GetPrivateProfileInt(SECTION,
+		"mono", DEFAULT_MONO, INIFILE);
+	w->rubik.reverse = (BOOL) GetPrivateProfileInt(SECTION,
+		"reverseVideo", DEFAULT_REVERSE, INIFILE);
+	/* Cyan */
+	(void) GetPrivateProfileString(SECTION,
+		"frameColor", "0 255 255", szBuf, sizeof (szBuf), INIFILE);
 	(void) sscanf(szBuf, "%d %d %d",
 		&(color.red), &(color.green), &(color.blue));
 	w->rubik.frameGC = RGB(color.red, color.green, color.blue);
 	/* gray25 */
-	(void) GetPrivateProfileString(SECTION, "pieceBorder", "64 64 64",
-		szBuf, sizeof (szBuf), INIFILE);
+	(void) GetPrivateProfileString(SECTION,
+		"pieceBorder", "64 64 64", szBuf, sizeof (szBuf), INIFILE);
 	(void) sscanf(szBuf, "%d %d %d",
 		&(color.red), &(color.green), &(color.blue));
 	w->rubik.borderGC = RGB(color.red, color.green, color.blue);
 	/* #AEB2C3 */
-	(void) GetPrivateProfileString(SECTION, "background", "174 178 195",
-		szBuf, sizeof (szBuf), INIFILE);
+	(void) GetPrivateProfileString(SECTION,
+		"background", "174 178 195", szBuf, sizeof (szBuf), INIFILE);
 	(void) sscanf(szBuf, "%d %d %d",
 		&(color.red), &(color.green), &(color.blue));
 	w->rubik.inverseGC = RGB(color.red, color.green, color.blue);
 	for (face = 0; face < MAX_FACES; face++) {
 		(void) sprintf(buf, "faceColor%d", face);
-		(void) GetPrivateProfileString(SECTION, buf,
-			faceColorString[face],
+		(void) GetPrivateProfileString(SECTION,
+			buf, faceColorString[face],
 			szBuf, sizeof (szBuf), INIFILE);
 		(void) sscanf(szBuf, "%d %d %d",
 			&(color.red), &(color.green), &(color.blue));
@@ -1307,18 +1334,23 @@ setValuesPuzzle(RubikWidget w)
 		(void) sprintf(buf, "faceChar%d", face);
 		charbuf[0] = faceColorChar[face];
 		charbuf[1] = '\0';
-		(void) GetPrivateProfileString(SECTION, buf, charbuf,
-			szBuf, sizeof (szBuf), INIFILE);
+		(void) GetPrivateProfileString(SECTION,
+			buf, charbuf, szBuf, sizeof (szBuf), INIFILE);
 		w->rubik.faceChar[face] = szBuf[0];
 	}
-	(void) GetPrivateProfileString(SECTION, "userName", "Guest",
-		szBuf, sizeof (szBuf), INIFILE);
-	(void) strcpy(w->rubik.userName, szBuf);
-		w->rubik.userName[80] = 0;
-	(void) GetPrivateProfileString(SECTION, "scoreFile", "",
-		szBuf, sizeof (szBuf), INIFILE);
-	(void) strcpy(w->rubik.scoreFile, szBuf);
-		w->rubik.scoreFile[80] = 0;
+	w->rubik.delay = GetPrivateProfileInt(SECTION,
+		"delay", 10, INIFILE);
+	w->rubik.sound = (BOOL) GetPrivateProfileInt(SECTION,
+		"sound", FALSE, INIFILE);
+	(void) GetPrivateProfileString(SECTION,
+		"moveSound", MOVESOUND, szBuf, sizeof (szBuf), INIFILE);
+	(void) strncpy(w->rubik.moveSound, szBuf, 80);
+	(void) GetPrivateProfileString(SECTION,
+		"userName", "Guest", szBuf, sizeof (szBuf), INIFILE);
+	(void) strncpy(w->rubik.userName, szBuf, 80);
+	(void) GetPrivateProfileString(SECTION,
+		"scoreFile", "", szBuf, sizeof (szBuf), INIFILE);
+	(void) strncpy(w->rubik.scoreFile, szBuf, 80);
 }
 
 void
@@ -1571,10 +1603,15 @@ setValuesPuzzle(Widget current, Widget request, Widget renew)
 		redraw = True;
 		w->rubik.currentDirection = IGNORE_DIR;
 	} else if (w->rubik.currentDirection > IGNORE_DIR) {
-		(void) moveAllPieces(w, w->rubik.currentFace,
-			w->rubik.currentPosition, w->rubik.currentDirection,
-			w->rubik.currentControl, w->rubik.currentFast);
+		int face = w->rubik.currentFace;
+		int position = w->rubik.currentPosition;
+		int direction = w->rubik.currentDirection;
+
+		w->rubik.currentFace = IGNORE_DIR;
+		w->rubik.currentPosition = IGNORE_DIR;
 		w->rubik.currentDirection = IGNORE_DIR;
+		(void) moveAllPieces(w, face, position, direction,
+			w->rubik.currentControl, w->rubik.currentFast);
 	}
 	return redraw;
 }
@@ -1586,10 +1623,9 @@ destroyPuzzle(Widget old)
 	Display *display = XtDisplay(w);
 	int face;
 
-#if 0
 #if defined( USE_SOUND ) && defined( USE_ESOUND )
-	(void) shutdown_sound();
-#endif
+	if (w->rubik.dim == 2)
+		(void) shutdown_sound();
 #endif
 	for (face = 0; face < MAX_FACES; face++)
 		XtReleaseGC(old, w->rubik.faceGC[face]);
@@ -1662,10 +1698,9 @@ Widget request, Widget renew
 #ifdef USE_NAS
 	dsp = XtDisplay(w);
 #endif
-#if 0
 #ifdef USE_ESOUND
-	(void) init_sound();
-#endif
+	if (w->rubik.dim == 2)
+		(void) init_sound();
 #endif
 #endif
 }
@@ -1697,11 +1732,15 @@ selectPuzzle(RubikWidget w
 	if (selectPieces(w, x, y,
 		     &(w->rubik.currentFace), &(w->rubik.currentPosition))) {
 		if (control || w->rubik.practice || !checkSolved(w, w->rubik.orient))
-			drawSquare(w, w->rubik.currentFace, w->rubik.currentPosition,
+			drawSquareAll(w, w->rubik.currentFace, w->rubik.currentPosition,
 				TRUE);
 	} else {
 		w->rubik.currentFace = IGNORE_DIR;
 		w->rubik.currentDirection = IGNORE_DIR;
+#ifdef HAVE_OPENGL
+		if (w->rubik.dim == 4)
+			drawAllPiecesGL((RubikGLWidget) w);
+#endif
 	}
 }
 
@@ -1738,18 +1777,28 @@ releasePuzzle(RubikWidget w
 			must also be able to handle double moves */
 		}
 		if (count == 1) {
-			movePuzzle(w, w->rubik.currentFace, w->rubik.currentPosition,
+			face = w->rubik.currentFace;
+			position = w->rubik.currentPosition;
+			w->rubik.currentFace = IGNORE_DIR;
+			w->rubik.currentPosition = IGNORE_DIR;
+			movePuzzle(w, face, position,
 				direction, (control) ? 1 : 0, NORMAL);
 			if (!control && checkSolved(w, w->rubik.orient)) {
 				setPuzzle(w, ACTION_SOLVED);
 			}
 		} else if (count == 2) {
 			setPuzzle(w, ACTION_AMBIGUOUS);
-		} else if (count == 0)
+		} else if (count == 0) {
 			moveNoPieces(w);
+		}
 	}
 	w->rubik.currentFace = IGNORE_DIR;
 	w->rubik.currentDirection = IGNORE_DIR;
+#ifdef HAVE_OPENGL
+	if (w->rubik.dim == 4 && count != 1) {
+		drawAllPiecesGL((RubikGLWidget) w);
+	}
+#endif
 }
 
 #ifndef WINVER
