@@ -1,7 +1,7 @@
 /*
  * @(#)Rubik3d.c
  *
- * Copyright 1994 - 2008  David A. Bagley, bagleyd@tux.org
+ * Copyright 1994 - 2010  David A. Bagley, bagleyd@tux.org
  *
  * All rights reserved.
  *
@@ -58,6 +58,7 @@ static char translations3D[] =
  <KeyPress>0x3C: Slow()\n\
  <KeyPress>0x2C: Slow()\n\
  Shift<KeyPress>2: Sound()\n\
+ <KeyPress>F11: MoveCcw()\n\
  <KeyPress>KP_Divide: MoveCcw()\n\
  <KeyPress>R5: MoveCcw()\n\
  <KeyPress>Home: MoveTl()\n\
@@ -76,6 +77,7 @@ static char translations3D[] =
  <KeyPress>KP_Left: MoveLeft()\n\
  <KeyPress>KP_4: MoveLeft()\n\
  <KeyPress>R10: MoveLeft()\n\
+ <KeyPress>F12: MoveCw()\n\
  <KeyPress>Begin: MoveCw()\n\
  <KeyPress>KP_5: MoveCw()\n\
  <KeyPress>R11: MoveCw()\n\
@@ -185,25 +187,25 @@ static XtResource resources3D[] =
 	 XtRString, (caddr_t) "#AEB2C3" /*XtDefaultBackground*/},
 	{XtNframeColor, XtCColor, XtRPixel, sizeof (Pixel),
 	 XtOffset(RubikWidget, rubik.frameColor),
-	 XtRString, (caddr_t) "cyan" /*XtDefaultForeground*/},
+	 XtRString, (caddr_t) "Cyan" /*XtDefaultForeground*/},
 	{XtNfaceColor0, XtCLabel, XtRString, sizeof (String),
 	 XtOffset(RubikWidget, rubik.faceName[0]),
-	 XtRString, (caddr_t) "red"},
+	 XtRString, (caddr_t) "Red"},
 	{XtNfaceColor1, XtCLabel, XtRString, sizeof (String),
 	 XtOffset(RubikWidget, rubik.faceName[1]),
-	 XtRString, (caddr_t) "yellow"},
+	 XtRString, (caddr_t) "Yellow"},
 	{XtNfaceColor2, XtCLabel, XtRString, sizeof (String),
 	 XtOffset(RubikWidget, rubik.faceName[2]),
-	 XtRString, (caddr_t) "white"},
+	 XtRString, (caddr_t) "White"},
 	{XtNfaceColor3, XtCLabel, XtRString, sizeof (String),
 	 XtOffset(RubikWidget, rubik.faceName[3]),
-	 XtRString, (caddr_t) "green"},
+	 XtRString, (caddr_t) "Green"},
 	{XtNfaceColor4, XtCLabel, XtRString, sizeof (String),
 	 XtOffset(RubikWidget, rubik.faceName[4]),
-	 XtRString, (caddr_t) "orange"},
+	 XtRString, (caddr_t) "Orange"},
 	{XtNfaceColor5, XtCLabel, XtRString, sizeof (String),
 	 XtOffset(RubikWidget, rubik.faceName[5]),
-	 XtRString, (caddr_t) "blue"},
+	 XtRString, (caddr_t) "Blue"},
 	{XtNpieceBorder, XtCColor, XtRPixel, sizeof (Pixel),
 	 XtOffset(RubikWidget, rubik.borderColor),
 	 XtRString, (caddr_t) "gray25" /*XtDefaultForeground*/},
