@@ -1,7 +1,7 @@
 /*
  * @(#)xrubik.c
  *
- * Copyright 1993 - 2009  David A. Bagley, bagleyd@tux.org
+ * Copyright 1993 - 2010  David A. Bagley, bagleyd@tux.org
  *
  * All rights reserved.
  *
@@ -21,8 +21,9 @@
 /* Driver file for Rubik */
 
 #ifndef WINVER
+#include "version.h"
 static const char aboutHelp[] = {
-"Rubik Version 7.5\n"
+"Rubik Version " VERSION "\n"
 "Send bugs (reports or fixes) to the author: "
 "David Bagley <bagleyd@tux.org>\n"
 "The latest version is at: "
@@ -213,9 +214,10 @@ static RubikRec widget;
 #define SET_STARTED(w,b) XtVaSetValues(w, XtNstart, b, NULL)
 #include "Rubik.h"
 #include "Rubik2d.h"
-#include "Rubik3d.h"
 #ifdef HAVE_OPENGL
 #include "RubikGL.h"
+#else
+#include "Rubik3d.h"
 #endif
 #ifdef HAVE_XPM
 #include <X11/xpm.h>
@@ -297,15 +299,9 @@ static Widget solveDialog, practiceDialog, randomizeDialog;
 static Arg arg[3];
 #else
 static Widget shell;
-#ifdef HAVE_OPENGL
-static Widget shellGL;
-#endif
 #endif
 static Pixmap pixmap = None;
 static Widget topLevel, puzzle2d, puzzle3d;
-#ifdef HAVE_OPENGL
-static Widget puzzleGL;
-#endif
 static char *progDsp;
 static char userNameDsp[USER_NAME_LENGTH] = "";
 
@@ -461,6 +457,7 @@ writeRecords(void)
 		char lockFile[FILE_NAME_LENGTH];
 
 		(void) strncpy(lockFile, fileName, FILE_NAME_LENGTH - 6);
+		lockFile[FILE_NAME_LENGTH - 6] = '\0';
 		(void) strcat(lockFile, ".lock");
 		while (((lfd = open(lockFile, O_CREAT | O_EXCL, 0644)) < 0) &&
 				errno == EEXIST)
@@ -592,29 +589,6 @@ makeEquivalent(String *userName, String *scoreFile,
 		XtNfaceColor3, faceColor[3],
 		XtNfaceColor4, faceColor[4],
 		XtNfaceColor5, faceColor[5], NULL);
-#ifdef HAVE_OPENGL
-	XtVaSetValues(puzzleGL,
-		XtNuserName, *userName,
-		XtNsizex, *sizex,
-		XtNsizey, *sizey,
-		XtNsizez, *sizez,
-		XtNorient, *orient,
-		XtNpractice, *practice,
-		XtNmono, mono,
-		XtNreverseVideo, reverse,
-		XtNdelay, *delay,
-		XtNdirection, IGNORE_DIR,
-		XtNstart, False,
-		XtNforeground, foreground,
-		XtNbackground, background,
-		XtNpieceBorder, pieceBorder,
-		XtNfaceColor0, faceColor[0],
-		XtNfaceColor1, faceColor[1],
-		XtNfaceColor2, faceColor[2],
-		XtNfaceColor3, faceColor[3],
-		XtNfaceColor4, faceColor[4],
-		XtNfaceColor5, faceColor[5], NULL);
-#endif
 }
 #endif
 
@@ -643,11 +617,6 @@ printStatus(char *msg, int nMoves
 #ifdef WINVER
 	SetWindowText(widget.core.hWnd, (LPSTR) titleDsp);
 #else
-#ifdef HAVE_OPENGL
-	if (dim == 4)
-		XtVaSetValues(XtParent(puzzleGL), XtNtitle, titleDsp, NULL);
-	else
-#endif
 	XtVaSetValues(XtParent((dim == 2) ? puzzle2d : puzzle3d),
 		XtNtitle, titleDsp, NULL);
 #endif
@@ -764,9 +733,10 @@ void
 	printStatus(messageDsp, movesDsp);
 #else
 	printStatus(messageDsp, movesDsp, 2, sizex, sizey, sizez);
-	printStatus(messageDsp, movesDsp, 3, sizex, sizey, sizez);
 #ifdef HAVE_OPENGL
 	printStatus(messageDsp, movesDsp, 4, sizex, sizey, sizez);
+#else
+	printStatus(messageDsp, movesDsp, 3, sizex, sizey, sizez);
 #endif
 #endif
 #endif
@@ -786,53 +756,32 @@ puzzleListener(Widget w, caddr_t clientData, rubikCallbackStruct *callData)
 	int dim = 0;
 #else
 	int reason = callData->reason;
-	Widget otherw1 = (Widget) NULL;
-#ifdef HAVE_OPENGL
-	Widget otherw2 = (Widget) NULL;
-#endif
+	Widget otherw = (Widget) NULL;
 #ifndef HAVE_MOTIF
-	int dim = 0, otherdim1 = 0;
-#ifdef HAVE_OPENGL
-	int otherdim2 = 0;
-#endif
+	int dim = 0, otherdim = 0;
 #endif
 
 	if (w == puzzle2d) {
-		otherw1 = puzzle3d;
-#ifdef HAVE_OPENGL
-		otherw2 = puzzleGL;
-#endif
+		otherw = puzzle3d;
 #ifndef HAVE_MOTIF
 		dim = 2;
-		otherdim1 = 3;
 #ifdef HAVE_OPENGL
-		otherdim2 = 4;
+		otherdim = 4;
+#else
+		otherdim = 3;
 #endif
 #endif
 	} else if (w == puzzle3d) {
-		otherw1 = puzzle2d;
-#ifdef HAVE_OPENGL
-		otherw2 = puzzleGL;
-#endif
+		otherw = puzzle2d;
 #ifndef HAVE_MOTIF
-		dim = 3;
-		otherdim1 = 2;
+		otherdim = 2;
 #ifdef HAVE_OPENGL
-		otherdim2 = 4;
-#endif
-#endif
-	}
-#ifdef HAVE_OPENGL
-	else if (w == puzzleGL) {
-		otherw1 = puzzle2d;
-		otherw2 = puzzle3d;
-#ifndef HAVE_MOTIF
 		dim = 4;
-		otherdim1 = 2;
-		otherdim2 = 3;
+#else
+		dim = 3;
+#endif
 #endif
 	}
-#endif
 #endif
 	(void) strcpy(messageDsp, "");
 #ifdef WINVER
@@ -866,11 +815,6 @@ puzzleListener(Widget w, caddr_t clientData, rubikCallbackStruct *callData)
 		(void) XIconifyWindow(XtDisplay(shell),
 			XtWindow(shell),
 			XScreenNumberOfScreen(XtScreen(shell)));
-#ifdef HAVE_OPENGL
-		(void) XIconifyWindow(XtDisplay(shellGL),
-			XtWindow(shellGL),
-			XScreenNumberOfScreen(XtScreen(shellGL)));
-#endif
 #endif
 #endif
 		break;
@@ -913,11 +857,7 @@ puzzleListener(Widget w, caddr_t clientData, rubikCallbackStruct *callData)
 		movesDsp = 0;
 		randomized = False;
 #ifndef WINVER
-#ifdef HAVE_OPENGL
-		XtVaSetValues(otherw2,
-			XtNdirection, RESTORE_DIR, NULL);
-#endif
-		XtVaSetValues(otherw1,
+		XtVaSetValues(otherw,
 			XtNdirection, RESTORE_DIR, NULL);
 		XtVaSetValues(w,
 			XtNdirection, RESTORE_DIR, NULL);
@@ -927,11 +867,7 @@ puzzleListener(Widget w, caddr_t clientData, rubikCallbackStruct *callData)
 		movesDsp = 0;
 		randomized = False;
 #ifndef WINVER
-#ifdef HAVE_OPENGL
-		XtVaSetValues(otherw2,
-			XtNdirection, CLEAR_DIR, NULL);
-#endif
-		XtVaSetValues(otherw1,
+		XtVaSetValues(otherw,
 			XtNdirection, CLEAR_DIR, NULL);
 		XtVaSetValues(w,
 			XtNdirection, CLEAR_DIR, NULL);
@@ -956,16 +892,7 @@ puzzleListener(Widget w, caddr_t clientData, rubikCallbackStruct *callData)
 #ifndef WINVER
 	case ACTION_MOVED:
 		if (callData->control) {
-#ifdef HAVE_OPENGL
-			XtVaSetValues(otherw2,
-				XtNface, callData->face,
-				XtNpos, callData->position,
-				XtNdirection, callData->direction,
-				XtNcontrol, callData->control,
-				XtNfast, callData->fast,
-				XtNstart, True, NULL);
-#endif
-			XtVaSetValues(otherw1,
+			XtVaSetValues(otherw,
 				XtNface, callData->face,
 				XtNpos, callData->position,
 				XtNdirection, callData->direction,
@@ -974,15 +901,7 @@ puzzleListener(Widget w, caddr_t clientData, rubikCallbackStruct *callData)
 				XtNstart, True, NULL);
 		} else {
 			movesDsp++;
-#ifdef HAVE_OPENGL
-			XtVaSetValues(otherw2,
-				XtNface, callData->face,
-				XtNpos, callData->position,
-				XtNdirection, callData->direction,
-				XtNcontrol, callData->control,
-				XtNfast, callData->fast, NULL);
-#endif
-			XtVaSetValues(otherw1,
+			XtVaSetValues(otherw,
 				XtNface, callData->face,
 				XtNpos, callData->position,
 				XtNdirection, callData->direction,
@@ -1007,22 +926,14 @@ puzzleListener(Widget w, caddr_t clientData, rubikCallbackStruct *callData)
 				MESSAGE_LENGTH);
 		SET_STARTED(w, False);
 #ifndef WINVER
-#ifdef HAVE_OPENGL
-		SET_STARTED(otherw2, False);
-#endif
-		SET_STARTED(otherw1, False);
+		SET_STARTED(otherw, False);
 #endif
 		randomized = False;
 		break;
 	case ACTION_COMPUTED:
-#ifdef WINVER
 		SET_STARTED(w, False);
-#else
-		SET_STARTED(w, False);
-#ifdef HAVE_OPENGL
-		SET_STARTED(otherw2, False);
-#endif
-		SET_STARTED(otherw1, False);
+#ifndef WINVER
+		SET_STARTED(otherw, False);
 #endif
 		break;
 	case ACTION_PRACTICE:
@@ -1040,12 +951,7 @@ puzzleListener(Widget w, caddr_t clientData, rubikCallbackStruct *callData)
 		XtVaSetValues(w,
 			XtNpractice, practice,
 			XtNstart, False, NULL);
-#ifdef HAVE_OPENGL
-		XtVaSetValues(otherw2,
-			XtNpractice, practice,
-			XtNstart, False, NULL);
-#endif
-		XtVaSetValues(otherw1,
+		XtVaSetValues(otherw,
 			XtNpractice, practice,
 			XtNstart, False, NULL);
 #ifdef HAVE_MOTIF
@@ -1063,12 +969,7 @@ puzzleListener(Widget w, caddr_t clientData, rubikCallbackStruct *callData)
 		XtVaSetValues(w,
 			XtNpractice, False,
 			XtNstart, False, NULL);
-#ifdef HAVE_OPENGL
-		XtVaSetValues(otherw2,
-			XtNpractice, False,
-			XtNstart, False, NULL);
-#endif
-		XtVaSetValues(otherw1,
+		XtVaSetValues(otherw,
 			XtNpractice, False,
 			XtNstart, False, NULL);
 #endif
@@ -1081,14 +982,14 @@ puzzleListener(Widget w, caddr_t clientData, rubikCallbackStruct *callData)
 #ifdef WINVER
 			view = w->rubik.view;
 #else
-			XtVaGetValues(puzzleGL,
+			XtVaGetValues(puzzle3d,
 				XtNview, &view, NULL);
 #endif
 			view = (view + 1) % (2 * MAX_VIEWS);
 #ifdef WINVER
 			w->rubik.view = view;
 #else
-			XtVaSetValues(puzzleGL,
+			XtVaSetValues(puzzle3d,
 				XtNview, view, NULL);
 #endif
 		}
@@ -1101,11 +1002,10 @@ puzzleListener(Widget w, caddr_t clientData, rubikCallbackStruct *callData)
 #ifdef WINVER
 		w->rubik.orient = orient;
 #else
-		XtVaSetValues(w, XtNorient, orient, NULL);
-#ifdef HAVE_OPENGL
-		XtVaSetValues(otherw2, XtNorient, orient, NULL);
-#endif
-		XtVaSetValues(otherw1, XtNorient, orient, NULL);
+		XtVaSetValues(w,
+			XtNorient, orient, NULL);
+		XtVaSetValues(otherw,
+			XtNorient, orient, NULL);
 #ifdef HAVE_MOTIF
 		XmToggleButtonSetState(orientizeSwitch, orient, True);
 #endif
@@ -1118,11 +1018,10 @@ puzzleListener(Widget w, caddr_t clientData, rubikCallbackStruct *callData)
 #ifdef WINVER
 		w->rubik.sizex = sizex;
 #else
-		XtVaSetValues(w, XtNsizex, sizex, NULL);
-#ifdef HAVE_OPENGL
-		XtVaSetValues(otherw2, XtNsizex, sizex, NULL);
-#endif
-		XtVaSetValues(otherw1, XtNsizex, sizex, NULL);
+		XtVaSetValues(w,
+			XtNsizex, sizex, NULL);
+		XtVaSetValues(otherw,
+			XtNsizex, sizex, NULL);
 #ifdef HAVE_MOTIF
 		if (sizex > MAX_FACETS)
 			XtVaSetValues(cubesXSlider, XmNmaximum, sizex, NULL);
@@ -1137,11 +1036,10 @@ puzzleListener(Widget w, caddr_t clientData, rubikCallbackStruct *callData)
 #ifdef WINVER
 		w->rubik.sizex = sizex;
 #else
-		XtVaSetValues(w, XtNsizex, sizex, NULL);
-#ifdef HAVE_OPENGL
-		XtVaSetValues(otherw2, XtNsizex, sizex, NULL);
-#endif
-		XtVaSetValues(otherw1, XtNsizex, sizex, NULL);
+		XtVaSetValues(w,
+			XtNsizex, sizex, NULL);
+		XtVaSetValues(otherw,
+			XtNsizex, sizex, NULL);
 #ifdef HAVE_MOTIF
 		XmScaleSetValue(cubesXSlider, sizex);
 		if (sizex >= MAX_FACETS)
@@ -1156,11 +1054,10 @@ puzzleListener(Widget w, caddr_t clientData, rubikCallbackStruct *callData)
 #ifdef WINVER
 		w->rubik.sizey = sizey;
 #else
-		XtVaSetValues(w, XtNsizey, sizey, NULL);
-#ifdef HAVE_OPENGL
-		XtVaSetValues(otherw2, XtNsizey, sizey, NULL);
-#endif
-		XtVaSetValues(otherw1, XtNsizey, sizey, NULL);
+		XtVaSetValues(w,
+			XtNsizey, sizey, NULL);
+		XtVaSetValues(otherw,
+			XtNsizey, sizey, NULL);
 #ifdef HAVE_MOTIF
 		if (sizey > MAX_FACETS)
 			XtVaSetValues(cubesYSlider, XmNmaximum, sizey, NULL);
@@ -1175,11 +1072,10 @@ puzzleListener(Widget w, caddr_t clientData, rubikCallbackStruct *callData)
 #ifdef WINVER
 		w->rubik.sizey = sizey;
 #else
-		XtVaSetValues(w, XtNsizey, sizey, NULL);
-#ifdef HAVE_OPENGL
-		XtVaSetValues(otherw2, XtNsizey, sizey, NULL);
-#endif
-		XtVaSetValues(otherw1, XtNsizey, sizey, NULL);
+		XtVaSetValues(w,
+			XtNsizey, sizey, NULL);
+		XtVaSetValues(otherw,
+			XtNsizey, sizey, NULL);
 #ifdef HAVE_MOTIF
 		XmScaleSetValue(cubesYSlider, sizey);
 		if (sizey >= MAX_FACETS)
@@ -1194,11 +1090,10 @@ puzzleListener(Widget w, caddr_t clientData, rubikCallbackStruct *callData)
 #ifdef WINVER
 		w->rubik.sizez = sizez;
 #else
-		XtVaSetValues(w, XtNsizez, sizez, NULL);
-#ifdef HAVE_OPENGL
-		XtVaSetValues(otherw2, XtNsizez, sizez, NULL);
-#endif
-		XtVaSetValues(otherw1, XtNsizez, sizez, NULL);
+		XtVaSetValues(w,
+			XtNsizez, sizez, NULL);
+		XtVaSetValues(otherw,
+			XtNsizez, sizez, NULL);
 #ifdef HAVE_MOTIF
 		if (sizez > MAX_FACETS)
 			XtVaSetValues(cubesZSlider, XmNmaximum, sizez, NULL);
@@ -1213,11 +1108,10 @@ puzzleListener(Widget w, caddr_t clientData, rubikCallbackStruct *callData)
 #ifdef WINVER
 		w->rubik.sizez = sizez;
 #else
-		XtVaSetValues(w, XtNsizez, sizez, NULL);
-#ifdef HAVE_OPENGL
-		XtVaSetValues(otherw2, XtNsizez, sizez, NULL);
-#endif
-		XtVaSetValues(otherw1, XtNsizez, sizez, NULL);
+		XtVaSetValues(w,
+			XtNsizez, sizez, NULL);
+		XtVaSetValues(otherw,
+			XtNsizez, sizez, NULL);
 #ifdef HAVE_MOTIF
 		XmScaleSetValue(cubesZSlider, sizez);
 		if (sizez >= MAX_FACETS)
@@ -1228,16 +1122,7 @@ puzzleListener(Widget w, caddr_t clientData, rubikCallbackStruct *callData)
 #ifndef WINVER
 	case ACTION_UNDO:
 		if (callData->control) {
-#ifdef HAVE_OPENGL
-			XtVaSetValues(otherw2,
-				XtNface, callData->face,
-				XtNpos, callData->position,
-				XtNdirection, callData->direction,
-				XtNcontrol, callData->control,
-				XtNfast, callData->fast,
-				XtNstart, True, NULL);
-#endif
-			XtVaSetValues(otherw1,
+			XtVaSetValues(otherw,
 				XtNface, callData->face,
 				XtNpos, callData->position,
 				XtNdirection, callData->direction,
@@ -1246,36 +1131,20 @@ puzzleListener(Widget w, caddr_t clientData, rubikCallbackStruct *callData)
 				XtNstart, True, NULL);
 		} else {
 			movesDsp--;
-#ifdef HAVE_OPENGL
-			XtVaSetValues(otherw2,
-				XtNface, callData->face,
-				XtNpos, callData->position,
-				XtNdirection, callData->direction,
-				XtNcontrol, callData->control,
-				XtNfast, callData->fast, NULL);
-#endif
-			XtVaSetValues(otherw1,
+			XtVaSetValues(otherw,
 				XtNface, callData->face,
 				XtNpos, callData->position,
 				XtNdirection, callData->direction,
 				XtNcontrol, callData->control,
 				XtNfast, callData->fast, NULL);
+			SET_STARTED(w, True);
 		}
 		break;
 #endif
 #ifndef WINVER
 	case ACTION_REDO:
 		if (callData->control) {
-#ifdef HAVE_OPENGL
-			XtVaSetValues(otherw2,
-				XtNface, callData->face,
-				XtNpos, callData->position,
-				XtNdirection, callData->direction,
-				XtNcontrol, callData->control,
-				XtNfast, callData->fast,
-				XtNstart, True, NULL);
-#endif
-			XtVaSetValues(otherw1,
+			XtVaSetValues(otherw,
 				XtNface, callData->face,
 				XtNpos, callData->position,
 				XtNdirection, callData->direction,
@@ -1284,20 +1153,13 @@ puzzleListener(Widget w, caddr_t clientData, rubikCallbackStruct *callData)
 				XtNstart, True, NULL);
 		} else {
 			movesDsp++;
-#ifdef HAVE_OPENGL
-			XtVaSetValues(otherw2,
-				XtNface, callData->face,
-				XtNpos, callData->position,
-				XtNdirection, callData->direction,
-				XtNcontrol, callData->control,
-				XtNfast, callData->fast, NULL);
-#endif
-			XtVaSetValues(otherw1,
+			XtVaSetValues(otherw,
 				XtNface, callData->face,
 				XtNpos, callData->position,
 				XtNdirection, callData->direction,
 				XtNcontrol, callData->control,
 				XtNfast, callData->fast, NULL);
+			SET_STARTED(w, True);
 		}
 		break;
 #endif
@@ -1305,13 +1167,23 @@ puzzleListener(Widget w, caddr_t clientData, rubikCallbackStruct *callData)
 	case ACTION_DIM:
 		dim++;
 #ifdef HAVE_OPENGL
-		if (dim > 4)
+		if (dim == 3)
+			dim = 4;
+		else if (dim > 4)
 #else
 		if (dim > 3)
 #endif
 			dim = 2;
 		w->rubik.dim = dim;
 		break;
+#endif
+#ifndef WINVER
+	case ACTION_CHEAT:
+		XtVaSetValues(w,
+			XtNcheat, cheat, NULL);
+		XtVaSetValues(otherw,
+			XtNcheat, cheat, NULL);
+		break;
 #endif
 	}
 #ifdef WINVER
@@ -1321,10 +1193,7 @@ puzzleListener(Widget w, caddr_t clientData, rubikCallbackStruct *callData)
 	printStatus(messageDsp, movesDsp);
 #else
 	printStatus(messageDsp, movesDsp, dim, sizex, sizey, sizez);
-	printStatus(messageDsp, movesDsp, otherdim1, sizex, sizey, sizez);
-#ifdef HAVE_OPENGL
-	printStatus(messageDsp, movesDsp, otherdim2, sizex, sizey, sizez);
-#endif
+	printStatus(messageDsp, movesDsp, otherdim, sizex, sizey, sizez);
 #endif
 #endif
 }
@@ -1793,7 +1662,8 @@ puzzleRandomizeListener(Widget w, XtPointer clientData,
 }
 
 static void
-cubesXChangeListener(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
+cubesXChangeListener(Widget w, XtPointer clientData,
+		XmScaleCallbackStruct *cbs)
 {
 	int sizex = cbs->value, old, sizey, sizez;
 	Boolean orient, practice;
@@ -1809,10 +1679,6 @@ cubesXChangeListener(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
 			XtNsizex, sizex, NULL);
 		XtVaSetValues(puzzle3d,
 			XtNsizex, sizex, NULL);
-#ifdef HAVE_OPENGL
-		XtVaSetValues(puzzleGL,
-			XtNsizex, sizex, NULL);
-#endif
 		movesDsp = 0;
 		(void) sprintf(buff, "%d", movesDsp);
 		printState(movesText, buff);
@@ -1823,7 +1689,8 @@ cubesXChangeListener(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
 }
 
 static void
-cubesYChangeListener(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
+cubesYChangeListener(Widget w, XtPointer clientData,
+		XmScaleCallbackStruct *cbs)
 {
 	int sizey = cbs->value, old, sizex, sizez;
 	Boolean orient, practice;
@@ -1839,10 +1706,6 @@ cubesYChangeListener(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
 			XtNsizey, sizey, NULL);
 		XtVaSetValues(puzzle3d,
 			XtNsizey, sizey, NULL);
-#ifdef HAVE_OPENGL
-		XtVaSetValues(puzzleGL,
-			XtNsizey, sizey, NULL);
-#endif
 		movesDsp = 0;
 		(void) sprintf(buff, "%d", movesDsp);
 		printState(movesText, buff);
@@ -1853,7 +1716,8 @@ cubesYChangeListener(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
 }
 
 static void
-cubesZChangeListener(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
+cubesZChangeListener(Widget w, XtPointer clientData,
+		XmScaleCallbackStruct *cbs)
 {
 	int sizez = cbs->value, old, sizex, sizey;
 	Boolean orient, practice;
@@ -1869,10 +1733,6 @@ cubesZChangeListener(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
 			XtNsizez, sizez, NULL);
 		XtVaSetValues(puzzle3d,
 			XtNsizez, sizez, NULL);
-#ifdef HAVE_OPENGL
-		XtVaSetValues(puzzleGL,
-			XtNsizez, sizez, NULL);
-#endif
 		movesDsp = 0;
 		(void) sprintf(buff, "%d", movesDsp);
 		printState(movesText, buff);
@@ -1883,7 +1743,8 @@ cubesZChangeListener(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
 }
 
 static void
-orientToggle(Widget w, XtPointer clientData, XmToggleButtonCallbackStruct *cbs)
+orientToggle(Widget w, XtPointer clientData,
+		XmToggleButtonCallbackStruct *cbs)
 {
 	int sizex, sizey, sizez;
 	Boolean orient = cbs->set, practice;
@@ -1897,10 +1758,6 @@ orientToggle(Widget w, XtPointer clientData, XmToggleButtonCallbackStruct *cbs)
 		XtNorient, orient, NULL);
 	XtVaSetValues(puzzle3d,
 		XtNorient, orient, NULL);
-#ifdef HAVE_OPENGL
-	XtVaSetValues(puzzleGL,
-		XtNorient, orient, NULL);
-#endif
 	movesDsp = 0;
 	(void) sprintf(buff, "%d", movesDsp);
 	printState(movesText, buff);
@@ -1910,7 +1767,8 @@ orientToggle(Widget w, XtPointer clientData, XmToggleButtonCallbackStruct *cbs)
 }
 
 static void
-practiceToggle(Widget w, XtPointer clientData, XmToggleButtonCallbackStruct *cbs)
+practiceToggle(Widget w, XtPointer clientData,
+		XmToggleButtonCallbackStruct *cbs)
 {
 	int sizex, sizey, sizez;
 	Boolean orient, practice = cbs->set;
@@ -1921,11 +1779,6 @@ practiceToggle(Widget w, XtPointer clientData, XmToggleButtonCallbackStruct *cbs
 	XtVaSetValues(puzzle3d,
 		XtNpractice, practice,
 		XtNstart, False, NULL);
-#ifdef HAVE_OPENGL
-	XtVaSetValues(puzzleGL,
-		XtNpractice, practice,
-		XtNstart, False, NULL);
-#endif
 	XtVaGetValues(puzzle2d,
 		XtNsizex, &sizex,
 		XtNsizey, &sizey,
@@ -1943,16 +1796,14 @@ practiceToggle(Widget w, XtPointer clientData, XmToggleButtonCallbackStruct *cbs
 }
 
 static void
-speedChangeListener(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
+speedChangeListener(Widget w, XtPointer clientData,
+		XmScaleCallbackStruct *cbs)
 {
 	int delay = MAX_SPEED + MIN_SPEED - cbs->value - 1, oldDelay;
 
 	XtVaGetValues(puzzle2d,
 		XtNdelay, &oldDelay, NULL);
 	if (oldDelay != delay) {
-#ifdef HAVE_OPENGL
-		XtVaSetValues(puzzleGL, XtNdelay, delay, NULL);
-#endif
 		XtVaSetValues(puzzle3d, XtNdelay, delay, NULL);
 		XtVaSetValues(puzzle2d, XtNdelay, delay, NULL);
 	}
@@ -2335,30 +2186,28 @@ main(int argc, char **argv)
 		XtNheight, 200, NULL);
 	XtAddCallback(puzzle2d, XtNselectCallback,
 		(XtCallbackProc) puzzleListener, (XtPointer) NULL);
+#ifdef HAVE_OPENGL
+	puzzle3d = XtCreateManagedWidget("rubik",
+		rubikGLWidgetClass, mainPanel, NULL, 0);
+#else
 	puzzle3d = XtCreateManagedWidget("rubik",
 		rubik3dWidgetClass, mainPanel, NULL, 0);
+#endif
 	XtVaSetValues(puzzle3d,
 		XtNheight, 200, NULL);
-#ifdef HAVE_OPENGL
-	puzzleGL = XtCreateManagedWidget("rubik",
-		rubikGLWidgetClass, mainPanel, NULL, 0);
-	XtVaSetValues(puzzleGL,
-		XtNheight, 200, NULL);
-#endif
 #else
 	shell = XtCreateApplicationShell(argv[0],
 		topLevelShellWidgetClass, NULL, 0);
-#ifdef HAVE_OPENGL
-	shellGL = XtCreateApplicationShell(argv[0],
-		topLevelShellWidgetClass, NULL, 0);
-#endif
 	puzzle2d = XtCreateManagedWidget("rubik",
 		rubik2dWidgetClass, topLevel, NULL, 0);
+	XtAddCallback(puzzle2d, XtNselectCallback,
+		(XtCallbackProc) puzzleListener, (XtPointer) NULL);
+#ifdef HAVE_OPENGL
+	puzzle3d = XtCreateManagedWidget("rubik",
+		rubikGLWidgetClass, shell, NULL, 0);
+#else
 	puzzle3d = XtCreateManagedWidget("rubik",
 		rubik3dWidgetClass, shell, NULL, 0);
-#ifdef HAVE_OPENGL
-	puzzleGL = XtCreateManagedWidget("rubik",
-		rubikGLWidgetClass, shellGL, NULL, 0);
 #endif
 #endif
 	XtVaGetValues(puzzle2d,
@@ -2400,22 +2249,10 @@ main(int argc, char **argv)
 #endif
 	XtAddCallback(puzzle3d, XtNselectCallback,
 		(XtCallbackProc) puzzleListener, (XtPointer) NULL);
-#ifdef HAVE_OPENGL
-#ifndef HAVE_MOTIF
-	XtVaSetValues(shellGL,
-		XtNinput, True,
-		XtNiconPixmap, pixmap, NULL);
-#endif
-	XtAddCallback(puzzleGL, XtNselectCallback,
-		(XtCallbackProc) puzzleListener, (XtPointer) NULL);
-#endif
 	initialize();
 	XtRealizeWidget(topLevel);
 #ifndef HAVE_MOTIF
 	XtRealizeWidget(shell);
-#ifdef HAVE_OPENGL
-	XtRealizeWidget(shellGL);
-#endif
 #endif
 	XGrabButton(XtDisplay(puzzle2d), (unsigned int) AnyButton, AnyModifier,
 		XtWindow(puzzle2d), TRUE, (unsigned int) (ButtonPressMask |
@@ -2427,13 +2264,6 @@ main(int argc, char **argv)
 		ButtonMotionMask | ButtonReleaseMask),
 		GrabModeAsync, GrabModeAsync, XtWindow(puzzle3d),
 		XCreateFontCursor(XtDisplay(puzzle3d), XC_hand2));
-#ifdef HAVE_OPENGL
-	XGrabButton(XtDisplay(puzzleGL), (unsigned int) AnyButton, AnyModifier,
-		XtWindow(puzzleGL), TRUE, (unsigned int) (ButtonPressMask |
-		ButtonMotionMask | ButtonReleaseMask),
-		GrabModeAsync, GrabModeAsync, XtWindow(puzzleGL),
-		XCreateFontCursor(XtDisplay(puzzleGL), XC_crosshair));
-#endif
 	XtMainLoop();
 
 #ifdef VMS
