@@ -1,7 +1,7 @@
 /*
  * @(#)Skewb.c
  *
- * Copyright 1994 - 2008  David A. Bagley, bagleyd@tux.org
+ * Copyright 1994 - 2010  David A. Bagley, bagleyd@tux.org
  *
  * All rights reserved.
  *
@@ -122,7 +122,8 @@ setPuzzle(SkewbWidget w, int reason)
 }
 
 static void
-setPuzzleMove(SkewbWidget w, int reason, int face, int position, int direction)
+setPuzzleMove(SkewbWidget w, int reason, int face, int position, int direction,
+		int control, int fast)
 {
 	skewbCallbackStruct cb;
 
@@ -130,6 +131,8 @@ setPuzzleMove(SkewbWidget w, int reason, int face, int position, int direction)
 	cb.face = face;
 	cb.position = position;
 	cb.direction = direction;
+	cb.control = control;
+	cb.fast = fast;
 	XtCallCallbacks((Widget) w, (char *) XtNselectCallback, &cb);
 }
 #endif
@@ -598,7 +601,24 @@ static SkewbLocPos orthToDiag[MAX_FACES][MAX_ORIENT][MAX_ORIENT] =
 	}
 };
 
-static SkewbStack undo, redo;
+static SkewbStack undo = {NULL, NULL, NULL, 0};
+static SkewbStack redo = {NULL, NULL, NULL, 0};
+
+static void
+checkPieces(SkewbWidget w)
+{
+	char *buf1 = NULL, *buf2 = NULL;
+
+	if (w->skewb.delay < 0) {
+		intCat(&buf1, "Delay can not be negative (",
+			w->skewb.delay);
+		stringCat(&buf2, buf1, "), taking absolute value");
+		free(buf1);
+		DISPLAY_WARNING(buf2);
+		free(buf2);
+		w->skewb.delay = -w->skewb.delay;
+	}
+}
 
 Boolean
 checkSolved(SkewbWidget w)
@@ -614,14 +634,14 @@ checkSolved(SkewbWidget w)
 			} else if (test.face !=		/*face */
 				  w->skewb.cubeLoc[face][position].face ||
 				  (w->skewb.orient && test.rotation !=		/*STRT - MAX_ORIENT */
-				  w->skewb.cubeLoc[face][position].rotation))
+				  w->skewb.cubeLoc[face][position].rotation)) {
 				return False;
+			}
 		}
 	return True;
 }
 
 #ifdef DEBUG
-
 void
 printCube(SkewbWidget w)
 {
@@ -635,7 +655,6 @@ printCube(SkewbWidget w)
 	}
 	(void) printf("\n");
 }
-
 #endif
 
 static void
@@ -647,6 +666,16 @@ drawDiamond(SkewbWidget w, int face, int offset)
 		drawDiamond3D((Skewb3DWidget) w, face, offset);
 }
 
+static void
+drawDiamondAll(SkewbWidget w, int face, int offset)
+{
+	drawDiamond(w, face, offset);
+#ifdef HAVE_OPENGL
+	if (w->skewb.dim == 4)
+		drawAllPiecesGL((SkewbGLWidget) w);
+#endif
+}
+
 static void
 drawTriangle(SkewbWidget w, int face, int position, int offset)
 {
@@ -656,6 +685,16 @@ drawTriangle(SkewbWidget w, int face, int position, int offset)
 		drawTriangle3D((Skewb3DWidget) w, face, position, offset);
 }
 
+static void
+drawTriangleAll(SkewbWidget w, int face, int position, int offset)
+{
+	drawTriangle(w, face, position, offset);
+#ifdef HAVE_OPENGL
+	if (w->skewb.dim == 4)
+		drawAllPiecesGL((SkewbGLWidget) w);
+#endif
+}
+
 void
 drawAllPieces(SkewbWidget w)
 {
@@ -664,6 +703,7 @@ drawAllPieces(SkewbWidget w)
 #ifdef HAVE_OPENGL
 	if (w->skewb.dim == 4) {
 		drawAllPiecesGL((SkewbGLWidget) w);
+		return;
 	}
 #endif
 	for (face = 0; face < MAX_FACES; face++) {
@@ -714,11 +754,6 @@ rotateFace(SkewbWidget w, int face, int direction)
 		(w->skewb.cubeLoc[face][MAX_ORIENT].rotation + direction) %
 		MAX_ORIENT;
 	drawDiamond(w, face, FALSE);
-#ifdef HAVE_OPENGL
-	if (w->skewb.dim == 4) {
-		drawAllPiecesGL((SkewbGLWidget) w);
-	}
-#endif
 }
 
 static void
@@ -748,11 +783,6 @@ writeFace(SkewbWidget w, int face, int rotate, int h)
 		(w->skewb.cubeLoc[face][MAX_ORIENT].rotation + rotate) %
 		MAX_ORIENT;
 	drawDiamond(w, face, FALSE);
-#ifdef HAVE_OPENGL
-	if (w->skewb.dim == 4) {
-		drawAllPiecesGL((SkewbGLWidget) w);
-	}
-#endif
 }
 
 static void
@@ -783,7 +813,8 @@ rotateDiagonal(SkewbWidget w, int rotate, int orient, int size)
 	else			/* size == MAJOR */
 		for (g = 0; g < MAX_ORIENT; g++)
 			w->skewb.majorLoc[orient][g].rotation =
-				(w->skewb.majorLoc[orient][g].rotation + rotate) % MAX_ORIENT;
+				(w->skewb.majorLoc[orient][g].rotation + rotate) %
+				MAX_ORIENT;
 }
 
 static void
@@ -804,20 +835,24 @@ writeDiagonal(SkewbWidget w, int face, int corner, int orient, int size)
 			drawTriangle(w, face, h, FALSE);
 		}
 	}
-#ifdef HAVE_OPENGL
-	if (w->skewb.dim == 4) {
-		drawAllPiecesGL((SkewbGLWidget) w);
-	}
-#endif
-
 }
 
 static void
-movePieces(SkewbWidget w, int face, int position, int direction)
+movePieces(SkewbWidget w, int face, int position, int direction,
+		int control, int fast)
 {
 	int oldFace = face, pos = position, dir = direction;
 	int newFace, newDirection, newCorner, k, size, rotate;
 
+	if ((direction + position) % 2 == 0 && direction < MAX_ORIENT)
+		(void) printf("wrong face %d, position %d, direction %d\n",
+			face, position, direction);
+#ifdef HAVE_OPENGL
+	if (control != 2 && fast != INSTANT && w->skewb.dim == 4) {
+		movePiecesGL((SkewbGLWidget) w, oldFace, position, dir,
+			(control == 1), fast);
+	}
+#endif
 	if (dir < 2 * MAX_ORIENT) {
 		/* position as MAX_ORIENT is ambiguous */
 		for (size = MINOR; size <= MAJOR; size++) {
@@ -859,10 +894,19 @@ movePieces(SkewbWidget w, int face, int position, int direction)
 			dir = newDirection;
 		}
 	}
+#ifdef HAVE_OPENGL
+	if (!control && fast == INSTANT && w->skewb.dim == 4) {
+		drawAllPiecesGL((SkewbGLWidget) w);
+	}
+#endif
+#ifdef DEBUG
+	printCube(w);
+#endif
+
 }
 
 static void
-moveControlCb(SkewbWidget w, int face, int position, int direction)
+moveControlCb(SkewbWidget w, int face, int position, int direction, int fast)
 {
 	int oldFace = face, pos = position, dir = direction;
 	int newFace, rotate;
@@ -875,30 +919,31 @@ moveControlCb(SkewbWidget w, int face, int position, int direction)
 		pos = newpos.position;
 		dir = newpos.direction;
 	}
-	movePieces(w, oldFace, pos, dir);
-	setPuzzleMove(w, ACTION_CONTROL, oldFace, pos, dir);
+	movePieces(w, oldFace, pos, dir, 1, fast);
+	setPuzzleMove(w, ACTION_CONTROL, oldFace, pos, dir, 1, fast);
 	newFace = minToMaj[oldFace][pos].face;
 	rotate = minToMaj[oldFace][pos].rotation % MAX_ORIENT;
 	dir = (rotate + dir) % MAX_ORIENT;
 	pos = (pos + rotate + 2) % MAX_ORIENT;
-	movePieces(w, newFace, pos, dir);
-	setPuzzleMove(w, ACTION_CONTROL, newFace, pos, dir);
+	movePieces(w, newFace, pos, dir, 2, fast);
+	setPuzzleMove(w, ACTION_CONTROL, newFace, pos, dir, 2, fast);
 }
 
 static void
-moveAltCb(SkewbWidget w, int face, int position, int direction)
+moveAltCb(SkewbWidget w, int face, int position, int direction, int fast)
 {
-	movePieces(w, face, position, direction);
-	setPuzzleMove(w, ACTION_CONTROL, face, position, direction);
+	movePieces(w, face, position, direction, 0, fast);
+	setPuzzleMove(w, ACTION_CONTROL, face, position, direction, 0, fast);
 }
 
 void
-movePuzzle(SkewbWidget w, int face, int position, int direction, int control)
+movePuzzle(SkewbWidget w, int face, int position, int direction, int control,
+		int fast)
 {
 	if (control == 2)
-		moveAltCb(w, face, position, direction);
-	else if (control)
-		moveControlCb(w, face, position, direction);
+		moveAltCb(w, face, position, direction, fast);
+	else if (control == 1)
+		moveControlCb(w, face, position, direction, fast);
 	else {
 		SkewbLocPos newpos;
 
@@ -907,9 +952,12 @@ movePuzzle(SkewbWidget w, int face, int position, int direction, int control)
 		newpos.direction = direction;
 		if (direction >= 2 * MAX_ORIENT)
 			newpos = orthToDiag[face][position][direction % MAX_ORIENT];
-		movePieces(w, newpos.face, newpos.position, newpos.direction);
+		movePieces(w, newpos.face, newpos.position, newpos.direction,
+			0, fast);
+		w->skewb.currentFace = IGNORE_DIR;
+		w->skewb.currentPosition = IGNORE_DIR;
 		setPuzzleMove(w, ACTION_MOVED, newpos.face, newpos.position,
-			newpos.direction);
+			newpos.direction, 0, fast);
 	}
 #ifdef USE_SOUND
 	if (w->skewb.sound) {
@@ -920,6 +968,14 @@ movePuzzle(SkewbWidget w, int face, int position, int direction, int control)
 	flushMoves(w, &redo, FALSE);
 }
 
+void
+movePuzzleDelay(SkewbWidget w, const int face, const int position,
+                const int direction, const int control)
+{
+        movePuzzle(w, face, position, direction, control, NORMAL);
+        Sleep((unsigned int) w->skewb.delay);
+}
+
 static Boolean
 selectPieces(SkewbWidget w, int x, int y, int *face, int *position)
 {
@@ -929,6 +985,11 @@ selectPieces(SkewbWidget w, int x, int y, int *face, int *position)
 	else if (w->skewb.dim == 3)
 		return selectPieces3D((Skewb3DWidget) w, x, y,
 			face, position);
+#ifdef HAVE_OPENGL
+	else if (w->skewb.dim == 4)
+		return selectPiecesGL((SkewbGLWidget) w, x, y,
+			face, position);
+#endif
 	return False;
 }
 
@@ -966,6 +1027,10 @@ narrowSelection(SkewbWidget w, int *face, int *position, int *direction)
 		return narrowSelection2D((Skewb2DWidget) w, face, position, direction);
 	else if (w->skewb.dim == 3)
 		return narrowSelection3D((Skewb3DWidget) w, face, position, direction);
+#ifdef HAVE_OPENGL
+	else if (w->skewb.dim == 4)
+		return narrowSelectionGL((SkewbGLWidget) w, face, position, direction);
+#endif
 	return False;
 }
 
@@ -995,7 +1060,7 @@ movePuzzleInput(SkewbWidget w, int x, int y, int direction, int control,
 		control = (control) ? 1 : 0;
 	if (position == MAX_ORIENT)
 		return;
-	movePuzzle(w, face, position, direction, control);
+	movePuzzle(w, face, position, direction, control, NORMAL);
 	if (!control && checkSolved(w)) {
 		setPuzzle(w, ACTION_SOLVED);
 	}
@@ -1090,6 +1155,7 @@ getPieces(SkewbWidget w)
 	free(lname);
 	free(fname);
 	w->skewb.cheat = True; /* Assume the worst. */
+	setPuzzle(w, ACTION_CHEAT);
 }
 
 static void
@@ -1139,7 +1205,7 @@ writePieces(SkewbWidget w)
 	(void) fprintf(fp, "practice%c %d\n", SYMBOL,
 		(w->skewb.practice) ? 1 : 0);
 	(void) fprintf(fp, "moves%c %d\n", SYMBOL,
-		 numMoves(&undo));
+		numMoves(&undo));
 	printStartPosition(fp, w);
 	printMoves(fp, &undo);
 	(void) fclose(fp);
@@ -1167,9 +1233,9 @@ undoPieces(SkewbWidget w)
 				2 * MAX_ORIENT;
 		}
 		if (control == 2)
-			moveAltCb(w, face, position, direction);
+			moveAltCb(w, face, position, direction, DOUBLE);
 		else if (control == 1)
-			moveControlCb(w, face, position, direction);
+			moveControlCb(w, face, position, direction, DOUBLE);
 		else {
 			if (direction >= 2 * MAX_ORIENT) {
 				SkewbLocPos newpos;
@@ -1179,8 +1245,8 @@ undoPieces(SkewbWidget w)
 				position = newpos.position;
 				direction = newpos.direction;
 			}
-			movePieces(w, face, position, direction);
-			setPuzzleMove(w, ACTION_UNDO, face, position, direction);
+			movePieces(w, face, position, direction, 0, DOUBLE);
+			setPuzzleMove(w, ACTION_UNDO, face, position, direction, 0, DOUBLE);
 			if (checkSolved(w)) {
 				setPuzzle(w, ACTION_SOLVED);
 			}
@@ -1199,9 +1265,9 @@ redoPieces(SkewbWidget w)
 		setMove(&undo,
 			face, position, direction, control);
 		if (control == 2)
-			moveAltCb(w, face, position, direction);
+			moveAltCb(w, face, position, direction, DOUBLE);
 		else if (control == 1)
-			moveControlCb(w, face, position, direction);
+			moveControlCb(w, face, position, direction, DOUBLE);
 		else {
 			if (direction >= 2 * MAX_ORIENT) {
 				SkewbLocPos newpos;
@@ -1211,8 +1277,8 @@ redoPieces(SkewbWidget w)
 				position = newpos.position;
 				direction = newpos.direction;
 			}
-			movePieces(w, face, position, direction);
-			setPuzzleMove(w, ACTION_REDO, face, position, direction);
+			movePieces(w, face, position, direction, 0, DOUBLE);
+			setPuzzleMove(w, ACTION_REDO, face, position, direction, 0, DOUBLE);
 			if (checkSolved(w)) {
 				setPuzzle(w, ACTION_SOLVED);
 			}
@@ -1239,6 +1305,7 @@ randomizePieces(SkewbWidget w)
 	int big = MAX_CUBES * 3 + NRAND(2);
 
 	w->skewb.cheat = False;
+	setPuzzle(w, ACTION_CHEAT);
 	if (w->skewb.practice)
 		practicePieces(w);
 	setPuzzle(w, ACTION_RESET);
@@ -1251,7 +1318,7 @@ randomizePieces(SkewbWidget w)
 		face = NRAND(MAX_FACES);
 		position = NRAND(MAX_ORIENT);
 		direction = ((NRAND(2)) ? position + 1 : position + 3) % MAX_ORIENT;
-		movePuzzle(w, face, position, direction, FALSE);
+		movePuzzle(w, face, position, direction, FALSE, INSTANT);
 	}
 	flushMoves(w, &undo, TRUE);
 	flushMoves(w, &redo, FALSE);
@@ -1266,11 +1333,7 @@ solvePieces(SkewbWidget w)
 {
 	if (checkSolved(w))
 		return;
-	{
-		printf("got here\n");
-
-		setPuzzle(w, ACTION_SOLVE_MESSAGE);
-	}
+	solveSomePieces(w);
 }
 
 static void
@@ -1321,37 +1384,42 @@ setValuesPuzzle(SkewbWidget w)
 	char szBuf[80], buf[20], charbuf[2];
 	int face;
 
-	w->skewb.orient = (BOOL) GetPrivateProfileInt(SECTION, "orient",
-		DEFAULT_ORIENT, INIFILE);
-	w->skewb.practice = (BOOL) GetPrivateProfileInt(SECTION, "practice",
-		DEFAULT_PRACTICE, INIFILE);
+	w->skewb.orient = (BOOL) GetPrivateProfileInt(SECTION,
+		"orient", DEFAULT_ORIENT, INIFILE);
+	w->skewb.practice = (BOOL) GetPrivateProfileInt(SECTION,
+		"practice", DEFAULT_PRACTICE, INIFILE);
+#ifdef HAVE_OPENGL
+	w->skewb.dim = GetPrivateProfileInt(SECTION, "dim", 4, INIFILE);
+#else
 	w->skewb.dim = GetPrivateProfileInt(SECTION, "dim", 3, INIFILE);
-	w->skewb.mono = (BOOL) GetPrivateProfileInt(SECTION, "mono",
-		DEFAULT_MONO, INIFILE);
-	w->skewb.reverse = (BOOL) GetPrivateProfileInt(SECTION, "reverseVideo",
-		DEFAULT_REVERSE, INIFILE);
-	/* cyan */
-	(void) GetPrivateProfileString(SECTION, "frameColor", "0 255 255",
-		szBuf, sizeof (szBuf), INIFILE);
+#endif
+	w->skewb.view = GetPrivateProfileInt(SECTION, "view", 1, INIFILE);
+	w->skewb.mono = (BOOL) GetPrivateProfileInt(SECTION,
+		"mono", DEFAULT_MONO, INIFILE);
+	w->skewb.reverse = (BOOL) GetPrivateProfileInt(SECTION,
+		"reverseVideo", DEFAULT_REVERSE, INIFILE);
+	/* Cyan */
+	(void) GetPrivateProfileString(SECTION,
+		"frameColor", "0 255 255", szBuf, sizeof (szBuf), INIFILE);
 	(void) sscanf(szBuf, "%d %d %d",
 		&(color.red), &(color.green), &(color.blue));
 	w->skewb.frameGC = RGB(color.red, color.green, color.blue);
 	/* gray25 */
-	(void) GetPrivateProfileString(SECTION, "pieceBorder", "64 64 64",
-		szBuf, sizeof (szBuf), INIFILE);
+	(void) GetPrivateProfileString(SECTION,
+		"pieceBorder", "64 64 64", szBuf, sizeof (szBuf), INIFILE);
 	(void) sscanf(szBuf, "%d %d %d",
 		&(color.red), &(color.green), &(color.blue));
 	w->skewb.borderGC = RGB(color.red, color.green, color.blue);
 	/* #AEB2C3 */
-	(void) GetPrivateProfileString(SECTION, "background", "174 178 195",
-		szBuf, sizeof (szBuf), INIFILE);
+	(void) GetPrivateProfileString(SECTION,
+		"background", "174 178 195", szBuf, sizeof (szBuf), INIFILE);
 	(void) sscanf(szBuf, "%d %d %d",
 		&(color.red), &(color.green), &(color.blue));
 	w->skewb.inverseGC = RGB(color.red, color.green, color.blue);
 	for (face = 0; face < MAX_FACES; face++) {
 		(void) sprintf(buf, "faceColor%d", face);
-		(void) GetPrivateProfileString(SECTION, buf,
-			faceColorString[face],
+		(void) GetPrivateProfileString(SECTION,
+			buf, faceColorString[face],
 			szBuf, sizeof (szBuf), INIFILE);
 		(void) sscanf(szBuf, "%d %d %d",
 			&(color.red), &(color.green), &(color.blue));
@@ -1360,18 +1428,23 @@ setValuesPuzzle(SkewbWidget w)
 		(void) sprintf(buf, "faceChar%d", face);
 		charbuf[0] = faceColorChar[face];
 		charbuf[1] = '\0';
-		(void) GetPrivateProfileString(SECTION, buf, charbuf,
-			szBuf, sizeof (szBuf), INIFILE);
+		(void) GetPrivateProfileString(SECTION,
+			buf, charbuf, szBuf, sizeof (szBuf), INIFILE);
 		w->skewb.faceChar[face] = szBuf[0];
 	}
-	(void) GetPrivateProfileString(SECTION, "userName", "Guest",
-		szBuf, sizeof (szBuf), INIFILE);
-	(void) strcpy(w->skewb.userName, szBuf);
-		w->skewb.userName[80] = 0;
-	(void) GetPrivateProfileString(SECTION, "scoreFile", "",
-		szBuf, sizeof (szBuf), INIFILE);
-	(void) strcpy(w->skewb.scoreFile, szBuf);
-		w->skewb.scoreFile[80] = 0;
+	w->skewb.delay = GetPrivateProfileInt(SECTION,
+		"delay", 10, INIFILE);
+	w->skewb.sound = (BOOL) GetPrivateProfileInt(SECTION,
+		"sound", FALSE, INIFILE);
+	(void) GetPrivateProfileString(SECTION,
+                "moveSound", MOVESOUND, szBuf, sizeof (szBuf), INIFILE);
+        (void) strncpy(w->skewb.moveSound, szBuf, 80);
+	(void) GetPrivateProfileString(SECTION,
+		"userName", "Guest", szBuf, sizeof (szBuf), INIFILE);
+	(void) strncpy(w->skewb.userName, szBuf, 80);
+	(void) GetPrivateProfileString(SECTION,
+		"scoreFile", "", szBuf, sizeof (szBuf), INIFILE);
+	(void) strncpy(w->skewb.scoreFile, szBuf, 80);
 }
 
 void
@@ -1533,6 +1606,7 @@ setValuesPuzzle(Widget current, Widget request, Widget renew)
 	Boolean redraw = False, setColors = False;
 	int face;
 
+	checkPieces(w);
 	for (face = 0; face < MAX_FACES; face++) {
 		if (strcmp(w->skewb.faceName[face], c->skewb.faceName[face])) {
 			setColors = True;
@@ -1615,9 +1689,15 @@ setValuesPuzzle(Widget current, Widget request, Widget renew)
 		redraw = True;
 		w->skewb.currentDirection = IGNORE_DIR;
 	} else if (w->skewb.currentDirection > IGNORE_DIR) {
-		movePieces(w, w->skewb.currentFace, w->skewb.currentPosition,
-			w->skewb.currentDirection);
+		int face = w->skewb.currentFace;
+		int position = w->skewb.currentPosition;
+		int direction = w->skewb.currentDirection;
+
+		w->skewb.currentFace = IGNORE_DIR;
+		w->skewb.currentPosition = IGNORE_DIR;
 		w->skewb.currentDirection = IGNORE_DIR;
+		movePieces(w, face, position, direction,
+			w->skewb.currentControl, w->skewb.currentFast);
 	}
 	return redraw;
 }
@@ -1629,10 +1709,9 @@ destroyPuzzle(Widget old)
 	Display *display = XtDisplay(w);
 	int face;
 
-#if 0
 #if defined( USE_SOUND ) && defined( USE_ESOUND )
-	(void) shutdown_sound();
-#endif
+	if (w->skewb.dim == 2)
+		(void) shutdown_sound();
 #endif
 	for (face = 0; face < MAX_FACES; face++)
 		XtReleaseGC(old, w->skewb.faceGC[face]);
@@ -1685,6 +1764,7 @@ Widget request, Widget renew
 #endif
 	w->skewb.focus = False;
 	loadFont(w);
+	checkPieces(w);
 	newMoves(&undo);
 	newMoves(&redo);
 	w->skewb.cheat = False;
@@ -1700,10 +1780,9 @@ Widget request, Widget renew
 #ifdef USE_NAS
 	dsp = XtDisplay(w);
 #endif
-#if 0
 #ifdef USE_ESOUND
-	(void) init_sound();
-#endif
+	if (w->skewb.dim == 2)
+		(void) init_sound();
 #endif
 #endif
 }
@@ -1730,27 +1809,35 @@ selectPuzzle(SkewbWidget w
 #ifndef WINVER
 	int x = event->xbutton.x, y = event->xbutton.y;
 	int control = (int) (event->xkey.state & ControlMask);
-	int alt = (int) (event->xkey.state & Mod1Mask);
+	int alt = (int) (event->xkey.state & (Mod1Mask | Mod3Mask | Mod4Mask | Mod5Mask));
 #endif
 
 	if (selectPieces(w, x, y, &(w->skewb.currentFace),
 			&(w->skewb.currentPosition))) {
 		if (w->skewb.currentPosition == MAX_ORIENT) {
 			if (control || alt || w->skewb.practice || !checkSolved(w)) {
-				drawDiamond(w, w->skewb.currentFace, TRUE);
+				drawDiamondAll(w, w->skewb.currentFace, TRUE);
 				FLUSH(w);
 				Sleep(100);
 				drawDiamond(w, w->skewb.currentFace, FALSE);
 				w->skewb.currentFace = IGNORE_DIR;
 				w->skewb.currentDirection = IGNORE_DIR;
+#ifdef HAVE_OPENGL
+				if (w->skewb.dim == 4)
+					drawAllPiecesGL((SkewbGLWidget) w);
+#endif
 			}
 		} else if (control || alt || w->skewb.practice || !checkSolved(w)) {
-			drawTriangle(w, w->skewb.currentFace, w->skewb.currentPosition,
+			drawTriangleAll(w, w->skewb.currentFace, w->skewb.currentPosition,
 				TRUE);
 		}
 	} else {
 		w->skewb.currentFace = IGNORE_DIR;
 		w->skewb.currentDirection = IGNORE_DIR;
+#ifdef HAVE_OPENGL
+		if (w->skewb.dim == 4)
+			drawAllPiecesGL((SkewbGLWidget) w);
+#endif
 	}
 }
 
@@ -1766,7 +1853,7 @@ releasePuzzle(SkewbWidget w
 #ifndef WINVER
 	int x = event->xbutton.x, y = event->xbutton.y;
 	int control = (int) (event->xkey.state & ControlMask);
-	int alt = (int) (event->xkey.state & Mod1Mask);
+	int alt = (int) (event->xkey.state & (Mod1Mask | Mod3Mask | Mod4Mask | Mod5Mask));
 #endif
 	int face, position, count = -1, direction = 0, ctrl = control;
 
@@ -1804,17 +1891,25 @@ releasePuzzle(SkewbWidget w
 				count = 0;
 		}
 		if (count == 1) {
-			movePuzzle(w, w->skewb.currentFace,
-				w->skewb.currentPosition, direction,
-				ctrl);
+			face = w->skewb.currentFace;
+			position = w->skewb.currentPosition;
+			w->skewb.currentFace = IGNORE_DIR;
+			w->skewb.currentPosition = IGNORE_DIR;
+			movePuzzle(w, face, position, direction, ctrl, NORMAL);
 			if (!ctrl && checkSolved(w)) {
 				setPuzzle(w, ACTION_SOLVED);
 			}
-		} else if (count == 0)
+		} else if (count == 0) {
 			moveNoPieces(w);
+		}
 	}
 	w->skewb.currentFace = IGNORE_DIR;
 	w->skewb.currentDirection = IGNORE_DIR;
+#ifdef HAVE_OPENGL
+	if (w->skewb.dim == 4 && count != 1) {
+		drawAllPiecesGL((SkewbGLWidget) w);
+	}
+#endif
 }
 
 #ifndef WINVER
