@@ -1,7 +1,7 @@
 /*
  * @(#)Skewb.h
  *
- * Copyright 1994 - 2008  David A. Bagley, bagleyd@tux.org
+ * Copyright 1994 - 2010  David A. Bagley, bagleyd@tux.org
  *
  * All rights reserved.
  *
@@ -53,8 +53,10 @@
 #define XtNstart ((char *) "start")
 #define XtNcheat ((char *) "cheat")
 #define XtNface ((char *) "face")
-#define XtNpos ((char *) "pos")
+#define XtNpos ((char *) "position")
 #define XtNdirection ((char *) "direction")
+#define XtNcontrol ((char *) "control")
+#define XtNfast ((char *) "fast")
 #define XtNpixmapSize ((char *) "pixmapSize")
 #define XtNselectCallback ((char *) "selectCallback")
 #define XtCMono ((char *) "Mono")
@@ -68,8 +70,10 @@
 #define XtCScoreFile ((char *) "ScoreFile")
 #define XtCMenu ((char *) "Menu")
 #define XtCFace ((char *) "Face")
-#define XtCPos ((char *) "Pos")
+#define XtCPos ((char *) "Position")
 #define XtCDirection ((char *) "Direction")
+#define XtCControl ((char *) "Control")
+#define XtCFast ((char *) "Fast")
 #define XtCPixmapSize ((char *) "PixmapSize")
 
 typedef struct _SkewbClassRec *SkewbWidgetClass;
@@ -80,6 +84,8 @@ typedef struct {
 	XEvent     *event;
 	int         reason;
 	int         face, position, direction;
+	int         control;
+	int         fast;
 } skewbCallbackStruct;
 #endif
 
@@ -89,15 +95,14 @@ typedef struct {
 #define ACTION_HIDE 103
 #define ACTION_PRACTICE_QUERY 104
 #define ACTION_RANDOMIZE_QUERY 105
-#define ACTION_SOLVE_MESSAGE 106
-#define ACTION_RESTORE 107
-#define ACTION_RESET 108
-#define ACTION_AMBIGUOUS 109
-#define ACTION_ILLEGAL 110
-#define ACTION_MOVED 111
-#define ACTION_CONTROL 112
-#define ACTION_SOLVED 113
-#define ACTION_COMPUTED 114
+#define ACTION_RESTORE 106
+#define ACTION_RESET 107
+#define ACTION_AMBIGUOUS 108
+#define ACTION_ILLEGAL 109
+#define ACTION_MOVED 110
+#define ACTION_CONTROL 111
+#define ACTION_SOLVED 112
+#define ACTION_COMPUTED 113
 #define ACTION_UNDO 200
 #define ACTION_REDO 201
 #define ACTION_CLEAR 202
@@ -110,6 +115,7 @@ typedef struct {
 #define ACTION_SOUND 209
 #define ACTION_VIEW 210
 #define ACTION_DIM 211
+#define ACTION_CHEAT 212
 #define ACTION_TR 300
 #define ACTION_BR 301
 #define ACTION_BL 302
