@@ -1,7 +1,7 @@
 /*
  * @(#)Skewb2d.c
  *
- * Copyright 1994 - 2008  David A. Bagley, bagleyd@tux.org
+ * Copyright 1994 - 2010  David A. Bagley, bagleyd@tux.org
  *
  * All rights reserved.
  *
@@ -27,7 +27,8 @@
 static Boolean setValuesPuzzle2D(Widget current, Widget request, Widget renew);
 static void resizePuzzle2D(Skewb2DWidget w);
 static void initializePuzzle2D(Widget request, Widget renew);
-static void exposePuzzle2D(Widget renew, XEvent *event, Region region);
+static void exposePuzzle2D(Widget renew,
+	XEvent *event, Region region);
 static void movePuzzle2DTl(Skewb2DWidget w,
 	XEvent *event, char **args, int nArgs);
 static void movePuzzle2DTop(Skewb2DWidget w,
@@ -36,7 +37,7 @@ static void movePuzzle2DTr(Skewb2DWidget w,
 	XEvent *event, char **args, int nArgs);
 static void movePuzzle2DLeft(Skewb2DWidget w,
 	XEvent *event, char **args, int nArgs);
-static void movePuzzle2dRight(Skewb2DWidget w,
+static void movePuzzle2DRight(Skewb2DWidget w,
 	XEvent *event, char **args, int nArgs);
 static void movePuzzle2DBl(Skewb2DWidget w,
 	XEvent *event, char **args, int nArgs);
@@ -58,6 +59,7 @@ static char translations2D[] =
  <KeyPress>0x3C: Slow()\n\
  <KeyPress>0x2C: Slow()\n\
  Shift<KeyPress>2: Sound()\n\
+ <KeyPress>F11: MoveCcw()\n\
  <KeyPress>KP_Divide: MoveCcw()\n\
  <KeyPress>R5: MoveCcw()\n\
  <KeyPress>Home: MoveTl()\n\
@@ -76,6 +78,7 @@ static char translations2D[] =
  <KeyPress>KP_Left: MoveLeft()\n\
  <KeyPress>KP_4: MoveLeft()\n\
  <KeyPress>R10: MoveLeft()\n\
+ <KeyPress>F12: MoveCw()\n\
  <KeyPress>Begin: MoveCw()\n\
  <KeyPress>KP_5: MoveCw()\n\
  <KeyPress>R11: MoveCw()\n\
@@ -126,7 +129,7 @@ static XtActionsRec actionsList2D[] =
 	{(char *) "MoveTr", (XtActionProc) movePuzzle2DTr},
 	{(char *) "MoveLeft", (XtActionProc) movePuzzle2DLeft},
 	{(char *) "MoveCw", (XtActionProc) movePuzzleCw},
-	{(char *) "MoveRight", (XtActionProc) movePuzzle2dRight},
+	{(char *) "MoveRight", (XtActionProc) movePuzzle2DRight},
 	{(char *) "MoveBl", (XtActionProc) movePuzzle2DBl},
 	{(char *) "MoveBottom", (XtActionProc) movePuzzle2DBottom},
 	{(char *) "MoveBr", (XtActionProc) movePuzzle2DBr},
@@ -175,25 +178,25 @@ static XtResource resources2D[] =
 	 XtRString, (caddr_t) "#AEB2C3" /*XtDefaultBackground*/},
 	{XtNframeColor, XtCColor, XtRPixel, sizeof (Pixel),
 	 XtOffset(SkewbWidget, skewb.frameColor),
-	 XtRString, (caddr_t) "cyan" /*XtDefaultForeground*/},
+	 XtRString, (caddr_t) "Cyan" /*XtDefaultForeground*/},
 	{XtNfaceColor0, XtCLabel, XtRString, sizeof (String),
 	 XtOffset(SkewbWidget, skewb.faceName[0]),
-	 XtRString, (caddr_t) "red"},
+	 XtRString, (caddr_t) "Red"},
 	{XtNfaceColor1, XtCLabel, XtRString, sizeof (String),
 	 XtOffset(SkewbWidget, skewb.faceName[1]),
-	 XtRString, (caddr_t) "blue"},
+	 XtRString, (caddr_t) "Blue"},
 	{XtNfaceColor2, XtCLabel, XtRString, sizeof (String),
 	 XtOffset(SkewbWidget, skewb.faceName[2]),
-	 XtRString, (caddr_t) "white"},
+	 XtRString, (caddr_t) "White"},
 	{XtNfaceColor3, XtCLabel, XtRString, sizeof (String),
 	 XtOffset(SkewbWidget, skewb.faceName[3]),
-	 XtRString, (caddr_t) "green"},
+	 XtRString, (caddr_t) "Green"},
 	{XtNfaceColor4, XtCLabel, XtRString, sizeof (String),
 	 XtOffset(SkewbWidget, skewb.faceName[4]),
-	 XtRString, (caddr_t) "pink"},
+	 XtRString, (caddr_t) "Pink"},
 	{XtNfaceColor5, XtCLabel, XtRString, sizeof (String),
 	 XtOffset(SkewbWidget, skewb.faceName[5]),
-	 XtRString, (caddr_t) "yellow"},
+	 XtRString, (caddr_t) "Yellow"},
 	{XtNpieceBorder, XtCColor, XtRPixel, sizeof (Pixel),
 	 XtOffset(SkewbWidget, skewb.borderColor),
 	 XtRString, (caddr_t) "gray25" /*XtDefaultForeground*/},
@@ -245,6 +248,12 @@ static XtResource resources2D[] =
 	{XtNdirection, XtCDirection, XtRInt, sizeof (int),
 	 XtOffset(SkewbWidget, skewb.currentDirection),
 	 XtRString, (caddr_t) "-1"},
+	{XtNcontrol, XtCControl, XtRInt, sizeof (int),
+	 XtOffset(SkewbWidget, skewb.currentControl),
+	 XtRString, (caddr_t) "0"},
+	{XtNfast, XtCFast, XtRInt, sizeof (int),
+	 XtOffset(SkewbWidget, skewb.currentFast),
+	 XtRString, (caddr_t) "1"},
 	{XtNpixmapSize, XtCPixmapSize, XtRInt, sizeof (int),
 	 XtOffset(SkewbWidget, skewb.pixmapSize),
 	 XtRString, (caddr_t) "64"},
@@ -426,9 +435,9 @@ drawOrientLine(Skewb2DWidget w, int cube, int orient, int dx, int dy,
 			return;
 		case TL:
 			DRAWLINE(w, dr, borderGC,
-				dx - w->skewb.delta,
+				dx - w->skewb.delta + 1,
 				dy,
-				dx - w->skewb.delta -
+				dx - w->skewb.delta + 1 -
 				w->skewb.orientLineLength / 2,
 				dy);
 			return;
@@ -864,7 +873,7 @@ movePuzzle2DTop(Skewb2DWidget w, XEvent *event, char **args, int nArgs)
 	movePuzzleInput((SkewbWidget) w, event->xbutton.x, event->xbutton.y,
 		TOP,
 		(int) (event->xkey.state & ControlMask),
-		(int) (event->xkey.state & Mod1Mask));
+		(int) (event->xkey.state & (Mod1Mask | Mod3Mask | Mod4Mask | Mod5Mask)));
 }
 
 static void
@@ -880,16 +889,16 @@ movePuzzle2DLeft(Skewb2DWidget w, XEvent *event, char **args, int nArgs)
 	movePuzzleInput((SkewbWidget) w, event->xbutton.x, event->xbutton.y,
 		LEFT,
 		(int) (event->xkey.state & ControlMask),
-		(int) (event->xkey.state & Mod1Mask));
+		(int) (event->xkey.state & (Mod1Mask | Mod3Mask | Mod4Mask | Mod5Mask)));
 }
 
 static void
-movePuzzle2dRight(Skewb2DWidget w, XEvent *event, char **args, int nArgs)
+movePuzzle2DRight(Skewb2DWidget w, XEvent *event, char **args, int nArgs)
 {
 	movePuzzleInput((SkewbWidget) w, event->xbutton.x, event->xbutton.y,
 		RIGHT,
 		(int) (event->xkey.state & ControlMask),
-		(int) (event->xkey.state & Mod1Mask));
+		(int) (event->xkey.state & (Mod1Mask | Mod3Mask | Mod4Mask | Mod5Mask)));
 }
 
 static void
@@ -905,7 +914,7 @@ movePuzzle2DBottom(Skewb2DWidget w, XEvent *event, char **args, int nArgs)
 	movePuzzleInput((SkewbWidget) w, event->xbutton.x, event->xbutton.y,
 		BOTTOM,
 		(int) (event->xkey.state & ControlMask),
-		(int) (event->xkey.state & Mod1Mask));
+		(int) (event->xkey.state & (Mod1Mask | Mod3Mask | Mod4Mask | Mod5Mask)));
 }
 
 static void
