@@ -1,7 +1,7 @@
 /*
  * @(#)Skewb3d.c
  *
- * Copyright 1994 - 2008  David A. Bagley, bagleyd@tux.org
+ * Copyright 1994 - 2010  David A. Bagley, bagleyd@tux.org
  *
  * All rights reserved.
  *
@@ -28,14 +28,22 @@ static Boolean setValuesPuzzle3D(Widget current, Widget request, Widget renew);
 static void resizePuzzle3D(Skewb3DWidget w);
 static void initializePuzzle3D(Widget request, Widget renew);
 static void exposePuzzle3D(Widget renew, XEvent *event, Region region);
-static void movePuzzle3DTl(Skewb3DWidget w, XEvent *event, char **args, int nArgs);
-static void movePuzzle3DTop(Skewb3DWidget w, XEvent *event, char **args, int nArgs);
-static void movePuzzle3DTr(Skewb3DWidget w, XEvent *event, char **args, int nArgs);
-static void movePuzzle3DLeft(Skewb3DWidget w, XEvent *event, char **args, int nArgs);
-static void movePuzzle3DRight(Skewb3DWidget w, XEvent *event, char **args, int nArgs);
-static void movePuzzle3DBl(Skewb3DWidget w, XEvent *event, char **args, int nArgs);
-static void movePuzzle3DBottom(Skewb3DWidget w, XEvent *event, char **args, int nArgs);
-static void movePuzzle3DBr(Skewb3DWidget w, XEvent *event, char **args, int nArgs);
+static void movePuzzle3DTl(Skewb3DWidget w,
+	XEvent *event, char **args, int nArgs);
+static void movePuzzle3DTop(Skewb3DWidget w,
+	XEvent *event, char **args, int nArgs);
+static void movePuzzle3DTr(Skewb3DWidget w,
+	XEvent *event, char **args, int nArgs);
+static void movePuzzle3DLeft(Skewb3DWidget w,
+	XEvent *event, char **args, int nArgs);
+static void movePuzzle3DRight(Skewb3DWidget w,
+	XEvent *event, char **args, int nArgs);
+static void movePuzzle3DBl(Skewb3DWidget w,
+	XEvent *event, char **args, int nArgs);
+static void movePuzzle3DBottom(Skewb3DWidget w,
+	XEvent *event, char **args, int nArgs);
+static void movePuzzle3DBr(Skewb3DWidget w,
+	XEvent *event, char **args, int nArgs);
 
 static char translations3D[] =
 "<KeyPress>q: Quit()\n\
@@ -50,6 +58,7 @@ static char translations3D[] =
  <KeyPress>0x3C: Slow()\n\
  <KeyPress>0x2C: Slow()\n\
  Shift<KeyPress>2: Sound()\n\
+ <KeyPress>F11: MoveCcw()\n\
  <KeyPress>KP_Divide: MoveCcw()\n\
  <KeyPress>R5: MoveCcw()\n\
  <KeyPress>Home: MoveTl()\n\
@@ -68,6 +77,7 @@ static char translations3D[] =
  <KeyPress>KP_Left: MoveLeft()\n\
  <KeyPress>KP_4: MoveLeft()\n\
  <KeyPress>R10: MoveLeft()\n\
+ <KeyPress>F12: MoveCw()\n\
  <KeyPress>Begin: MoveCw()\n\
  <KeyPress>KP_5: MoveCw()\n\
  <KeyPress>R11: MoveCw()\n\
@@ -167,25 +177,25 @@ static XtResource resources3D[] =
 	 XtRString, (caddr_t) "#AEB2C3" /*XtDefaultBackground*/},
 	{XtNframeColor, XtCColor, XtRPixel, sizeof (Pixel),
 	 XtOffset(SkewbWidget, skewb.frameColor),
-	 XtRString, (caddr_t) "cyan" /*XtDefaultForeground*/},
+	 XtRString, (caddr_t) "Cyan" /*XtDefaultForeground*/},
 	{XtNfaceColor0, XtCLabel, XtRString, sizeof (String),
 	 XtOffset(SkewbWidget, skewb.faceName[0]),
-	 XtRString, (caddr_t) "red"},
+	 XtRString, (caddr_t) "Red"},
 	{XtNfaceColor1, XtCLabel, XtRString, sizeof (String),
 	 XtOffset(SkewbWidget, skewb.faceName[1]),
-	 XtRString, (caddr_t) "blue"},
+	 XtRString, (caddr_t) "Blue"},
 	{XtNfaceColor2, XtCLabel, XtRString, sizeof (String),
 	 XtOffset(SkewbWidget, skewb.faceName[2]),
-	 XtRString, (caddr_t) "white"},
+	 XtRString, (caddr_t) "White"},
 	{XtNfaceColor3, XtCLabel, XtRString, sizeof (String),
 	 XtOffset(SkewbWidget, skewb.faceName[3]),
-	 XtRString, (caddr_t) "green"},
+	 XtRString, (caddr_t) "Green"},
 	{XtNfaceColor4, XtCLabel, XtRString, sizeof (String),
 	 XtOffset(SkewbWidget, skewb.faceName[4]),
-	 XtRString, (caddr_t) "pink"},
+	 XtRString, (caddr_t) "Pink"},
 	{XtNfaceColor5, XtCLabel, XtRString, sizeof (String),
 	 XtOffset(SkewbWidget, skewb.faceName[5]),
-	 XtRString, (caddr_t) "yellow"},
+	 XtRString, (caddr_t) "Yellow"},
 	{XtNpieceBorder, XtCColor, XtRPixel, sizeof (Pixel),
 	 XtOffset(SkewbWidget, skewb.borderColor),
 	 XtRString, (caddr_t) "gray25" /*XtDefaultForeground*/},
@@ -237,6 +247,12 @@ static XtResource resources3D[] =
 	{XtNdirection, XtCDirection, XtRInt, sizeof (int),
 	 XtOffset(SkewbWidget, skewb.currentDirection),
 	 XtRString, (caddr_t) "-1"},
+	{XtNcontrol, XtCControl, XtRInt, sizeof (int),
+	 XtOffset(SkewbWidget, skewb.currentControl),
+	 XtRString, (caddr_t) "0"},
+	{XtNfast, XtCFast, XtRInt, sizeof (int),
+	 XtOffset(SkewbWidget, skewb.currentFast),
+	 XtRString, (caddr_t) "1"},
 	{XtNpixmapSize, XtCPixmapSize, XtRInt, sizeof (int),
 	 XtOffset(SkewbWidget, skewb.pixmapSize),
 	 XtRString, (caddr_t) "64"},
@@ -817,16 +833,16 @@ resizePieces(Skewb3DWidget w)
 				subcubeLoc3D[face][orient + 1].y) / 2;
 			orientDiamondLoc3D[0][face][orient].x =
 				(orientCubeLoc3D[0][face][orient].x +
-				 orientCubeLoc3D[0][face][orient + 1].x) / 2;
+				orientCubeLoc3D[0][face][orient + 1].x) / 2;
 			orientDiamondLoc3D[0][face][orient].y =
 				(orientCubeLoc3D[0][face][orient].y +
-				 orientCubeLoc3D[0][face][orient + 1].y) / 2;
+				orientCubeLoc3D[0][face][orient + 1].y) / 2;
 			orientDiamondLoc3D[1][face][orient].x =
 				(orientCubeLoc3D[1][face][orient].x +
-				 orientCubeLoc3D[1][face][orient + 1].x) / 2;
+				orientCubeLoc3D[1][face][orient + 1].x) / 2;
 			orientDiamondLoc3D[1][face][orient].y =
 				(orientCubeLoc3D[1][face][orient].y +
-				 orientCubeLoc3D[1][face][orient + 1].y) / 2;
+				orientCubeLoc3D[1][face][orient + 1].y) / 2;
 		}
 		/* Its a parallelagram so take advantage of that */
 		diamondLoc3D[face][orient].x = (cubeLoc3D[face][MAX_ORIENT - 1].x -
@@ -844,16 +860,16 @@ resizePieces(Skewb3DWidget w)
 			subcubeLoc3D[face][MAX_ORIENT / 2].y) / 2;
 		orientDiamondLoc3D[0][face][orient].x =
 			(orientCubeLoc3D[0][face][MAX_ORIENT - 1].x -
-			 orientCubeLoc3D[0][face][MAX_ORIENT / 2].x) / 2;
+			orientCubeLoc3D[0][face][MAX_ORIENT / 2].x) / 2;
 		orientDiamondLoc3D[0][face][orient].y =
 			(orientCubeLoc3D[0][face][MAX_ORIENT - 1].y -
-			 orientCubeLoc3D[0][face][MAX_ORIENT / 2].y) / 2;
+			orientCubeLoc3D[0][face][MAX_ORIENT / 2].y) / 2;
 		orientDiamondLoc3D[1][face][orient].x =
 			(orientCubeLoc3D[1][face][MAX_ORIENT - 1].x -
-			 orientCubeLoc3D[1][face][MAX_ORIENT / 2].x) / 2;
+			orientCubeLoc3D[1][face][MAX_ORIENT / 2].x) / 2;
 		orientDiamondLoc3D[1][face][orient].y =
 			(orientCubeLoc3D[1][face][MAX_ORIENT - 1].y -
-			 orientCubeLoc3D[1][face][MAX_ORIENT / 2].y) / 2;
+			orientCubeLoc3D[1][face][MAX_ORIENT / 2].y) / 2;
 
 		mapFrom3D(w, face, 1, &corner);
 		orientDiamond[face][corner][0].x = cubeLoc3D[face][1].x / 2;
@@ -1165,7 +1181,7 @@ movePuzzle3DTl(Skewb3DWidget w, XEvent *event, char **args, int nArgs)
 	movePuzzleInput((SkewbWidget) w, event->xbutton.x, event->xbutton.y,
 		TL,
 		(int) (event->xkey.state & ControlMask),
-		(int) (event->xkey.state & Mod1Mask));
+		(int) (event->xkey.state & (Mod1Mask | Mod3Mask | Mod4Mask | Mod5Mask)));
 }
 
 static void
@@ -1174,7 +1190,7 @@ movePuzzle3DTop(Skewb3DWidget w, XEvent *event, char **args, int nArgs)
 	movePuzzleInput((SkewbWidget) w, event->xbutton.x, event->xbutton.y,
 		TOP,
 		(int) (event->xkey.state & ControlMask),
-		(int) (event->xkey.state & Mod1Mask));
+		(int) (event->xkey.state & (Mod1Mask | Mod3Mask | Mod4Mask | Mod5Mask)));
 }
 
 static void
@@ -1183,7 +1199,7 @@ movePuzzle3DTr(Skewb3DWidget w, XEvent *event, char **args, int nArgs)
 	movePuzzleInput((SkewbWidget) w, event->xbutton.x, event->xbutton.y,
 		TR,
 		(int) (event->xkey.state & ControlMask),
-		(int) (event->xkey.state & Mod1Mask));
+		(int) (event->xkey.state & (Mod1Mask | Mod3Mask | Mod4Mask | Mod5Mask)));
 }
 
 static void
@@ -1192,7 +1208,7 @@ movePuzzle3DLeft(Skewb3DWidget w, XEvent *event, char **args, int nArgs)
 	movePuzzleInput((SkewbWidget) w, event->xbutton.x, event->xbutton.y,
 		LEFT,
 		(int) (event->xkey.state & ControlMask),
-		(int) (event->xkey.state & Mod1Mask));
+		(int) (event->xkey.state & (Mod1Mask | Mod3Mask | Mod4Mask | Mod5Mask)));
 }
 
 static void
@@ -1201,7 +1217,7 @@ movePuzzle3DRight(Skewb3DWidget w, XEvent *event, char **args, int nArgs)
 	movePuzzleInput((SkewbWidget) w, event->xbutton.x, event->xbutton.y,
 		RIGHT,
 		(int) (event->xkey.state & ControlMask),
-		(int) (event->xkey.state & Mod1Mask));
+		(int) (event->xkey.state & (Mod1Mask | Mod3Mask | Mod4Mask | Mod5Mask)));
 }
 
 static void
@@ -1210,7 +1226,7 @@ movePuzzle3DBl(Skewb3DWidget w, XEvent *event, char **args, int nArgs)
 	movePuzzleInput((SkewbWidget) w, event->xbutton.x, event->xbutton.y,
 		BL,
 		(int) (event->xkey.state & ControlMask),
-		(int) (event->xkey.state & Mod1Mask));
+		(int) (event->xkey.state & (Mod1Mask | Mod3Mask | Mod4Mask | Mod5Mask)));
 }
 
 static void
@@ -1219,7 +1235,7 @@ movePuzzle3DBottom(Skewb3DWidget w, XEvent *event, char **args, int nArgs)
 	movePuzzleInput((SkewbWidget) w, event->xbutton.x, event->xbutton.y,
 		BOTTOM,
 		(int) (event->xkey.state & ControlMask),
-		(int) (event->xkey.state & Mod1Mask));
+		(int) (event->xkey.state & (Mod1Mask | Mod3Mask | Mod4Mask | Mod5Mask)));
 }
 
 static void
@@ -1228,6 +1244,6 @@ movePuzzle3DBr(Skewb3DWidget w, XEvent *event, char **args, int nArgs)
 	movePuzzleInput((SkewbWidget) w, event->xbutton.x, event->xbutton.y,
 		BR,
 		(int) (event->xkey.state & ControlMask),
-		(int) (event->xkey.state & Mod1Mask));
+		(int) (event->xkey.state & (Mod1Mask | Mod3Mask | Mod4Mask | Mod5Mask)));
 }
 #endif
