@@ -1,7 +1,7 @@
 /*
  * @(#)SkewbP.h
  *
- * Copyright 1994 - 2008  David A. Bagley, bagleyd@tux.org
+ * Copyright 1994 - 2009  David A. Bagley, bagleyd@tux.org
  *
  * All rights reserved.
  *
@@ -37,7 +37,7 @@ extern void dimPuzzle(SkewbWidget w);
 extern int  movePuzzleDir(SkewbWidget w, const int direction);
 extern void setPuzzle(SkewbWidget w, int reason);
 extern void setPuzzleMove(SkewbWidget w, int reason, int face, int position,
-	int direction);
+	int direction, int control, int fast);
 
 #else
 
@@ -83,6 +83,10 @@ extern void movePuzzleCcw(SkewbWidget w, XEvent *event, char **args,
 #define MINOR 0
 #define MAJOR 1
 
+#define NORMAL 1
+#define DOUBLE 2
+#define INSTANT 3
+
 typedef struct _SkewbLocPos {
 	int         face, position, direction;
 } SkewbLocPos;
@@ -114,7 +118,8 @@ typedef struct _SkewbPart {
 	SkewbLoc    rowLoc[MAX_ORIENT][MAX_CUBES];
 	SkewbLoc    minorLoc[MAX_ORIENT], majorLoc[MAX_ORIENT][MAX_ORIENT];
 	SkewbLoc    skewbLoc[MAX_FACES][MAX_CUBES];
-	int         currentFace, currentPosition, currentDirection;
+	int         currentFace, currentPosition, currentDirection, currentFast;
+	int         currentControl;
 	Boolean     started, cheat, sound;
 	Boolean     practice, orient, vertical, mono, reverse, focus;
 	Boolean     scoreOnly, versionOnly;
@@ -264,14 +269,13 @@ extern void leavePuzzle(SkewbWidget w
 
 extern void movePuzzleInput(SkewbWidget w, int x, int y, int direction,
 	int control, int alt);
+extern void setPuzzle(SkewbWidget w, int reason);
 extern void movePuzzle(SkewbWidget w, int face, int position, int direction,
-	int control);
+	int control, int speed);
+extern void movePuzzleDelay(SkewbWidget w,
+	int face, int position, int direction, int control);
 extern void setAllColors(SkewbWidget w);
-#if 0
-/* For future auto-solver */
-extern void solvePieces(SkewbWidget w);
-
-#endif
+extern void solveSomePieces(SkewbWidget w);
 extern void drawAllPieces(SkewbWidget w);
 extern Boolean checkSolved(SkewbWidget w);
 extern void newMoves(SkewbStack *s);
