@@ -1,7 +1,7 @@
 /*
  * @(#)SkewbU.c
  *
- * Copyright 1994 - 2008  David A. Bagley, bagleyd@tux.org
+ * Copyright 1994 - 2009  David A. Bagley, bagleyd@tux.org
  *
  * All rights reserved.
  *
@@ -201,7 +201,7 @@ scanMoves(FILE *fp, SkewbWidget w, int moves)
 		while ((c = getc(fp)) != EOF && c != SYMBOL);
 		(void) fscanf(fp, "%d %d %d %d",
 			&face, &position, &direction, &control);
-		movePuzzle(w, face, position, direction, control);
+		movePuzzle(w, face, position, direction, control, INSTANT);
 	}
 }
 
