@@ -1,7 +1,7 @@
 /*
  * @(#)xskewb.c
  *
- * Copyright 1993 - 2009  David A. Bagley, bagleyd@tux.org
+ * Copyright 1993 - 2010  David A. Bagley, bagleyd@tux.org
  *
  * All rights reserved.
  *
@@ -21,8 +21,9 @@
 /* Driver file for Skewb */
 
 #ifndef WINVER
+#include "version.h"
 static const char aboutHelp[] = {
-"Skewb Version 7.5\n"
+"Skewb Version " VERSION "\n"
 "Send bugs (reports or fixes) to the author: "
 "David Bagley <bagleyd@tux.org>\n"
 "The latest version is at: "
@@ -92,8 +93,7 @@ static const char featuresHelp[] = {
 "\n"
 "Press \"C\" or \"c\" keys to clear the puzzle.\n"
 "\n"
-"\"S\" or \"s\" keys reserved for the auto-solver "
-"(not implemented).\n"
+"\"S\" or \"s\" keys to start auto-solver.\n"
 "\n"
 "Press \"O\" or \"o\" keys to toggle  the orient mode.  One "
 "has  to orient the faces  in orient mode,  besides\n"
@@ -105,11 +105,9 @@ static const char featuresHelp[] = {
 "\n"
 "Press \"V\" or \"v\" keys to change the view of the cube.\n"
 "\n"
-"Press \">\" or \".\" keys to speed up the movement of pieces "
-"(not implemented).\n"
+"Press \">\" or \".\" keys to speed up the movement of pieces.\n"
 "\n"
-"Press \"<\" or \",\" keys to slow down the movement of pieces "
-"(not implemented).\n"
+"Press \"<\" or \",\" keys to slow down the movement of pieces.\n"
 "\n"
 "Press \"@\" key to toggle the sound.\n"
 "\n"
@@ -125,9 +123,7 @@ static const char featuresHelp[] = {
 "4<5>6  Left, Clockwise, Right\n"
 "  v\n"
 "1 2 3  Lower Left, Down, Lower Right\n"
-"Note: Top, Left, Right, and Down only work when the "
-"control key is pressed and there is no analog for\n"
-"Skewb3d.\n"
+"\n"
 "If the mouse is on a diamond, the above keys will not "
 "move cube because the move is ambiguous.  Also\n"
 "if the mouse is on a triangle, not all the keys will "
@@ -146,8 +142,10 @@ static const char featuresHelp[] = {
 "same is \"5\" is Clockwise and \"/\" is Counterclockwise.\n"
 "\n"
 "Use the control key and the left mouse button, keypad, or "
-"arrow keys to move the whole cube.  This is\n"
-"not recorded as a turn."
+"arrow keys to move the whole cube.  Its also possible to\n"
+"rotate whole cube with an axis through a face with alt key "
+"is pressed (Tab key when using Windows).This is not\n"
+"recorded as a turn.\n"
 };
 
 static const char referencesHelp[] = {
@@ -191,6 +189,7 @@ static SkewbRec widget;
 #include <Xm/MessageB.h>
 #include <Xm/PushBG.h>
 #include <Xm/CascadeB.h>
+#include <Xm/Scale.h>
 #include <Xm/ToggleB.h>
 #ifdef MOUSEBITMAPS
 #include "pixmaps/mouse-l.xbm"
@@ -203,9 +202,10 @@ static SkewbRec widget;
 #define SET_STARTED(w,b) XtVaSetValues(w, XtNstart, b, NULL)
 #include "Skewb.h"
 #include "Skewb2d.h"
-#include "Skewb3d.h"
 #ifdef HAVE_OPENGL
 #include "SkewbGL.h"
+#else
+#include "Skewb3d.h"
 #endif
 #ifdef HAVE_XPM
 #include <X11/xpm.h>
@@ -273,7 +273,10 @@ static char progDsp[PROGRAM_NAME_LENGTH] = TITLE;
 static char userNameDsp[USER_NAME_LENGTH] = "Guest";
 #else
 #ifdef HAVE_MOTIF
-static Widget movesText, recordText, message, orientizeSwitch, practiceSwitch;
+#define MIN_SPEED 1
+#define MAX_SPEED 50
+static Widget movesText, recordText, message;
+static Widget speedSlider, orientizeSwitch, practiceSwitch;
 static char buff[21];
 static Widget descriptionDialog, featuresDialog;
 static Widget optionsDialog, referencesDialog, aboutDialog;
@@ -281,15 +284,9 @@ static Widget solveDialog, practiceDialog, randomizeDialog;
 static Arg arg[3];
 #else
 static Widget shell;
-#ifdef HAVE_OPENGL
-static Widget shellGL;
-#endif
 #endif
 static Pixmap pixmap = None;
 static Widget topLevel, puzzle2d, puzzle3d;
-#ifdef HAVE_OPENGL
-static Widget puzzleGL;
-#endif
 static char *progDsp;
 static char userNameDsp[USER_NAME_LENGTH] = "";
 
@@ -411,6 +408,7 @@ writeRecords(void)
 		char lockFile[FILE_NAME_LENGTH];
 
 		(void) strncpy(lockFile, fileName, FILE_NAME_LENGTH - 6);
+		lockFile[FILE_NAME_LENGTH - 6] = '\0';
 		(void) strcat(lockFile, ".lock");
 		while (((lfd = open(lockFile, O_CREAT | O_EXCL, 0644)) < 0) &&
 				errno == EEXIST)
@@ -460,7 +458,7 @@ printRecord(Boolean orient, Boolean practice)
  * but I do not know it off hand. */
 static void
 makeEquivalent(String *userName, String *scoreFile,
-		Boolean *orient, Boolean *practice)
+		Boolean *orient, Boolean *practice, int *delay)
 {
 	Boolean mono, reverse;
 	Boolean scoreOnly, versionOnly;
@@ -474,6 +472,7 @@ makeEquivalent(String *userName, String *scoreFile,
 		XtNpractice, practice,
 		XtNmono, &mono,
 		XtNreverseVideo, &reverse,
+		XtNdelay, delay,
 		XtNforeground, &foreground,
 		XtNbackground, &background,
 		XtNpieceBorder, &pieceBorder,
@@ -508,6 +507,7 @@ makeEquivalent(String *userName, String *scoreFile,
 		XtNreverseVideo, reverse,
 		XtNdirection, IGNORE_DIR,
 		XtNstart, False,
+		XtNdelay, *delay,
 		XtNforeground, foreground,
 		XtNbackground, background,
 		XtNpieceBorder, pieceBorder,
@@ -517,25 +517,6 @@ makeEquivalent(String *userName, String *scoreFile,
 		XtNfaceColor3, faceColor[3],
 		XtNfaceColor4, faceColor[4],
 		XtNfaceColor5, faceColor[5], NULL);
-#ifdef HAVE_OPENGL
-	XtVaSetValues(puzzleGL,
-		XtNuserName, *userName,
-		XtNorient, *orient,
-		XtNpractice, *practice,
-		XtNmono, mono,
-		XtNreverseVideo, reverse,
-		XtNdirection, IGNORE_DIR,
-		XtNstart, False,
-		XtNforeground, foreground,
-		XtNbackground, background,
-		XtNpieceBorder, pieceBorder,
-		XtNfaceColor0, faceColor[0],
-		XtNfaceColor1, faceColor[1],
-		XtNfaceColor2, faceColor[2],
-		XtNfaceColor3, faceColor[3],
-		XtNfaceColor4, faceColor[4],
-		XtNfaceColor5, faceColor[5], NULL);
-#endif
 }
 #endif
 
@@ -562,11 +543,6 @@ printStatus(char *msg, int nMoves
 #ifdef WINVER
 	SetWindowText(widget.core.hWnd, (LPSTR) titleDsp);
 #else
-#ifdef HAVE_OPENGL
-	if (dim == 4)
-		XtVaSetValues(XtParent(puzzleGL), XtNtitle, titleDsp, NULL);
-	else
-#endif
 	XtVaSetValues(XtParent((dim == 2) ? puzzle2d : puzzle3d),
 		XtNtitle, titleDsp, NULL);
 #endif
@@ -620,7 +596,9 @@ void
 	if (strcmp(scoreFile, ""))
 		(void) strncpy(scoreFileName, scoreFile, FILE_NAME_LENGTH);
 #else
-	makeEquivalent(&userName, &scoreFile, &orient, &practice);
+	int delay;
+
+	makeEquivalent(&userName, &scoreFile, &orient, &practice, &delay);
 #ifdef HAVE_MOTIF
 	XmToggleButtonSetState(orientizeSwitch, orient, True);
 	XmToggleButtonSetState(practiceSwitch, practice, True);
@@ -660,9 +638,10 @@ void
 	printStatus(messageDsp, movesDsp);
 #else
 	printStatus(messageDsp, movesDsp, 2);
-	printStatus(messageDsp, movesDsp, 3);
 #ifdef HAVE_OPENGL
 	printStatus(messageDsp, movesDsp, 4);
+#else
+	printStatus(messageDsp, movesDsp, 3);
 #endif
 #endif
 #endif
@@ -681,53 +660,32 @@ puzzleListener(Widget w, caddr_t clientData, skewbCallbackStruct *callData)
 	int dim = 0;
 #else
 	int reason = callData->reason;
-	Widget otherw1 = (Widget) NULL;
-#ifdef HAVE_OPENGL
-	Widget otherw2 = (Widget) NULL;
-#endif
+	Widget otherw = (Widget) NULL;
 #ifndef HAVE_MOTIF
-	int dim = 0, otherdim1 = 0;
-#ifdef HAVE_OPENGL
-	int otherdim2 = 0;
-#endif
+	int dim = 0, otherdim = 0;
 #endif
 
 	if (w == puzzle2d) {
-		otherw1 = puzzle3d;
-#ifdef HAVE_OPENGL
-		otherw2 = puzzleGL;
-#endif
+		otherw = puzzle3d;
 #ifndef HAVE_MOTIF
 		dim = 2;
-		otherdim1 = 3;
 #ifdef HAVE_OPENGL
-		otherdim2 = 4;
+		otherdim = 4;
+#else
+		otherdim = 3;
 #endif
 #endif
 	} else if (w == puzzle3d) {
-		otherw1 = puzzle2d;
-#ifdef HAVE_OPENGL
-		otherw2 = puzzleGL;
-#endif
+		otherw = puzzle2d;
 #ifndef HAVE_MOTIF
-		dim = 3;
-		otherdim1 = 2;
+		otherdim = 2;
 #ifdef HAVE_OPENGL
-		otherdim2 = 4;
-#endif
-#endif
-	}
-#ifdef HAVE_OPENGL
-	else if (w == puzzleGL) {
-		otherw1 = puzzle2d;
-		otherw2 = puzzle3d;
-#ifndef HAVE_MOTIF
 		dim = 4;
-		otherdim1 = 2;
-		otherdim2 = 3;
+#else
+		dim = 3;
+#endif
 #endif
 	}
-#endif
 #endif
 	(void) strcpy(messageDsp, "");
 #ifdef WINVER
@@ -755,11 +713,6 @@ puzzleListener(Widget w, caddr_t clientData, skewbCallbackStruct *callData)
 		(void) XIconifyWindow(XtDisplay(shell),
 			XtWindow(shell),
 			XScreenNumberOfScreen(XtScreen(shell)));
-#ifdef HAVE_OPENGL
-		(void) XIconifyWindow(XtDisplay(shellGL),
-			XtWindow(shellGL),
-			XScreenNumberOfScreen(XtScreen(shellGL)));
-#endif
 #endif
 #endif
 		break;
@@ -779,18 +732,6 @@ puzzleListener(Widget w, caddr_t clientData, skewbCallbackStruct *callData)
 #endif
 		break;
 #endif
-	case ACTION_SOLVE_MESSAGE:
-#ifdef WINVER
-		(void) MessageBox(w->core.hWnd, solveHelp,
-			"Auto-solve", MB_OK);
-#else
-#ifdef HAVE_MOTIF
-		XtManageChild(solveDialog);
-#else
-		(void) strncpy(messageDsp, solveHelp, MESSAGE_LENGTH);
-#endif
-#endif
-		break;
 	case ACTION_RESTORE:
 		if (practice) {
 			(void) strncpy(recordDsp, "practice",
@@ -802,11 +743,7 @@ puzzleListener(Widget w, caddr_t clientData, skewbCallbackStruct *callData)
 		movesDsp = 0;
 		randomized = False;
 #ifndef WINVER
-#ifdef HAVE_OPENGL
-		XtVaSetValues(otherw2,
-			XtNdirection, RESTORE_DIR, NULL);
-#endif
-		XtVaSetValues(otherw1,
+		XtVaSetValues(otherw,
 			XtNdirection, RESTORE_DIR, NULL);
 		XtVaSetValues(w,
 			XtNdirection, RESTORE_DIR, NULL);
@@ -816,11 +753,7 @@ puzzleListener(Widget w, caddr_t clientData, skewbCallbackStruct *callData)
 		movesDsp = 0;
 		randomized = False;
 #ifndef WINVER
-#ifdef HAVE_OPENGL
-		XtVaSetValues(otherw2,
-			XtNdirection, CLEAR_DIR, NULL);
-#endif
-		XtVaSetValues(otherw1,
+		XtVaSetValues(otherw,
 			XtNdirection, CLEAR_DIR, NULL);
 		XtVaSetValues(w,
 			XtNdirection, CLEAR_DIR, NULL);
@@ -841,31 +774,22 @@ puzzleListener(Widget w, caddr_t clientData, skewbCallbackStruct *callData)
 #ifndef WINVER
 	case ACTION_MOVED:
 		movesDsp++;
-#ifdef HAVE_OPENGL
-		XtVaSetValues(otherw2,
+		XtVaSetValues(otherw,
 			XtNstart, True,
 			XtNface, callData->face,
 			XtNpos, callData->position,
-			XtNdirection, callData->direction, NULL);
-#endif
-		XtVaSetValues(otherw1,
-			XtNstart, True,
-			XtNface, callData->face,
-			XtNpos, callData->position,
-			XtNdirection, callData->direction, NULL);
+			XtNdirection, callData->direction,
+			XtNcontrol, callData->control,
+			XtNfast, callData->fast, NULL);
 		SET_STARTED(w, True);
 		break;
 	case ACTION_CONTROL:
-#ifdef HAVE_OPENGL
-		XtVaSetValues(otherw2,
+		XtVaSetValues(otherw,
 			XtNface, callData->face,
 			XtNpos, callData->position,
-			XtNdirection, callData->direction, NULL);
-#endif
-		XtVaSetValues(otherw1,
-			XtNface, callData->face,
-			XtNpos, callData->position,
-			XtNdirection, callData->direction, NULL);
+			XtNdirection, callData->direction,
+			XtNcontrol, callData->control,
+			XtNfast, callData->fast, NULL);
 		break;
 #endif
 	case ACTION_SOLVED:
@@ -882,22 +806,14 @@ puzzleListener(Widget w, caddr_t clientData, skewbCallbackStruct *callData)
 				MESSAGE_LENGTH);
 		SET_STARTED(w, False);
 #ifndef WINVER
-#ifdef HAVE_OPENGL
-		SET_STARTED(otherw2, False);
-#endif
-		SET_STARTED(otherw1, False);
+		SET_STARTED(otherw, False);
 #endif
 		randomized = False;
 		break;
 	case ACTION_COMPUTED:
-#ifdef WINVER
 		SET_STARTED(w, False);
-#else
-		SET_STARTED(w, False);
-#ifdef HAVE_OPENGL
-		SET_STARTED(otherw2, False);
-#endif
-		SET_STARTED(otherw1, False);
+#ifndef WINVER
+		SET_STARTED(otherw, False);
 #endif
 		break;
 	case ACTION_PRACTICE:
@@ -915,12 +831,7 @@ puzzleListener(Widget w, caddr_t clientData, skewbCallbackStruct *callData)
 		XtVaSetValues(w,
 			XtNpractice, practice,
 			XtNstart, False, NULL);
-#ifdef HAVE_OPENGL
-		XtVaSetValues(otherw2,
-			XtNpractice, practice,
-			XtNstart, False, NULL);
-#endif
-		XtVaSetValues(otherw1,
+		XtVaSetValues(otherw,
 			XtNpractice, practice,
 			XtNstart, False, NULL);
 #ifdef HAVE_MOTIF
@@ -938,12 +849,7 @@ puzzleListener(Widget w, caddr_t clientData, skewbCallbackStruct *callData)
 		XtVaSetValues(w,
 			XtNpractice, False,
 			XtNstart, False, NULL);
-#ifdef HAVE_OPENGL
-		XtVaSetValues(otherw2,
-			XtNpractice, False,
-			XtNstart, False, NULL);
-#endif
-		XtVaSetValues(otherw1,
+		XtVaSetValues(otherw,
 			XtNpractice, False,
 			XtNstart, False, NULL);
 #endif
@@ -956,14 +862,14 @@ puzzleListener(Widget w, caddr_t clientData, skewbCallbackStruct *callData)
 #ifdef WINVER
 			view = w->skewb.view;
 #else
-			XtVaGetValues(puzzleGL,
+			XtVaGetValues(puzzle3d,
 				XtNview, &view, NULL);
 #endif
 			view = (view + 1) % (2 * MAX_VIEWS);
 #ifdef WINVER
 			w->skewb.view = view;
 #else
-			XtVaSetValues(puzzleGL,
+			XtVaSetValues(puzzle3d,
 				XtNview, view, NULL);
 #endif
 		}
@@ -978,11 +884,7 @@ puzzleListener(Widget w, caddr_t clientData, skewbCallbackStruct *callData)
 #else
 		XtVaSetValues(w,
 			XtNorient, orient, NULL);
-#ifdef HAVE_OPENGL
-		XtVaSetValues(otherw2,
-			XtNorient, orient, NULL);
-#endif
-		XtVaSetValues(otherw1,
+		XtVaSetValues(otherw,
 			XtNorient, orient, NULL);
 #ifdef HAVE_MOTIF
 		XmToggleButtonSetState(orientizeSwitch, orient, True);
@@ -992,36 +894,26 @@ puzzleListener(Widget w, caddr_t clientData, skewbCallbackStruct *callData)
 #ifndef WINVER
 	case ACTION_UNDO:
 		movesDsp--;
-#ifdef HAVE_OPENGL
-		XtVaSetValues(otherw2,
+		XtVaSetValues(otherw,
 			XtNstart, True,
 			XtNface, callData->face,
 			XtNpos, callData->position,
-			XtNdirection, callData->direction, NULL);
-#endif
-		XtVaSetValues(otherw1,
-			XtNstart, True,
-			XtNface, callData->face,
-			XtNpos, callData->position,
-			XtNdirection, callData->direction, NULL);
+			XtNdirection, callData->direction,
+			XtNcontrol, callData->control,
+			XtNfast, callData->fast, NULL);
 		SET_STARTED(w, True);
 		break;
 #endif
 #ifndef WINVER
 	case ACTION_REDO:
 		movesDsp++;
-#ifdef HAVE_OPENGL
-		XtVaSetValues(otherw2,
+		XtVaSetValues(otherw,
 			XtNstart, True,
 			XtNface, callData->face,
 			XtNpos, callData->position,
-			XtNdirection, callData->direction, NULL);
-#endif
-		XtVaSetValues(otherw1,
-			XtNstart, True,
-			XtNface, callData->face,
-			XtNpos, callData->position,
-			XtNdirection, callData->direction, NULL);
+			XtNdirection, callData->direction,
+			XtNcontrol, callData->control,
+			XtNfast, callData->fast, NULL);
 		SET_STARTED(w, True);
 		break;
 #endif
@@ -1029,7 +921,9 @@ puzzleListener(Widget w, caddr_t clientData, skewbCallbackStruct *callData)
 	case ACTION_DIM:
 		dim++;
 #ifdef HAVE_OPENGL
-		if (dim > 4)
+		if (dim == 3)
+			dim = 4;
+		else if (dim > 4)
 #else
 		if (dim > 3)
 #endif
@@ -1037,7 +931,14 @@ puzzleListener(Widget w, caddr_t clientData, skewbCallbackStruct *callData)
 		w->skewb.dim = dim;
 		break;
 #endif
-
+#ifndef WINVER
+	case ACTION_CHEAT:
+		XtVaSetValues(w,
+			XtNcheat, cheat, NULL);
+		XtVaSetValues(otherw,
+			XtNcheat, cheat, NULL);
+		break;
+#endif
 	}
 #ifdef WINVER
 	printStatus(messageDsp, movesDsp, dim);
@@ -1046,17 +947,15 @@ puzzleListener(Widget w, caddr_t clientData, skewbCallbackStruct *callData)
 	printStatus(messageDsp, movesDsp);
 #else
 	printStatus(messageDsp, movesDsp, dim);
-	printStatus(messageDsp, movesDsp, otherdim1);
-#ifdef HAVE_OPENGL
-	printStatus(messageDsp, movesDsp, otherdim2);
-#endif
+	printStatus(messageDsp, movesDsp, otherdim);
 #endif
 #endif
 }
 
 #ifdef WINVER
 void
-setPuzzleMove(SkewbWidget w, int reason, int face, int position, int direction)
+setPuzzleMove(SkewbWidget w, int reason, int face, int position,
+		int direction, int control, int fast)
 {
 	/* Boolean orient, practice, cheat; */
 	int dim;
@@ -1453,7 +1352,8 @@ static XrmOptionDescRec options[] =
 
 #ifdef HAVE_MOTIF
 static void
-puzzlePracticeListener(Widget w, XtPointer clientData, XmAnyCallbackStruct *cbs)
+puzzlePracticeListener(Widget w, XtPointer clientData,
+		XmAnyCallbackStruct *cbs)
 {
 	if (cbs->reason == XmCR_OK) {
 		XtVaSetValues(puzzle2d, XtNmenu, ACTION_PRACTICE, NULL);
@@ -1461,7 +1361,8 @@ puzzlePracticeListener(Widget w, XtPointer clientData, XmAnyCallbackStruct *cbs)
 }
 
 static void
-puzzleRandomizeListener(Widget w, XtPointer clientData, XmAnyCallbackStruct *cbs)
+puzzleRandomizeListener(Widget w, XtPointer clientData,
+		XmAnyCallbackStruct *cbs)
 {
 	if (cbs->reason == XmCR_OK) {
 		XtVaSetValues(puzzle2d, XtNmenu, ACTION_RANDOMIZE, NULL);
@@ -1469,7 +1370,8 @@ puzzleRandomizeListener(Widget w, XtPointer clientData, XmAnyCallbackStruct *cbs
 }
 
 static void
-orientToggle(Widget w, XtPointer clientData, XmToggleButtonCallbackStruct *cbs)
+orientToggle(Widget w, XtPointer clientData,
+		XmToggleButtonCallbackStruct *cbs)
 {
 	Boolean orient = cbs->set, practice;
 
@@ -1479,10 +1381,6 @@ orientToggle(Widget w, XtPointer clientData, XmToggleButtonCallbackStruct *cbs)
 		XtNorient, orient, NULL);
 	XtVaSetValues(puzzle3d,
 		XtNorient, orient, NULL);
-#ifdef HAVE_OPENGL
-	XtVaSetValues(puzzleGL,
-		XtNorient, orient, NULL);
-#endif
 	movesDsp = 0;
 	(void) sprintf(buff, "%d", movesDsp);
 	printState(movesText, buff);
@@ -1503,11 +1401,6 @@ practiceToggle(Widget w, XtPointer clientData,
 	XtVaSetValues(puzzle3d,
 		XtNpractice, practice,
 		XtNstart, False, NULL);
-#ifdef HAVE_OPENGL
-	XtVaSetValues(puzzleGL,
-		XtNpractice, practice,
-		XtNstart, False, NULL);
-#endif
 	XtVaGetValues(puzzle2d,
 		XtNpractice, &orient, NULL);
 	movesDsp = 0;
@@ -1521,6 +1414,20 @@ practiceToggle(Widget w, XtPointer clientData,
 	printState(message, messageDsp);
 }
 
+static void
+speedChangeListener(Widget w, XtPointer clientData,
+		XmScaleCallbackStruct *cbs)
+{
+        int delay = MAX_SPEED + MIN_SPEED - cbs->value - 1, oldDelay;
+
+	XtVaGetValues(puzzle2d,
+		XtNdelay, &oldDelay, NULL);
+	if (oldDelay != delay) {
+		XtVaSetValues(puzzle3d, XtNdelay, delay, NULL);
+		XtVaSetValues(puzzle2d, XtNdelay, delay, NULL);
+	}
+}
+
 static void
 fileMenuListener(Widget w, void *value, void *clientData)
 {
@@ -1680,7 +1587,7 @@ main(int argc, char **argv)
 	clearString = XmStringCreateSimple((char *) "Clear");
 	practiceString = XmStringCreateSimple((char *) "Practice");
 	randomizeString = XmStringCreateSimple((char *) "Randomize");
-	solveString = XmStringCreateSimple((char *) "(Auto-solve)");
+	solveString = XmStringCreateSimple((char *) "Auto-solve");
 	orientizeString = XmStringCreateSimple((char *) "Orientize");
 	speedString = XmStringCreateSimple((char *) "Speed >");
 	slowString = XmStringCreateSimple((char *) "Slow <");
@@ -1767,7 +1674,7 @@ main(int argc, char **argv)
 		XmNseparatorOn, False,
 		XmNsashWidth, 1,
 		XmNsashHeight, 1, NULL);
-	movesRowCol = XtVaCreateManagedWidget("Rowcol",
+	movesRowCol = XtVaCreateManagedWidget("movesRowcol",
 		xmRowColumnWidgetClass, controlPanel,
 		XmNnumColumns, 2,
 		XmNorientation, XmHORIZONTAL,
@@ -1837,6 +1744,16 @@ main(int argc, char **argv)
 		XmNset, DEFAULT_PRACTICE, NULL);
 	XtAddCallback(practiceSwitch, XmNvalueChangedCallback,
 		(XtCallbackProc) practiceToggle, (XtPointer) NULL);
+	speedSlider = XtVaCreateManagedWidget("speedSlider",
+		xmScaleWidgetClass, switchRowCol,
+		XtVaTypedArg, XmNtitleString, XmRString, "Animation Speed", 16,
+		XmNminimum, MIN_SPEED,
+		XmNmaximum, MAX_SPEED,
+		XmNvalue, MAX_SPEED - 10,
+		XmNshowValue, True,
+		XmNorientation, XmHORIZONTAL, NULL);
+	XtAddCallback(speedSlider, XmNvalueChangedCallback,
+		(XtCallbackProc) speedChangeListener, (XtPointer) NULL);
 	messageRowCol = XtVaCreateManagedWidget("messageRowCol",
 		xmRowColumnWidgetClass, controlPanel, NULL);
 	message = XtVaCreateManagedWidget("Play Skewb! (use mouse and keypad)",
@@ -1847,30 +1764,28 @@ main(int argc, char **argv)
 		XtNheight, 200, NULL);
 	XtAddCallback(puzzle2d, XtNselectCallback,
 		(XtCallbackProc) puzzleListener, (XtPointer) NULL);
+#ifdef HAVE_OPENGL
+	puzzle3d = XtCreateManagedWidget("skewb",
+		skewbGLWidgetClass, mainPanel, NULL, 0);
+#else
 	puzzle3d = XtCreateManagedWidget("skewb",
 		skewb3dWidgetClass, mainPanel, NULL, 0);
+#endif
 	XtVaSetValues(puzzle3d,
 		XtNheight, 200, NULL);
-#ifdef HAVE_OPENGL
-	puzzleGL = XtCreateManagedWidget("skewb",
-		skewbGLWidgetClass, mainPanel, NULL, 0);
-	XtVaSetValues(puzzleGL,
-		XtNheight, 200, NULL);
-#endif
 #else
 	shell = XtCreateApplicationShell(argv[0],
 		topLevelShellWidgetClass, NULL, 0);
-#ifdef HAVE_OPENGL
-	shellGL = XtCreateApplicationShell(argv[0],
-		topLevelShellWidgetClass, NULL, 0);
-#endif
 	puzzle2d = XtCreateManagedWidget("skewb",
 		skewb2dWidgetClass, topLevel, NULL, 0);
+	XtAddCallback(puzzle2d, XtNselectCallback,
+		(XtCallbackProc) puzzleListener, (XtPointer) NULL);
+#ifdef HAVE_OPENGL
+	puzzle3d = XtCreateManagedWidget("skewb",
+		skewbGLWidgetClass, shell, NULL, 0);
+#else
 	puzzle3d = XtCreateManagedWidget("skewb",
 		skewb3dWidgetClass, shell, NULL, 0);
-#ifdef HAVE_OPENGL
-	puzzleGL = XtCreateManagedWidget("skewb",
-		skewbGLWidgetClass, shellGL, NULL, 0);
 #endif
 #endif
 	XtVaGetValues(puzzle2d,
@@ -1912,22 +1827,10 @@ main(int argc, char **argv)
 #endif
 	XtAddCallback(puzzle3d, XtNselectCallback,
 		(XtCallbackProc) puzzleListener, (XtPointer) NULL);
-#ifdef HAVE_OPENGL
-#ifndef HAVE_MOTIF
-	XtVaSetValues(shellGL,
-		XtNinput, True,
-		XtNiconPixmap, pixmap, NULL);
-#endif
-	XtAddCallback(puzzleGL, XtNselectCallback,
-		(XtCallbackProc) puzzleListener, (XtPointer) NULL);
-#endif
 	initialize();
 	XtRealizeWidget(topLevel);
 #ifndef HAVE_MOTIF
 	XtRealizeWidget(shell);
-#ifdef HAVE_OPENGL
-	XtRealizeWidget(shellGL);
-#endif
 #endif
 	XGrabButton(XtDisplay(puzzle2d), (unsigned int) AnyButton, AnyModifier,
 		XtWindow(puzzle2d), TRUE, (unsigned int) (ButtonPressMask |
@@ -1939,13 +1842,6 @@ main(int argc, char **argv)
 		ButtonMotionMask | ButtonReleaseMask),
 		GrabModeAsync, GrabModeAsync, XtWindow(puzzle3d),
 		XCreateFontCursor(XtDisplay(puzzle3d), XC_hand2));
-#ifdef HAVE_OPENGL
-	XGrabButton(XtDisplay(puzzleGL), (unsigned int) AnyButton, AnyModifier,
-		XtWindow(puzzleGL), TRUE, (unsigned int) (ButtonPressMask |
-		ButtonMotionMask | ButtonReleaseMask),
-		GrabModeAsync, GrabModeAsync, XtWindow(puzzleGL),
-		XCreateFontCursor(XtDisplay(puzzleGL), XC_crosshair));
-#endif
 	XtMainLoop();
 
 #ifdef VMS
