@@ -1,7 +1,7 @@
 /*
  * @(#)Threed.c
  *
- * Copyright 1994 - 2008  David A. Bagley, bagleyd@tux.org
+ * Copyright 1994 - 2010  David A. Bagley, bagleyd@tux.org
  *
  * All rights reserved.
  *
@@ -117,6 +117,7 @@ static char defaultTranslationsThreeD[] =
  <KeyPress>0x3C: Slow()\n\
  <KeyPress>0x2C: Slow()\n\
  Shift<KeyPress>2: Sound()\n\
+ <KeyPress>F11: MoveRaisePsi()\n\
  <KeyPress>KP_Divide: MoveRaisePsi()\n\
  <KeyPress>R5: MoveRaisePsi()\n\
  <KeyPress>Home: MoveRaiseThetaRaisePhi()\n\
@@ -136,6 +137,7 @@ static char defaultTranslationsThreeD[] =
  <KeyPress>KP_Left: MoveRaiseTheta()\n\
  <KeyPress>KP_4: MoveRaiseTheta()\n\
  <KeyPress>R10: MoveRaiseTheta()\n\
+ <KeyPress>F12: MoveLowerPsi()\n\
  <KeyPress>Begin: MoveLowerPsi()\n\
  <KeyPress>KP_5: MoveLowerPsi()\n\
  <KeyPress>R11: MoveLowerPsi()\n\
@@ -1221,9 +1223,9 @@ readThreeD(ThreeDWidget w)
 	(void) sscanf(string, "%d", &i);
 	w->threed.sound = (i != 0);
 	string = readLine(fp, buffer, SYMBOL);
-	(void) strcpy(w->threed.bumpSound, string);
+	(void) strncpy(w->threed.bumpSound, string, 80);
 	string = readLine(fp, buffer, SYMBOL);
-	(void) strcpy(w->threed.moveSound, string);
+	(void) strncpy(w->threed.moveSound, string, 80);
 	string = readLine(fp, buffer, SYMBOL);
 	(void) sscanf(string, "%d", &i);
 	w->threed.surface = (i != 0);
@@ -1458,10 +1460,8 @@ destroyThreeD(Widget old)
 	ThreeDWidget w = (ThreeDWidget) old;
 	int i;
 
-#if 0
 #if defined( USE_SOUND ) && defined( USE_ESOUND )
 	(void) shutdown_sound();
-#endif
 #endif
 	for (i = 0; i < COLORS; i++)
 		XtReleaseGC(old, w->threed.shadeGC[i]);
@@ -1623,12 +1623,10 @@ Widget request, Widget renew
 #ifdef USE_NAS
 	dsp = XtDisplay(w);
 #endif
-#if 0
 #ifdef USE_ESOUND
 	(void) init_sound();
 #endif
 #endif
-#endif
 }
 
 #ifndef WINVER
