@@ -1,7 +1,7 @@
 /*
  * @(#)Triangles.c
  *
- * Copyright 1994 - 2008  David A. Bagley, bagleyd@tux.org
+ * Copyright 1994 - 2010  David A. Bagley, bagleyd@tux.org
  *
  * All rights reserved.
  *
@@ -2001,17 +2001,17 @@ setValuesPuzzle(TrianglesWidget w)
 	} color;
 	char szBuf[80];
 
-	w->triangles.size = GetPrivateProfileInt(SECTION, "size",
-		DEFAULT_TILES, INIFILE);
-	w->triangles.base = GetPrivateProfileInt(SECTION, "base",
-		DEFAULT_BASE, INIFILE);
-	w->triangles.mono = (BOOL) GetPrivateProfileInt(SECTION, "mono",
-		DEFAULT_MONO, INIFILE);
+	w->triangles.size = GetPrivateProfileInt(SECTION,
+		"size", DEFAULT_TILES, INIFILE);
+	w->triangles.base = GetPrivateProfileInt(SECTION,
+		"base", DEFAULT_BASE, INIFILE);
+	w->triangles.mono = (BOOL) GetPrivateProfileInt(SECTION,
+		"mono", DEFAULT_MONO, INIFILE);
 	w->triangles.reverse = (BOOL) GetPrivateProfileInt(SECTION,
 		"reverseVideo", DEFAULT_REVERSE, INIFILE);
 	/* gray75 */
-	(void) GetPrivateProfileString(SECTION, "tileColor", "191 191 191",
-		szBuf, sizeof (szBuf), INIFILE);
+	(void) GetPrivateProfileString(SECTION,
+		"tileColor", "191 191 191", szBuf, sizeof (szBuf), INIFILE);
 	(void) sscanf(szBuf, "%d %d %d",
 		&(color.red), &(color.green), &(color.blue));
 	w->triangles.tileGC[1] = RGB(color.red, color.green, color.blue);
@@ -2020,14 +2020,14 @@ setValuesPuzzle(TrianglesWidget w)
         w->triangles.tileGC[2] = RGB(darker(color.red),
                 darker(color.green), darker(color.blue));
 	/* gray25 */
-	(void) GetPrivateProfileString(SECTION, "textColor", "64 64 64",
-		szBuf, sizeof (szBuf), INIFILE);
+	(void) GetPrivateProfileString(SECTION,
+		"textColor", "64 64 64", szBuf, sizeof (szBuf), INIFILE);
 	(void) sscanf(szBuf, "%d %d %d",
 		&(color.red), &(color.green), &(color.blue));
 	w->triangles.textGC = RGB(color.red, color.green, color.blue);
 	/* #AEB2C3 */
-	(void) GetPrivateProfileString(SECTION, "background", "174 178 195",
-		szBuf, sizeof (szBuf), INIFILE);
+	(void) GetPrivateProfileString(SECTION,
+		"background", "174 178 195", szBuf, sizeof (szBuf), INIFILE);
 	(void) sscanf(szBuf, "%d %d %d",
 		&(color.red), &(color.green), &(color.blue));
 	w->triangles.inverseGC[1] = RGB(color.red, color.green, color.blue);
@@ -2040,25 +2040,22 @@ setValuesPuzzle(TrianglesWidget w)
         w->triangles.inverseGC[4] = RGB(darker(darker(darker(color.red))),
                 darker(darker(darker(color.green))),
                 darker(darker(darker(color.blue))));
-	(void) GetPrivateProfileString(SECTION, "picture", PICTURE,
-		szBuf, sizeof (szBuf), INIFILE);
-	(void) strcpy(w->triangles.picture, szBuf);
-		w->triangles.picture[80] = 0;
-	w->triangles.delay = GetPrivateProfileInt(SECTION, "delay",
-		10, INIFILE);
-	w->triangles.sound = (BOOL)
-		GetPrivateProfileInt(SECTION, "sound", 0, INIFILE);
-	(void) GetPrivateProfileString(SECTION, "bumpSound", BUMPSOUND,
-		szBuf, sizeof (szBuf), INIFILE);
-	(void) strcpy(w->triangles.bumpSound, szBuf);
-	(void) GetPrivateProfileString(SECTION, "userName", "Guest",
-		szBuf, sizeof (szBuf), INIFILE);
-	(void) strcpy(w->triangles.userName, szBuf);
-	w->triangles.userName[80] = 0;
-	(void) GetPrivateProfileString(SECTION, "scoreFile", "",
-		szBuf, sizeof (szBuf), INIFILE);
-	(void) strcpy(w->triangles.scoreFile, szBuf);
-	w->triangles.scoreFile[80] = 0;
+	(void) GetPrivateProfileString(SECTION,
+		"picture", PICTURE, szBuf, sizeof (szBuf), INIFILE);
+	(void) strncpy(w->triangles.picture, szBuf, 80);
+	w->triangles.delay = GetPrivateProfileInt(SECTION,
+		"delay", 10, INIFILE);
+	w->triangles.sound = (BOOL) GetPrivateProfileInt(SECTION,
+		"sound", 0, INIFILE);
+	(void) GetPrivateProfileString(SECTION,
+		"bumpSound", BUMPSOUND, szBuf, sizeof (szBuf), INIFILE);
+	(void) strncpy(w->triangles.bumpSound, szBuf, 80);
+	(void) GetPrivateProfileString(SECTION,
+		"userName", "Guest", szBuf, sizeof (szBuf), INIFILE);
+	(void) strncpy(w->triangles.userName, szBuf, 80);
+	(void) GetPrivateProfileString(SECTION,
+		"scoreFile", "", szBuf, sizeof (szBuf), INIFILE);
+	(void) strncpy(w->triangles.scoreFile, szBuf, 80);
 }
 
 void
@@ -2309,10 +2306,8 @@ destroyPuzzle(Widget old)
 	Display *display = XtDisplay(w);
 	int i;
 
-#if 0
 #if defined( USE_SOUND ) && defined( USE_ESOUND )
 	(void) shutdown_sound();
-#endif
 #endif
 	XtReleaseGC(old, w->triangles.textGC);
 	for (i = 0; i < FG_SHADES; i++)
@@ -2560,12 +2555,10 @@ Widget request, Widget renew
 #ifdef USE_NAS
 	dsp = XtDisplay(w);
 #endif
-#if 0
 #ifdef USE_ESOUND
 	(void) init_sound();
 #endif
 #endif
-#endif
 }
 
 #ifndef WINVER
