@@ -1,27 +1,22 @@
-/*-
-# X-BASED TRIANGLES
-#
-#  TrianglesP.h
-#
-###
-#
-#  Copyright (c) 1994 - 2008	David A. Bagley, bagleyd@tux.org
-#
-#                   All Rights Reserved
-#
-#  Permission to use, copy, modify, and distribute this software and
-#  its documentation for any purpose and without fee is hereby granted,
-#  provided that the above copyright notice appear in all copies and
-#  that both that copyright notice and this permission notice appear in
-#  supporting documentation, and that the name of the author not be
-#  used in advertising or publicity pertaining to distribution of the
-#  software without specific, written prior permission.
-#
-#  This program is distributed in the hope that it will be "playable",
-#  but WITHOUT ANY WARRANTY; without even the implied warranty of
-#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
-#
-*/
+/*
+ * @(#)TrianglesP.h
+ *
+ * Copyright 1994 - 2008  David A. Bagley, bagleyd@tux.org
+ *
+ * All rights reserved.
+ *
+ * Permission to use, copy, modify, and distribute this software and
+ * its documentation for any purpose and without fee is hereby granted,
+ * provided that the above copyright notice appear in all copies and
+ * that both that copyright notice and this permission notice appear in
+ * supporting documentation, and that the name of the author not be
+ * used in advertising or publicity pertaining to distribution of the
+ * software without specific, written prior permission.
+ *
+ * This program is distributed in the hope that it will be "useful",
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ */
 
 /* Private header file for Triangles */
 
@@ -33,29 +28,29 @@
 #include "Triangles.h"
 
 #ifdef WINVER
-extern void DestroyPuzzle(TrianglesWidget w, HBRUSH brush);
-extern void ResizePuzzle(TrianglesWidget w);
-extern void SizePuzzle(TrianglesWidget w);
-extern void InitializePuzzle(TrianglesWidget w, HBRUSH brush);
-extern void ExposePuzzle(TrianglesWidget w);
-extern void HidePuzzle(TrianglesWidget w);
-extern void SelectPuzzle(TrianglesWidget w, const int x, const int y);
-extern void ReleasePuzzle(TrianglesWidget w);
-extern void GetPuzzle(TrianglesWidget w);
-extern void WritePuzzle(TrianglesWidget w);
-extern void UndoPuzzle(TrianglesWidget w);
-extern void RedoPuzzle(TrianglesWidget w);
-extern void ClearPuzzle(TrianglesWidget w);
-extern void RandomizePuzzle(TrianglesWidget w);
-extern void SolvePuzzle(TrianglesWidget w);
-extern void IncrementPuzzle(TrianglesWidget w);
-extern void DecrementPuzzle(TrianglesWidget w);
-extern void SpeedPuzzle(TrianglesWidget w);
-extern void SlowPuzzle(TrianglesWidget w);
-extern void SoundPuzzle(TrianglesWidget w);
-extern void EnterPuzzle(TrianglesWidget w);
-extern void LeavePuzzle(TrianglesWidget w);
-extern int MovePuzzle(TrianglesWidget w, const int direction);
+extern void destroyPuzzle(TrianglesWidget w, HBRUSH brush);
+extern void resizePuzzle(TrianglesWidget w);
+extern void sizePuzzle(TrianglesWidget w);
+extern void initializePuzzle(TrianglesWidget w, HBRUSH brush);
+extern void exposePuzzle(TrianglesWidget w);
+extern void hidePuzzle(TrianglesWidget w);
+extern void selectPuzzle(TrianglesWidget w, const int x, const int y);
+extern void releasePuzzle(TrianglesWidget w);
+extern void getPuzzle(TrianglesWidget w);
+extern void writePuzzle(TrianglesWidget w);
+extern void undoPuzzle(TrianglesWidget w);
+extern void redoPuzzle(TrianglesWidget w);
+extern void clearPuzzle(TrianglesWidget w);
+extern void randomizePuzzle(TrianglesWidget w);
+extern void solvePuzzle(TrianglesWidget w);
+extern void incrementPuzzle(TrianglesWidget w);
+extern void decrementPuzzle(TrianglesWidget w);
+extern void speedUpPuzzle(TrianglesWidget w);
+extern void slowDownPuzzle(TrianglesWidget w);
+extern void toggleSoundPuzzle(TrianglesWidget w);
+extern void enterPuzzle(TrianglesWidget w);
+extern void leavePuzzle(TrianglesWidget w);
+extern int movePuzzle(TrianglesWidget w, const int direction);
 
 #else
 
@@ -161,15 +156,15 @@ typedef struct _TrianglesRec {
 
 extern int *startPosition;
 extern void setPuzzle(TrianglesWidget w, int reason);
-extern int MovePuzzleDir(TrianglesWidget w, const int direction,
+extern int movePuzzleDir(TrianglesWidget w, const int direction,
 	const int fast);
 
 #if 0
 /* For future auto-solver */
-extern void SolveSomeTiles(TrianglesWidget w);
+extern void solveSomeTiles(TrianglesWidget w);
 #endif
-extern void DrawAllTiles(const TrianglesWidget w);
-extern Boolean CheckSolved(const TrianglesWidget w);
+extern void drawAllTiles(const TrianglesWidget w);
+extern Boolean checkSolved(const TrianglesWidget w);
 extern void newMoves(TrianglesStack *s);
 extern void deleteMoves(TrianglesStack *s);
 extern void setMove(TrianglesStack *s, int direction);
@@ -182,8 +177,8 @@ extern void printMoves(FILE *fp, TrianglesStack *s);
 extern void scanStartPosition(FILE *fp, TrianglesWidget w);
 extern void printStartPosition(FILE *fp, TrianglesWidget w);
 extern void setStartPosition(TrianglesWidget w);
-extern int Row(const int pos);
-extern int TrBl(const int pos, const int posRow);
-extern int TlBr(const int pos, const int posRow);
+extern int toRow(const int pos);
+extern int toTrBl(const int pos, const int posRow);
+extern int toTlBr(const int pos, const int posRow);
 
 #endif /* _TrianglesP_h */
